C     Output of FBtoFO from GEF1evt.BAS
      PROGRAM MAIN
      IMPLICIT NONE
C     '   GEV1evt.bas 
C     '   Calculates the observables of one fission event. 
C     ' 
C     ' 
C     '    Copyright 2009,2010,2011,2012,2013,2014: 
C     '       Dr. Karl-Heinz Schmidt,Rheinstrasse 4,64390 Erzhausen,Germany 
C     '       and 
C     '       Dr. Beatriz Jurado,Centre d'Etudes Nucleaires de Bordeaux-Gradignan, 
C     '       Chemin du Solarium,Le Haut Vigneau,BP 120,33175 Gradignan,Cedex, 
C     '       France 
C     ' 
C     '    This program is free software: you can redistribute it and/or modify 
C     '    it under the terms of the GNU General Public License as published by 
C     '    the Free Software Foundation,either version 3 of the License,or 
C     '    (at your option) any later version. 
C     ' 
C     '    This program is distributed in the hope that it will be useful, 
C     '    but WITHOUT ANY WARRANTY; without even the implied warranty of 
C     '    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
C     '    GNU General Public License for more details. 
C     ' 
C     '    You should have received a copy of the GNU General Public License 
C     '    along with this program.  If not,see <http://www.gnu.org/licenses/>. 
C     ' 
C     ' 
C     /' Documentation: '/ 
C     /' (1) K.-H. Schmidt and B. Jurado,Contribution to '/ 
C     /'     ESNT Workshop "The scission process",Saclay (France),April 12-16,2010 '/ 
C     /' (2) B. Jurado and K.-H. Schmidt,Contribution to '/ 
C     /'     Seminar an fission,Gent (Belgium),May 17-20,2010 '/ 
C     /' (3) K.-H. Schmidt and B. Jurado,Contribution to '/ 
C     /'     Seminar on fission,Gent (Belgium),May 17-20,2010 '/ 
C     /' (4) B. Jurado and K.-H. Schmidt,Contribution to '/ 
C     /'     EFNUDAT Workshop,Paris (France),May 25-27,2010 '/ 
C     /' (5) K.-H. Schmidt and B. Jurado,Contribution to '/ 
C     /'     EFNUDAT Workshop,Paris (France),May 25-27,2010 '/ 
C     /' (6) K.-H. Schmidt and B. Jurado,'/ 
C     /'     Final Report to EFNUDAT,October,2010 '/ 
C     /' (7) K.-H. Schmidt and B. Jurado,Phys. Rev. Lett. 104 (2010) 21250 '/ 
C     /' (8) K.-H. Schmidt and B. Jurado,Phys. Rev. C 82 (2011) 014607 '/ 
C     /' (9) K.-H. Schmidt and B. Jurado,Phys. Rev. C 83 (2011) 061601 '/ 
C     /' (10) K.-H. Schmidt and B. Jurado,arXiv:1007.0741v1[nucl-th] (2010) '/ 
C     /' (11) K.-H. Schmidt and B. Jurado,JEF/DOC 1423,NEA of OECD,2012 '/ 
C     /' (12) K.-H. Schmidt and B. Jurado,Phys. Rev. C 86 (2012) 044322 '/ 
C     /' (13) K.-H. Schmidt,B. Jurado,Ch. Amouroux,JEFF-Report 24,NEA of OECD,2014 '/ 
C     ' 
C     ' 
C     /' Further documentation and the newest version of the GEF code are '/ 
C     /' available from                                                   '/ 
C     /' http://www.cenbg.in2p3.fr/GEF and http://www.khs-erzhausen.de/ . '/ 
C     ' 
C     ' 
C     '    The development of the GEF code has been supported by the European Union, 
C     '    EURATOM 6 in the Framework Program "European Facilities for Nuclear Data 
C     '    Measurements" (EFNUDAT),contract number FP6-036434,the Framework 
C     '    Program "European Research Infrastructure for Nuclear Data Applications 
C     '    (ERINDA),contract number FP7-269499,and by the OECD Nuclear Energy Agency. 
C     ' 
C     ' 
C     ' Technical remark: The code contains commented sections with 
C     ' produce a deterministic version of the GEF code as a subroutine from this 
C     ' source with a dedicated pre-processor,named ExtractSub.bas. 
C     ' are used in the deterministic GEF version. 
C     ' ExtractSub.bas produces the deterministic code GEFSUB.bas in FreeBASIC. 
C     ' The translator FBtoFO.bas can be used to translate this code into FORTRAN99. 
C     ' In order to enable this translation,GEF.bas contains already some additional 
C     ' that are only used by the translator to provide some specific 
C     ' FORTRAN statements that cannot be automatically produced. 
C     ' 
C     ' 
C     /' K.-H. Schmidt / B. Jurado,07/Feb./2009 '/ 
C     /' SEFI9 is taken as a basis and extended by new features in SEFI14 (May 2010),KHS '/ 
C     /' Several improvements (even-odd effect,charge polarization etc. (June 2010),KHS '/ 
C     /' SEFI15 converted to FreeBASIC on 04/July/2010,KHS '/ 
C     /' Error in LyPair corrected (26/July/2010) KHS '/ 
C     /' Indices corrected in U_Shell inside Eva (1/Aug/2010) KHS '/ 
C     /' Major developments,sigma_E*(scission),sigma_Z(A) etc. (14/Aug/2010) KHS '/ 
C     /' Macroscopic masses from Thomas-Fermi model (Myers & Swiatecki) (17/Aug/2010) KHS '/ 
C     /' 3 reference options for energy input (4/Sept/2010) KHS '/ 
C     /' Graphic output of mass distribution added (if there are problems with the X11 
C     installation on LINUX,the graphics may be suppressed by simply commenting 
C     the line  -> #Include Once "DCLPlotting.bas" <- )  (5/Sept/2010) KHS '/ 
C     /' Comparison with ENDF compilation in graphic output (12/Sept/2010) KHS '/ 
C     /' Super-long fission channel included (14/Sept/2010) KHS '/ 
C     /' Overlap of S1 and S2 fission channels in both fragments included (18/Oct/2010) KHS '/ 
C     /' Output of neutron multiplicity distribution added (20/Oct/2010) KHS '/ 
C     /' Decreasing curvature of shells with increasing E* (24/Oct/2010) KHS '/ 
C     /' Angular momenta of fission fragments added (18/Dec/2010) KHS '/ 
C     /' CN angular momentum considered (14/Jan/2011) KHS '/ 
C     /' Numerical stability improved (28/Jan/2011) KHS '/ 
C     /' Output in ENDF format (optional) (4/Feb/2011) KHS '/ 
C     /' Input list from file supported (31/Jan/2011) KHS '/ 
C     /' Multiprocessing supported (5/Feb/2011) KHS '/ 
C     /' Polarization for symmetric fission channel improved (12/Feb/2011) KHS '/ 
C     /' GUI for input (23/Feb/2011) KHS '/ 
C     /' Calculation of fission-fragment angular momentum refined (5/May/2011) KHS '/ 
C     /' Neutron inverse cross section modified (5/August/2011) KHS '/ 
C     /' Even-odd staggering in neutron emission improved (5/August/2011) KHS '/ 
C     /' Slight modifications in angular-momentum distributions (19/October/2011) KHS '/ 
C     /' Gamma emission added (23/November/2011) KHS '/ 
C     /' TKE added (24/November/2011) KHS '/ 
C     /' Neutron spectrum added (25/November/2011) KHS '/ 
C     /' Neutron-gamma competition added (4/December/2011) KHS '/ 
C     /' Composite level density (Egidy + Ignatyuk) refined (31/January/2012) KHS '/ 
C     /' Treatment of GDR refined (14/February/2012) KHS '/ 
C     /' Deformation of S3 channel changed (27/February/2012) KHS '/ 
C     /' Z=44 deformed shell added (supports S1 around Pu) (27/February/2012) KHS '/ 
C     /' Uncertainties from perturbed fission yields (3/March/2012) KHS '/ 
C     /' Validity range extended to Z=120 (with a warning message) (8/March/2012) KHS '/ 
C     /' Neutron emission during fragment acceleration (18/March/2012) KHS '/ 
C     /' Several optimizations (15/April/2012) KHS '/ 
C     /' TF masses of Myers & Swiatecki corrected (pairing shift) (29/May/2012) KHS '/ 
C     /' Correction on intrinsic excitation energy (05/June/2012) KHS '/ 
C     /' Correction on gamma emission (25/September/2012) KHS '/ 
C     /' Free choice of listmode values (13/October/2012) KHS '/ 
C     /' Excitation-energy distribution from file (14/October/2012) KHS '/ 
C     /' Transfer of input from GUI corrected (02/November/2012) KHS '/ 
C     /' Parameters of perturbed calculations modified (02/November/2012) KHS '/ 
C     /' Model parameters je-adjusted (08/November/2012) KHS '/ 
C     /' Input options for isomeric target nuclei (09/November/2012) KHS '/ 
C     /' Random initialisation of the random generator (26/November/2012) KHS '/ 
C     /' Covariance matrix for Z,Apre,Apost,ZApre,ZApost (06/December/2012) KHS '/ 
C     /' Output file in XML format (06/December/2012) KHS '/ 
C     /' Multi-chance fission supported (13/December/2012) KHS '/ 
C     /' Pre-compound emission for (n,f) included (13/December/2012) KHS '/ 
C     /' Some technical corrections and modifications (17/December/2012) KHS '/ 
C     /' Transition from asymmetric to symmetric fission around Fm improved (19/December/2012) KHS '/ 
C     /' Influence of S2 channel on S1 channel in the other fragment included (20/December/2012) KHS'/ 
C     /' List-mode output of pre-fission neutron energies (21/December/2012) KHS '/ 
C     /' Parameterisation for EB-EA from fit to data in Dahlinger et al. (21/December/2012) KHS '/ 
C     /' Fission channel at Z=42 added (seen around Pu in light fragment and around Hg) (23/Dec./2012) KHS '/ 
C     /' Gamma-n / Gamma-f according to Moretto (IAEA Rochester) (23/December/2012) KHS '/ 
C     /' Pre-compound neutron energies modified (24/December/2012) KHS '/ 
C     /' Some technical revisions to avoid crashes in covariances (26/December/2012) KHS '/ 
C     /' Influence of shells on yrast line from Deleplanque et al. (26/December/2012) KHS '/ 
C     /' Fission threshold in multi-chance fission modified (30/December/2012) KHS '/ 
C     /' Output of energies at fission for multi-chance fission (30/December/2012) KHS '/ 
C     /' Several revisions (15/January/2013) KHS '/ 
C     /' New optical model fit (3/February/2013) KHS '/ 
C     /' Gamma-f / Gamma-n modified (3/February/2013) KHS '/ 
C     /' Handling for reading input from file corrected (5/February/2013) KHS '/ 
C     /' Data transfer from GUI corrected (6/February/2013) KHS '/ 
C     /' Input dialog re-organized (6/February/2013) KHS '/ 
C     /' Mass-dependent deformation and charge polarization revised (9/February/2013) KHS '/ 
C     /' Calculation of combined fission channels S12,S22 revised (10/February/2013) KHS '/ 
C     /' Extension of validity range to heavier nuclei (10/February/2013) KHS '/ 
C     /' Improved description of prompt-neutron spectra (21/February/2013) KHS '/ 
C     /' Several technical corrections and developments (April-May/2013) KHS '/ 
C     /' Pre-fission emission of protons considered (14/Mai,2013) KHS '/ 
C     /' Structure of energy list in input file modified (26/May/2013) KHS '/ 
C     /' Option "local fit" added (26/May/2013) KHS '/ 
C     /' Neutron evaporation corrected (more realistic even-odd effect in isotonic distr.) (21/June(2013) KHS '/ 
C     /' Even-odd effect in TKE added (23/June/2013) KHS '/ 
C     /' Calculation of Z-A-covariance matrix corrected (16/July/2013) KHS '/ 
C     /' Output of multi-variant distributions corrected for input from file (24/July/2013) KHS '/ 
C     /' New global fit (most important: Energy gain from saddle to scission reduced) (15/September/2013) KHS '/ 
C     /' Even-odd effect in neutron number of fragments modified (17/September/2013) KHS '/ 
C     /' Curvatures of fission valleys adjusted to experimental shells around 132Sn (18/September/2013) KHS '/ 
C     /' Width of S0 corrected: Fit of Rusanov (18/September/2013) KHS '/ 
C     /' Random generator Box with asymmetric diffuseness for S2 (18/September/2013) KHS '/ 
C     /' Gaussian random generator revised (20/September/2013) KHS '/ 
C     /' Mass shift of fission channels with E* modified (22/September/2013) KHS '/ 
C     /' Energy dependence of S1 position corrected,slightly modified parameters (25/September/2013) KHS '/ 
C     /' Initial angular momentum introduced as an input parameter (02/October/2013) KHS '/ 
C     /' Calculation of prompt-neutron emission improved,some model parameters modified (12/October/2013) KHS '/ 
C     /' Technical error,causing incomplete covariance matrices on output corrected  (17/October/2013) KHS '/ 
C     /' Washing of shell effects considerd in shape fluctuations (26/October/2013) KHS '/ 
C     /' Post-scission neutrons added to list-mode output (8/November/2013) KHS '/ 
C     /' Fission-gamma competition refined (10/November/2013) KHS '/ 
C     /' New global fit of model parameters (18/November/2013) KHS '/ 
C     /' Multi-chance fission modified (18/November/2013) KHS '/ 
C     /' A numerical instability removed (20/November/2013) KHS '/ 
C     /' Calculation of multi-chance fission: corrected and modified (28/November/2013) KHS '/ 
C     /' Spurious even-odd effect in fission probabilities (from Moeller's shells) removed (4/December/2013) KHS '/ 
C     /' More precise calculation of E* in n-induced fission (6/December/2013) KHS '/ 
C     /' Pre-fission gamma strength increased (adjusted to Pf(E*) of 238U (22/December/2013) KHS '/ 
C     /' Kinetic energy of prompt neutrons in cm system (fragment-neutron) (10/Janurary/2014) KHS '/ 
C     /' Binnig of prompt-neutron spectra corrected (shift by 50 keV) (10/January/2014) KHS '/ 
C     /' Description of fission barriers modified (15/January/2014) KHS '/ 
C     /' Description of energy-dependent fission probability modified (17/January/2014) KHS '/ 
C     /' E* at scission modified for fission below Bf (4/February/2014) KHS '/ 
C     /' Influence of Z=44 shell on deformation of light fragment (4/February/2014) KHS '/ 
C     /' Tunneling for S1 enhanced (16/February/2014) KHS '/ 
C     /' New global fit of fission channels (strength and position) (19/March/2014) KHS '/ 
C     /' Normalization of distributions for deterministic version corrected (23/May/2014) KHS '/ 
C     /' Calculation of "corrected sample variance" revised (05/September/2014) KHS '/ 
C     /' Uncertainties calculated with "corrected sample variance" (05/September/2014) KHS '/ 
C     /' Binsize for prompt neutrons set to 1 keV (09/December/2014) KHS '/ 
C     /' Binsize for prompt gammas set to 1 keV (09/December/2014) KHS '/ 
C     ' 
C     /' FreeBASIC is available from http://www.freebasic.net/ '/ 
C     /' It runs on Windows,Linux,and DOS. '/ 
C     /' FreeBASIC compiles a binary code that uses the C run-time library. '/ 
C     ' 
C     ' 
C     '  #Include "utilities.bi" 
C     ' 
C     /' Functions and subroutines '/ 
C     ' 
      	 
      DO Ntimes = 1 , 100 
C     ' 
      CALL GEFSUB(92,236,6.0,0.0) 
C     ' 
C     'Print "-------------------------" 
      END DO 
C     'Print Time 
C     /' 
C     Dim As Single Zsum 
C     ' 
C     'Print 
C     'Print "Z,A,Yield" 
C     For J = 20 To 80 
C     Zsum = 0 
C     For I = 20 To 150 
C     Zsum = Zsum + NZpre(I,J) 
C     If NZPRE(I,J) > 0.00001 Then 
C     '      Print J,I+J,NZPRE(I,J)*200 
C     End If 
C     Next I 
C     Next J 
C     ' 
C     'Print 
C     'Print "Z yields" 
C     For J = 20 To 80 
C     Zsum = 0 
C     For I = 20 To 150 
C     Zsum = Zsum + NZpre(I,J) 
C     Next I 
C     '  Print J,Zsum * 200 
C     Next J 
C     ' 
C     Dim As Single Asum 
C     'Print 
C     'Print "N yields" 
C     For I = 20 To 150 
C     Asum = 0 
C     For J = 20 To 80 
C     Asum = Asum + NZpre(I,J) 
C     '   If NZPRE(I,J) > 0.001 Then 
C     '     Print J,I+J,NZPRE(I,J)*200 
C     '   End If 
C     Next 
C     '  Print I,Asum * 200 
C     Next   '/ 
C     ' 
      End 
C     ' 
C     ' 
      SUBROUTINE GEFSUB(P_Z_CN,P_A_CN,P_E_EXC,P_J_CN)
      IMPLICIT NONE
      INTEGER*4 P_Z_CN
      INTEGER*4 P_A_CN
      REAL*4 P_E_EXC
      REAL*4 P_J_CN
C     /' Input parameters: '/ 
C     /' Atomic number,mass number,excitation energy/MeV,spin/h_bar of CN '/ 
C     /' Results are stored in external arrays. '/ 
C     ' 
      INCLUDE "GEF1evtdcl2.FOR" 
      xDelta_S0 = U_Delta_S0(P_Z_CN,P_A_CN) 
C     ' default values 
C     ' 
C     ' Use nominal parameter values: 
      P_DZ_Mean_S1 = xP_DZ_Mean_S1 
      P_DZ_Mean_S2 = xP_DZ_Mean_S2 
      P_DZ_Mean_S3 = xP_DZ_Mean_S3 
      P_DZ_Mean_S4 = xP_DZ_Mean_S4 
      P_Z_Curv_S1 = xP_Z_Curv_S1 
      P_Z_Curv_S2 = xP_Z_Curv_S2 
      P_A_Width_S2 = xP_A_Width_S2 
      P_Z_Curv_S3 = xP_Z_Curv_S3 
      P_Z_Curv_S4 = xP_Z_Curv_S4 
      Delta_S0 = xDelta_S0 
      P_Shell_S1 = xP_Shell_S1 
      P_Shell_S2 = xP_Shell_S2 
      P_Shell_S3 = xP_Shell_S3 
      P_Shell_S4 = xP_Shell_S4 
      T_low_S1 = xT_low_S1 
      T_low_S2 = xT_low_S2 
      T_low_S3 = xT_low_S3 
      T_low_S4 = xT_low_S4 
      T_low_SL = xT_low_SL 
      P_att_pol = xP_att_pol 
      HOMPOL = xHOMPOL 
      POLARadd = xPOLARadd 
C     ' 
      R_E_exc_used = P_E_exc 
      I_A_CN = P_A_CN 
      I_Z_CN = P_Z_CN 
C     ' 
C     /' Central Z values of fission modes '/ 
C     ' 
C     /' Fit to positions of fission channels (Boeckstiegel et al.,2008) '/ 
C     /' P_DZ_Mean_S1 and P_DZ_Mean_S2 allow for slight adjustments '/ 
C     '    Scope 
      R_Z_mod = I_Z_CN 
      ZC_Mode_0 = R_Z_mod * 0.5E0 
C     /' Central Z value of SL mode '/ 
      ZC_Mode_1 = (53.0E0 - 51.5E0) / (1.56E0 - 1.50E0) * 
     *(R_Z_mod**1.3E0 / I_A_CN - 1.50E0) + 51.5E0 + P_DZ_Mean_S1 
      ZC_Mode_2 = (55.8E0 - 54.5E0) / (1.56E0 - 1.50E0) * 
     *(R_Z_mod**1.3E0 / I_A_CN - 1.50E0) + 54.5E0 + P_DZ_Mean_S2 
      ZC_Mode_3 = ZC_Mode_2 + 4.5E0 + P_DZ_Mean_S3 
      ZC_Mode_4 = 42.05 + P_DZ_Mean_S4 
C     '    End Scope 
C     ' 
C     ' 
C     ' 
      I_N_CN = I_A_CN - I_Z_CN 
C     /' Mean deformation at scission as a function of mass '/ 
C     /' Mode 0: liquid drop and mode 4: Z = 44 '/ 
      beta1_prev = 0.3 
      beta2_prev = 0.3 
      beta1_opt = beta1_prev 
      beta2_opt = beta2_prev 
      DO I = 10 , I_Z_CN - 10 
      Z1 = I 
      Z2 = I_Z_CN - Z1 
      A1 = Z1 / REAL(I_Z_CN) * REAL(I_A_CN) 
      A2 = I_A_CN - A1 
C     ' 
      CALL Beta_Equi(A1,A2,Z1,Z2,dneck,beta1_prev,beta2_prev,beta1_opt,
     *beta2_opt) 
C     ' 
C     'Print "Mode 0,Z1,Z2,beta1,beta2 ";Z1;" ";Z2;" ";beta1_opt,beta2_opt 
C     'Print Z1;" ";Z2;" ";beta1_opt,beta2_opt 
      Beta(0,1,I) = beta1_opt 
C     /' "light" fragment '/ 
      Beta(4,1,I) = beta1_opt 
      Beta(0,2,I) = beta1_opt 
C     /' "heavy" fragment '/ 
      Beta(4,2,I) = beta1_opt 
      beta1_prev = beta1_opt 
      beta2_prev = beta2_opt 
      E_defo = Lymass(Z1,A1,beta1_opt) - Lymass(Z1,A1,0.0) 
C     'Print "Edefo 1",E_defo 
      Edefo(0,1,I) = E_defo 
C     /' "light" fragment '/ 
      Edefo(4,1,I) = E_defo 
      Edefo(0,2,I) = E_defo 
C     /' "heavy" fragment '/ 
      Edefo(4,2,I) = E_defo 
      END DO 
C     ' 
C     /' Mode 1: deformed shells (light) and spherical (heavy) '/ 
      DO I = 10 , I_Z_CN - 10 
      Z1 = I 
      Z2 = I_Z_CN - Z1 
      A1 = (Z1 - 0.5E0) / REAL(I_Z_CN) * REAL(I_A_CN) 
C     /' polarization roughly considered '/ 
      A2 = I_A_CN - A1 
      IF (  I_Z_CN * 0.5 .LT. ZC_Mode_1  ) THEN 
C     ' Beta_opt_light(A1,A2,Z1,Z2,dneck,0,rbeta_ld) 
C     /' nu_mean of Cf requires shells in the light fragment: '/ 
      rbeta = beta_light(I,betaL0,betaL1) - 0.1 
C     ' smaller than general deformation of light fragment 
C     '        (less neck influence due to spherical heavy fragment) 
      IF (  rbeta .LT. 0  )  rbeta = 0 
      Else 
      rbeta = beta_heavy(I,betaH0,betaH1) 
C     ' equal to S2 channel 
      IF (  rbeta .LT. 0  )  rbeta = 0 
      End If 
      Beta(1,1,I) = rbeta 
C     /' "light" fragment '/ 
      E_defo = Lymass(Z1,A1,rbeta) - Lymass(Z1,A1,0.0) 
      Edefo(1,1,I) = E_defo 
C     /' "light" fragment '/ 
      END DO 
C     ' 
      DO I = 10 , I_Z_CN - 10 
      rbeta = 0 
      Beta(1,2,I) = rbeta 
      Edefo(1,2,I) = 0 
C     /' "heavy" fragment (at S1 shell) '/ 
      END DO 
C     ' 
C     /' Mode 2: deformed shells (light and heavy) '/ 
      DO I = 10 , I_Z_CN - 10 
      Z1 = I 
      Z2 = I_Z_CN - Z1 
      A1 = (Z1 - 0.5E0) / REAL(I_Z_CN) * REAL(I_A_CN) 
C     /' polarization roughly considered '/ 
      A2 = I_A_CN - A1 
      IF (  I_Z_CN * 0.5 .LT. ZC_Mode_2  ) THEN 
C     ' Beta_opt_light(A1,A2,Z1,Z2,dneck,beta_heavy(Z2),rbeta_ld) 
      rbeta = beta_light(I,betaL0,betaL1) 
C     ' general deformation of light fragment 
      IF (  rbeta .LT. 0  )  rbeta = 0 
C     ' negative values replaced by 0 
      Else 
      rbeta = beta_heavy(I,betaH0,betaH1) 
C     ' equal to S2 channel 
      End If 
      Beta(2,1,I) = rbeta 
      E_defo = Lymass(Z1,A1,rbeta) - Lymass(Z1,A1,0.0) 
      Edefo(2,1,I) = E_defo 
      END DO 
      DO I = 10 , I_Z_CN - 10 
      rbeta = beta_heavy(I,betaH0,betaH1) 
C     /' "heavy" fragment (at S2 shell)'/ 
      IF (  rbeta .LT. 0  )  rbeta = 0 
C     ' negative values replaced by 0 
      Beta(2,2,I) = rbeta 
      Z1 = I 
      A1 = (Z1 + 0.5E0) / I_Z_CN * I_A_CN 
C     /' polarization roughly considered '/ 
      E_defo = Lymass(Z1,A1,rbeta) - Lymass(Z1,A1,0.0) 
      Edefo(2,2,I) = E_defo 
      END DO 
C     ' 
C     /' Mode 3 '/ 
      DO I = 10 , I_Z_CN - 10 
      Z1 = I 
      Z2 = I_Z_CN - Z1 
      A1 = (Z1 - 0.5E0) / REAL(I_Z_CN) * REAL(I_A_CN) 
C     /' polarization roughly considered '/ 
      A2 = I_A_CN - A1 
      rbeta = beta_light(I,betaL0,betaL1) 
      rbeta = Max(rbeta-0.10,0.0) 
C     /' for low nu-bar of lightest fragments '/ 
C     '  Beta_opt_light(A1,A2,Z1,Z2,dneck,beta_heavy(Z2,betaH0,betaH1),rbeta) 
      Beta(3,1,I) = rbeta 
      E_defo = Lymass(Z1,A1,rbeta) - Lymass(Z1,A1,0.0) 
      Edefo(3,1,I) = E_defo 
      END DO 
      DO I = 10 , I_Z_CN - 10 
      rbeta = beta_heavy(I,betaH0,betaH1) + 0.2 
C     /' for high nu-bar of heaviest fragments '/ 
      IF (  rbeta .LT. 0  )  rbeta = 0 
      Beta(3,2,I) = rbeta 
      Z1 = I 
      A1 = (Z1 + 0.5E0) / REAL(I_Z_CN) * REAL(I_A_CN) 
C     /' polarization roughly considered '/ 
      E_defo = Lymass(Z1,A1,rbeta) - Lymass(Z1,A1,0.0) 
      Edefo(3,2,I) = E_defo 
      END DO 
C     ' 
C     /' Mode 5: (Channel ST1 in both fragments) '/ 
      DO I = 10 , I_Z_CN - 10 
      Z1 = I 
      Z2 = I_Z_CN - Z1 
      rbeta = Beta(1,2,I) 
      IF (  rbeta .LT. 0  )  rbeta = 0 
      Beta(5,1,Int(Z1)) = rbeta 
      Beta(5,2,Int(Z1)) = rbeta 
      END DO 
C     ' 
C     /' Mode 6: (Channel ST2 in both fragments) '/ 
      DO I = 10 , I_Z_CN - 10 
      Z1 = I 
      Z2 = I_Z_CN - Z1 
      rbeta = Beta(2,2,I) 
      IF (  rbeta .LT. 0  )  rbeta = 0 
      Beta(6,1,Int(Z1)) = rbeta 
      Beta(6,2,Int(Z1)) = rbeta 
      END DO 
C     ' 
C     ' 
C     /' Mean Z as a function of mass '/ 
C     ' 
C     /' Mode 0 '/ 
      DO I = 10 , I_A_CN - 10 
      ZUCD = REAL(I) / REAL(I_A_CN) * REAL(I_Z_CN) 
      beta1 = Beta(0,1,Int(ZUCD + 0.5)) 
      beta2 = Beta(0,2,Int(I_Z_CN - ZUCD + 0.5)) 
      Z1 = Z_equi(I_Z_CN,I,I_A_CN - I,beta1,beta2,dneck,0,0.0,1.0) 
      Zmean(0,1,I) = Z1 
      Zshift(0,1,I) = Z1 - ZUCD 
      Zmean(0,2,I_A_CN - I) = I_Z_CN - Z1 
      Zshift(0,2,I_A_CN - I) = ZUCD - Z1 
      END DO 
C     ' 
C     /' Mode 1 '/ 
      DO I = 10 , I_A_CN - 10 
      ZUCD = REAL(I) / REAL(I_A_CN) * REAL(I_Z_CN) 
      Z = ZUCD + ZPOL1 
C     /' Charge polarisation is considered in a crude way '/ 
      beta1 = Beta(1,1,NINT(Z)) 
C     /' "light" fragment '/ 
      Z = ZUCD - ZPOL1 
      beta2 = Beta(1,2,NINT(I_Z_CN-Z)) 
C     /' "heavy" fragment  at S1 shell '/ 
      IF (  REAL(I_Z_CN) * 0.5 .LT. ZC_Mode_1  ) THEN 
      Z1 = Z_equi(I_Z_CN,I,I_A_CN - I,beta1,beta2,dneck,1,POLARadd,
     *POLARfac) 
      Else 
      Z1 = Z_equi(I_Z_CN,I,I_A_CN - I,beta1,beta2,dneck,1,0.0,0.0) 
      End If 
      Z1 = Z1 + ZPOL1 
C     /' Charge polarization by shell '/ 
C     ' 
      IF (  I_Z_CN - Z1 .LT. 50 .AND. (I_Z_CN - Z1) .GT. Z1  ) THEN 
      Z1 = I_Z_CN - 50 
C     /' Z of mean heavy fragment not below 50 '/ 
      END IF 
C     ' 
      Zmean(1,1,I) = Z1 
      Zshift(1,1,I) = Z1 - ZUCD 
C     ' neutron-deficient 
      Zmean(1,2,I_A_CN - I) = I_Z_CN - Z1 
      Zshift(1,2,I_A_CN - I) = ZUCD - Z1 
C     ' neutron rich at shell 
      END DO 
C     ' 
C     /' Mode 2 '/ 
      DO I = 10 , I_A_CN - 10 
      ZUCD = REAL(I) / REAL(I_A_CN) * REAL(I_Z_CN) 
      Z = ZUCD 
C     /' Charge polarisation is here neglected '/ 
      beta1 = Beta(2,1,NINT(Z)) 
      beta2 = Beta(2,2,NINT(I_Z_CN-Z)) 
      IF (  REAL(I_Z_CN) * 0.5 .LT. ZC_Mode_2  ) THEN 
      Z1 = Z_equi(I_Z_CN,I,I_A_CN-I,beta1,beta2,dneck,2,POLARadd,
     *POLARfac) 
      Else 
      Z1 = Z_equi(I_Z_CN,I,I_A_CN-I,beta1,beta2,dneck,2,0.0,0.0) 
      End If 
C     ' 
      Zmean(2,1,I) = Z1 
      Zshift(2,1,I) = Z1 - ZUCD 
C     ' neutron deficieint 
      Zmean(2,2,I_A_CN - I) = I_Z_CN - Z1 
      Zshift(2,2,I_A_CN - I) = ZUCD - Z1 
C     ' neutron rich at shell 
      END DO 
C     ' 
C     /' Mode 3 '/ 
      DO I = 10 , I_A_CN - 10 
      ZUCD = REAL(I) / REAL(I_A_CN) * REAL(I_Z_CN) 
      Z = ZUCD 
C     /' Charge polarisation is here neglected '/ 
      beta1 = Beta(3,1,NINT(Z)) 
      beta2 = Beta(3,2,NINT(I_Z_CN-Z)) 
      Z1 = Z_equi(I_Z_CN,I,I_A_CN - I,beta1,beta2,dneck,3,POLARadd,
     *POLARfac) 
      Zmean(3,1,I) = Z1 
      Zshift(3,1,I) = Z1 - ZUCD 
      Zmean(3,2,I_A_CN - I) = I_Z_CN - Z1 
      Zshift(3,2,I_A_CN - I) = ZUCD - Z1 
      END DO 
C     ' 
C     /' Mode 4 (assumed to be equal to mode 0) '/ 
      DO I = 10 , I_A_CN - 10 
      Zmean(4,1,I) = Zmean(0,1,I) 
      Zshift(4,1,I) = Zshift(0,1,I) 
      Zmean(4,2,I_A_CN - I) = Zmean(0,2,I_A_CN - I) 
      Zshift(4,2,I_A_CN - I) = Zshift(0,2,I_A_CN - I) 
      END DO 
C     ' 
C     ' 
C     /' General relations between Z and A of fission channels '/ 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_0 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(0,2,NINT(RA)) 
      END DO 
      AC_Mode_0 = (ZC_Mode_0 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
C     /' mean position in mass '/ 
      NC_Mode_0 = AC_Mode_0 - ZC_Mode_0 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_1 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(1,2,NINT(RA)) 
      END DO 
      AC_Mode_1 = (ZC_Mode_1 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      NC_Mode_1 = AC_Mode_1 - ZC_Mode_1 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_2 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(2,2,NINT(RA)) 
      END DO 
      AC_Mode_2 = (ZC_Mode_2 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      NC_Mode_2 = AC_Mode_2 - ZC_Mode_2 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_3 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(3,2,NINT(RA)) 
      END DO 
      AC_Mode_3 = (ZC_Mode_3 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      NC_Mode_3 = AC_Mode_3 - ZC_Mode_3 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_4 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(4,2,NINT(RA)) 
      END DO 
      AC_Mode_4 = (ZC_Mode_4 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      NC_Mode_4 = AC_Mode_4 - ZC_Mode_4 
C     ' 
C     ' 
C     /' Potential curvatures of fission modes '/ 
C     ' 
      RI = REAL(I_N_CN - I_Z_CN)/REAL(I_A_CN) 
C     /' measure of neutron excess '/ 
      R_Z_Curv_S0 = 8.E0 / REAL(I_Z_CN)**2 * Masscurv(REAL(I_Z_CN),
     *REAL(I_A_CN),RI,kappa) 
      R_Z_Curv1_S0 = 8.E0 / REAL(I_Z_CN)**2 * Masscurv1(REAL(I_Z_CN),
     *REAL(I_A_CN),RI,kappa) 
      R_A_Curv1_S0 = 8.E0 / REAL(I_A_CN)**2 * Masscurv1(REAL(I_Z_CN),
     *REAL(I_A_CN),RI,kappa) 
C     ' 
C     ' 
C     ' 
C     /' Energy transformation '/ 
C     ' 
      Select CASE( Emode) 
      CASE( 0) 
C     ' Energy above outer barrier given 
      R_E_exc_Eb = R_E_exc_used 
      R_E_exc_GS = R_E_exc_used + BFTFB(REAL(I_Z_CN),REAL(I_A_CN),1) 
      CASE( 1,3,-1) 
C     ' Energy above ground state given 
      R_E_exc_Eb = R_E_exc_used - BFTFB(REAL(I_Z_CN),REAL(I_A_CN),1) 
      R_E_exc_GS = R_E_exc_used 
      CASE( 2) 
C     ' kinetic energy of neutron given 
      SN = (U_Mass(REAL(I_Z_CN),REAL(I_A_CN-1)) + Lypair(I_Z_CN,
     *I_A_CN-1)) -(U_Mass(REAL(I_Z_CN),REAL(I_A_CN)) + Lypair(I_Z_CN,
     *I_A_CN)) 
      R_E_exc_GS = R_E_exc_used + SN 
      R_E_exc_Eb = R_E_exc_GS - BFTFB(REAL(I_Z_CN),REAL(I_A_CN),1) 
      End Select 
C     ' 
C     ' 
C     /' Fission barriers -> global parameters '/ 
C     ' 
      B_F = BFTF(REAL(I_Z_CN),REAL(I_A_CN),1) 
      B_F_ld = BFTF(REAL(I_Z_CN),REAL(I_A_CN),0) 
      E_B = BFTFB(REAL(I_Z_CN),REAL(I_A_CN),1) 
      E_B_ld = BFTFB(REAL(I_Z_CN),REAL(I_A_CN),0) 
C     ' 
C     ' 
C     /' Barriers and excitation energies of the fission modes '/ 
C     ' 
      E_exc_S0_prov = R_E_exc_Eb 
C     ' 
C     ' 
C     /' Additional influence of N=82 assumed '/ 
      Delta_NZ_Pol = 82.E0/50.E0 - REAL(I_N_CN)/REAL(I_Z_CN) 
      R_Shell_S1_eff = P_Shell_S1 * (1.E0 - P_Att_Pol * 
     *Abs(Delta_NZ_Pol)) 
C     ' 
C     ' 
C     /' In Pu,the Z=50 shell meets Z=44 in the light fragment. '/ 
C     /' A deformed shell at Z=44 is assumed to explain the enhancement        of the S1 channel around Pu '/ 
C     /' This very same shell automatically produces the double-humped '/ 
C     /' mass distribution in 180Hg '/ 
      S1_enhance = P_Shell_S4 + (REAL(I_Z_CN) - ZC_Mode_1 - 
     *ZC_Mode_4)**2 * P_Z_Curv_S4 
C     'Print "ZC_Mode_1,ZC_Mode_4",ZC_Mode_1,ZC_Mode_4 
C     'Print "Delta-Z S1-S4,S1_enhance",I_Z_CN-ZC_Mode_1 - ZC_Mode_4,S1_enhance 
      IF (  S1_enhance .GT. 0  )  S1_enhance = 0 
      R_Shell_S1_eff = R_Shell_S1_eff + S1_enhance 
C     ' 
C     /' The high TKE of S1 in 242Pu(sf) (and neighbours) is obtained by assuming '/ 
C     /' that the Z=44 shell reduces the deformation of the light fragment. '/ 
      DO I = 10 , I_Z_CN - 10 
      Z1 = I 
      A1 = (Z1 - 0.5E0) / REAL(I_Z_CN) * REAL(I_A_CN) 
C     /' polarization roughly considered '/ 
C     '      Beta(1,1,Z1) = Beta(1,1,Z1) + 0.15 * S1_enhance   /' "light" fragment '/ 
      Beta(1,1,I) = exp(S1_enhance) * Beta(1,1,I) + 
     *(1.E0-exp(S1_enhance)) * (Beta(1,1,I)-0.25) 
      Beta(1,1,I) = Max(Beta(1,1,I),0.0) 
      E_defo = Lymass(Z1,A1,Beta(1,1,I)) - Lymass(Z1,A1,0.0) 
      Edefo(1,1,I) = E_defo 
C     /' "light" fragment '/ 
      END DO 
C     ' 
C     ' Influence of S2 shell in complementary fragment 
C     ' May be called "S12 fission channel" 
      T_Asym_Mode_2 = 0.5 
      SigZ_Mode_2 = SQRT(0.5E0 * T_Asym_Mode_2/(P_Z_Curv_S2)) 
      SigA_Mode_2 = SigZ_Mode_2 * REAL(I_A_CN) / REAL(I_Z_CN) 
      S1_enhance = P_Shell_S2 * U_Box(REAL(P_A_CN) - AC_Mode_2 - 
     *AC_Mode_1,SigA_Mode_2,P_A_Width_S2) *P_A_Width_S2 
      IF (  S1_enhance .LT. 0.01  ) THEN 
      R_Shell_S1_eff = R_Shell_S1_eff + S1_enhance 
      End If 
C     ' Modify deformation of complementary fragment in corresponding analyzer 
C     ' 
C     ' Overlap of S2 and shell in light fragment 
      R_Shell_S2_eff = P_Shell_S2 
C     '   S2_enhance = P_Shell_S4 +  '             (Csng(I_Z_CN) - ZC_Mode_2 - ZC_Mode_4)^2 * P_Z_Curv_S4 
C     '   If S2_enhance > 0 Then S2_enhance = 0 
C     '   R_Shell_S2_eff = R_Shell_S2_eff + S2_enhance 
C     ' 
C     ' Overlap of S3 and shell in light fragment 
      R_Shell_S3_eff = P_Shell_S3 * (1.E0 - PZ_S3_olap_curv          * 
     *(REAL(I_Z_CN) - ZC_Mode_3 - PZ_S3_olap_pos)**2) 
C     '        * (Csng(I_Z_CN) - 60.5E0 - PZ_S3_olap_pos)^2) 
      R_Shell_S3_eff = Min(R_Shell_S3_eff,0.0) 
C     ' 
      R_Shell_S4_eff = P_Shell_S4 * 0.35 
C     ' 
      E_ld_S1 = R_A_Curv1_S0 * (REAL(I_A_CN)/REAL(I_Z_CN)*(ZC_MODE_1 - 
     *ZC_MODE_0) )**2 
      B_S1 = E_ld_S1 + R_Shell_S1_eff 
      E_exc_S1_prov = E_Exc_S0_prov - B_S1 
C     ' 
      E_ld_S2 = R_A_Curv1_S0 * (REAL(I_A_CN)/REAL(I_Z_CN)*(ZC_MODE_2 - 
     *ZC_MODE_0) )**2 
      B_S2 = E_ld_S2 + R_Shell_S2_eff 
      E_exc_S2_prov = E_Exc_S0_prov - B_S2 
C     ' 
      E_ld_S3 = R_A_Curv1_S0 * (REAL(I_A_CN)/REAL(I_Z_CN)*(ZC_MODE_3 - 
     *ZC_MODE_0) )**2 
      B_S3 = E_ld_S3 + R_Shell_S3_eff 
      E_exc_S3_prov = E_Exc_S0_prov - B_S3 
C     ' 
      IF (  I_A_CN .LT. 220  ) THEN 
C     ' Only here S4 is close enough to symmetry to have a chance 
      E_ld_S4 = R_A_Curv1_S0 * (REAL(I_A_CN)/REAL(I_Z_CN)*(ZC_MODE_4 - 
     *ZC_MODE_0) )**2 
      B_S4 = E_ld_S4 + R_Shell_S4_eff 
      E_exc_S4_prov = E_Exc_S0_prov - B_S4 
      Else 
      B_S4 = 9999 
      E_exc_S4_prov = - 9999 
      End If 
C     ' 
C     /' Mode 11 (overlap of channel 1 in light and heavy fragment '/ 
C     /' Potential depth with respect to liquid-drop potential: B_S11 '/ 
      B_S11 = 2.E0 * (R_Shell_S1_eff + De_Defo_S1              + 
     *P_Z_Curv_S1 * (ZC_Mode_1 - ZC_Mode_0)**2 ) - De_Defo_S1 
C     ' 
C     ' 
C     /' Lowering of effective barrier by lower ZPM due to larger width in 
C     partial overlap region (shells in light and heavy fragment) '/ 
      DES11ZPM = Level_S11 * Min(Abs(ZC_Mode_1 - ZC_Mode_0),
     *4.E0*P_Z_Curv_S1) 
C     ' Print B_S11,DES11ZPM,ZC_Mode_1-ZC_Mode_0 
C     ' 
      B_S11 = B_S11 + DES11ZPM 
C     ' 
C     '  If B_S11 > R_Shell_S1_eff + 0.5E0 Then 
C     '   If B_S11 > R_Shell_S1_eff + Level_S11 Then 
C     '     B_S11 = 100   ' S1 and S11 are exclusive 
C     '   Else 
C     '     B_S11 = Min(B_S11,R_Shell_S1_eff) 
C     '   End If 
C     ' 
C     ' 
      E_exc_S11_prov = E_Exc_S0_prov - B_S11 
C     ' 
C     /' Mode 22 (overlap of channel 2 in light and heavy fragment '/ 
C     /' Potential depth with respect to liquid-drop potential: B_S22 '/ 
C     ' 
C     '   B_S22 = 2.E0 * (E_ld_S2 + P_Shell_S2)  '       + 2.E0 * P_Z_Curv_S2 * (ZC_Mode_2 - ZC_Mode_0)^2   /' Parabola '/ 
C     'Print E_ld_S2,P_Shell_S2,P_Z_Curv_S2,ZC_Mode_2,ZC_Mode_0 
      B_S22 = 2.E0 * R_Shell_S2_eff * U_Box(REAL(P_A_CN)/2.0 - 
     *AC_Mode_2,SigA_Mode_2,P_A_Width_S2) * P_A_Width_S2 
C     ' The integral of U_Box is normalized,not the height! 
      IF (  Abs((P_A_CN/2.E0) - AC_Mode_2) .GT. P_A_Width_S2  )  B_S22 
     *= 9999 
C     ' 
      E_exc_S22_prov = E_Exc_S0_prov - B_S22 
C     ' 
C     ' 
      E_Min_Barr = Min(0.0,B_S1) 
      E_Min_Barr = Min(E_Min_Barr,B_S2) 
      E_Min_Barr = Min(E_Min_Barr,B_S3) 
      E_Min_Barr = Min(E_Min_Barr,B_S4) 
      E_Min_Barr = Min(E_Min_Barr,B_S11) 
      E_Min_Barr = Min(E_Min_Barr,B_S22) 
C     ' 
C     /' Energy minus the height of the respective fission saddle '/ 
      E_exc_S0 = E_exc_S0_prov + E_Min_Barr - Delta_S0 
      E_exc_S1 = E_exc_S1_prov + E_Min_Barr 
      E_exc_S2 = E_exc_S2_prov + E_Min_Barr 
      E_exc_S3 = E_exc_S3_prov + E_Min_Barr 
      E_exc_S4 = E_exc_S4_prov + E_Min_Barr 
      E_exc_S11 = E_exc_S11_prov + E_Min_Barr 
      E_exc_S22 = E_exc_S22_prov + E_Min_Barr 
C     ' 
C     /' Energy above the lowest fission saddle '/ 
      E_exc_Barr = Max(E_Exc_S0,E_Exc_S1) 
      E_exc_Barr = Max(E_exc_Barr,E_Exc_S2) 
      E_exc_Barr = Max(E_exc_Barr,E_Exc_S3) 
      E_exc_Barr = Max(E_exc_Barr,E_Exc_S4) 
      E_exc_Barr = Max(E_exc_Barr,E_exc_S11) 
      E_exc_Barr = Max(E_exc_Barr,E_exc_S22) 
C     ' 
C     ' 
C     ' 
C     /' Collective temperature used for calculating the widths 
C     in mass asymmetry and charge polarization '/ 
C     ' 
      IF (  E_Exc_S0 .LT. 0  ) THEN 
      E_tunn = -E_Exc_S0
      Else
      E_tunn = 0
      END IF
      R_E_exc_eff = Max(0.1,E_Exc_S0) 
C     '  T_Coll_Mode_0 = TFCOLL * R_E_exc_eff + _  /' empirical,replaced by TRusanov '/ 
      T_Coll_Mode_0 = TCOLLFRAC * (De_Saddle_Scission(REAL(I_Z_CN)**2 / 
     *           REAL(I_A_CN)**0.33333E0,ESHIFTSASCI_coll) - E_tunn) 
      T_Coll_Mode_0 = Max(T_Coll_Mode_0,0.0) 
C     ' 
C     ' Print "De_SS,E_tunn,T_Coll ";De_Saddle_Scission(I_Z_CN^2/I_A_CN^0.3333,ESHIFTSASCI_coll),E_tunn,T_Coll_Mode_0 
C     ' 
C     /' Temperature description fitting to the empirical systematics of Rusanov et al. '/ 
C     /' Here from Ye. N. Gruzintsev et al.,Z. Phys. A 323 (1986) 307 '/ 
C     /' Empirical description of the nuclear temperature according to the '/ 
C     /' Fermi-gas description. Should be valid at higher excitation energies '/ 
      T_Rusanov = TRusanov(R_E_exc_eff,REAL(I_A_CN)) 
C     '  Print "Temperatures,(GEF,Total,Rusanov): ",T_Coll_Mode_0,TFCOLL * R_E_exc_eff,T_Rusanov 
      T_Coll_Mode_0 = Max(T_Coll_Mode_0,T_Rusanov) 
C     /' Transition vom const. temp. to Fermi gas occurs around 20 MeV by MAX function '/ 
C     ' 
      T_Pol_Mode_0 = T_Pol_Red * T_Coll_Mode_0 
      T_Asym_Mode_0 = SQRT(T_Coll_Mode_0**2 + (6E0*TCOLLMIN)**2) 
C     ' 
      E_pot_scission = (De_Saddle_Scission(REAL(I_Z_CN)**2 /            
     *    REAL(I_A_CN)**0.33333E0,ESHIFTSASCI_intr) - E_tunn) 
C     ' 
C     /' Suppression of S1 fission channel due to reduced pairing in 132Sn '/ 
C     /' At very low excitation energy on the fission path,the binding energy at the 
C     S1 fission channel does not profit as much from pairing as SL and S2, 
C     because pairing is reduced in magic nuclei. This leads to a reduction of 
C     the yield in S1 in the case that the fully paired ground-state configuration 
C     is populated on the fission path with a considerable probability. '/ 
C     '   EeffS2 = Max(E_exc_S2,0.0) + EDISSFRAC * E_pot_scission - 2.3E0 
C     '   EeffS2 = Max(0.0,EeffS2) 
C     /' -2.3 MeV,because fission channels are assumed to be chosen before scission '/ 
C     ' 
C     '   If EeffS2 < ETHRESHSUPPS1 + 2.E0 * ESIGSUPPS1 Then 
C     '     E_exc_S1 = E_exc_S1 -  '        0.5E0 * 4.E0 * 12.E0 / Sqr(132.E0) * Gaussintegral(ETHRESHSUPPS1 - EeffS2,ESIGSUPPS1) 
C     '   EndIf 
C     ' 
      T_low_S1_used = T_low_S1 
C     ' 
      T_Coll_Mode_1 = TFCOLL * Max(E_exc_S1,0.E0) + TCOLLFRAC * 
     *(De_Saddle_Scission(I_Z_CN**2 / I_A_CN**0.33333E0,
     *ESHIFTSASCI_coll) - E_tunn) 
      T_Coll_Mode_1 = Max(T_Coll_mode_1,0.0) 
      T_Pol_Mode_1 = T_Pol_Red * T_Coll_Mode_1 
      T_Asym_Mode_1 = SQRT(T_Coll_Mode_1**2 + (4.0*TCOLLMIN)**2) 
C     ' TCOLLMIN for ZPM 
C     ' 
      T_Coll_Mode_2 = TFCOLL * Max(E_exc_S2,0.E0) + TCOLLFRAC * 
     *(De_Saddle_Scission(REAL(I_Z_CN)**2 /           
     *REAL(I_A_CN)**0.33333E0,ESHIFTSASCI_coll) - E_tunn) 
      T_Coll_Mode_2 = Max(T_Coll_mode_2,0.0) 
      T_Pol_Mode_2 = T_Pol_Red * T_Coll_Mode_2 
      T_Asym_Mode_2 = SQRT(T_Coll_Mode_2**2 + TCOLLMIN**2) 
C     ' 
      T_Coll_Mode_3 = TFCOLL * Max(E_exc_S3,0.E0) + TCOLLFRAC * 
     *(De_Saddle_Scission(REAL(I_Z_CN)**2 /             
     *REAL(I_A_CN)**0.33333E0,ESHIFTSASCI_coll) - E_tunn) 
      T_Coll_Mode_3 = Max(T_Coll_mode_3,0.0) 
      T_Pol_Mode_3 = T_Pol_Red * T_Coll_Mode_3 
      T_Asym_Mode_3 = SQRT(T_Coll_Mode_3**2 + TCOLLMIN**2) 
C     ' 
      T_Coll_Mode_4 = TFCOLL * Max(E_exc_S4,0.E0) + TCOLLFRAC * 
     *(De_Saddle_Scission(REAL(I_Z_CN)**2 /              
     *REAL(I_A_CN)**0.33333E0,ESHIFTSASCI_coll) - E_tunn) 
      T_Coll_Mode_4 = Max(T_Coll_mode_4,0.0) 
      T_Pol_Mode_4 = T_Pol_Red * T_Coll_Mode_4 
      T_Asym_Mode_4 = SQRT(T_Coll_Mode_4**2 + TCOLLMIN**2) 
C     ' 
C     /' Stiffness in polarization '/ 
C     ' 
      RZ = REAL(I_Z_CN) * 0.5E0 
      RA = REAL(I_A_CN) * 0.5E0 
      beta1 = Beta(0,1,NINT(RZ)) 
      beta2 = Beta(0,2,NINT(RZ)) 
      R_Pol_Curv_S0 = ( LyMass( RZ - 1.E0,RA,beta1 ) +              
     *LyMass( RZ + 1.0E0,RA,beta2 ) +              LyMass( RZ + 1.0E0,
     *RA,beta1 ) +              LyMass( RZ - 1.0E0,RA,beta2 ) +         
     *     ecoul( RZ - 1.0E0,RA,beta1,RZ + 1.0E0,RA,beta2,dneck) +      
     *        ecoul( RZ + 1.0E0,RA,beta1,RZ - 1.0E0,RA,beta2,dneck) -   
     *       2.0E0*ecoul( RZ,RA,beta1,RZ,RA,beta2,dneck) -          
     *2.0E0*LyMass( RZ,RA,beta1 ) -          2.0E0*LyMass( RZ,RA,beta2) 
     *) * 0.5E0 
C     ' 
      P_Pol_Curv_S0 = R_Pol_Curv_S0 
C     ' 
      R_Pol_Curv_S1 = R_Pol_Curv_S0 
      R_Pol_Curv_S2 = R_Pol_Curv_S0 
      R_Pol_Curv_S3 = R_Pol_Curv_S0 
      R_Pol_Curv_S4 = R_Pol_Curv_S0 
C     ' 
C     ' 
C     ' 
C     /' Mean values and standard deviations of fission modes '/ 
C     ' 
      SIGZ_Mode_0 = SQRT(0.5E0 * T_Asym_Mode_0/R_Z_Curv_S0) 
      IF (  T_Pol_Mode_0 .GT. 1.E-2  ) THEN 
      SigPol_Mode_0 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S0 /            
     *          Tanh(HOMPOL/(2.E0 * T_Pol_Mode_0))) 
      Else 
      SigPol_Mode_0 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S0) 
C     /' including influence of zero-point motion '/ 
      END IF 
C     ' 
C     ' 
      R_E_intr_S1 = Max(E_Exc_S1+Lypair(I_Z_CN,I_A_CN),0.0) 
      R_Att(1) = exp(-R_E_intr_S1/Shell_fading) 
      R_Att(5) = R_Att(1) 
      R_Att_Sad(1) = exp(-R_E_intr_S1/Shell_fading) 
      R_Att_Sad(5) = R_Att_Sad(1) 
      SIGZ_Mode_1 = SQRT(0.5E0 * 
     *T_Asym_Mode_1/(P_Z_Curv_S1*SQRT(R_Att(1)))) 
      IF (  T_Pol_Mode_1 .GT. 1.E-2  ) THEN 
      SigPol_Mode_1 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S1 /            
     *          Tanh(HOMPOL/(2.E0 * T_Pol_Mode_1))) 
      Else 
      SigPol_Mode_1 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S1) 
      END IF 
C     ' 
      R_E_intr_S2 = Max(E_Exc_S2+Lypair(I_Z_CN,I_A_CN),0.0) 
      R_Att(2) = exp(-R_E_intr_S2/Shell_fading) 
      R_Att(6) = R_Att(2) 
      R_Att_Sad(2) = exp(-R_E_intr_S2/Shell_fading) 
      R_Att_Sad(6) = R_Att_Sad(2) 
      SIGZ_Mode_2 = SQRT(0.5E0 * 
     *T_Asym_Mode_2/(P_Z_Curv_S2*SQRT(R_Att(2)))) 
      IF (  T_Pol_Mode_2 .GT. 1.E-2  ) THEN 
      SigPol_Mode_2 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S2 /            
     *          Tanh(HOMPOL/(2.E0 * T_Pol_Mode_2))) 
      Else 
      SigPol_Mode_2 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S2) 
      End If 
C     ' 
      R_E_intr_S3 = Max(E_exc_S3+Lypair(I_Z_CN,I_A_CN),0.0) 
      R_Att(3) = exp(-R_E_intr_S3/Shell_fading) 
      R_Att_Sad(3) = exp(-R_E_intr_S3/Shell_fading) 
      SIGZ_Mode_3 = SQRT(0.5E0 * 
     *T_Asym_Mode_3/(P_Z_Curv_S3*SQRT(R_Att(3)))) 
      IF (  T_Pol_Mode_3 .GT. 1.E-2  ) THEN 
      SigPol_Mode_3 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S3 /            
     *          Tanh(HOMPOL/(2.E0 * T_Pol_Mode_3))) 
      Else 
      SigPol_Mode_3 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S3) 
      End if 
C     ' 
      R_E_intr_S4 = Max(E_exc_S4+Lypair(I_Z_CN,I_A_CN),0.0) 
      R_Att(4) = exp(-R_E_intr_S4/Shell_fading) 
      R_Att_Sad(4) = exp(-R_E_intr_S4/Shell_fading) 
      SIGZ_Mode_4 = SQRT(0.5E0 * 
     *T_Asym_Mode_4/(P_Z_Curv_S4*SQRT(R_Att(4)))) 
      IF (  T_Pol_Mode_4 .GT. 1.E-2  ) THEN 
      SigPol_Mode_4 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S4 /            
     *          Tanh(HOMPOL/(2.E0 * T_Pol_Mode_4))) 
      Else 
      SigPol_Mode_4 = SQRT(0.25E0 * HOMPOL / R_Pol_Curv_S4) 
      End if 
C     ' 
C     ' 
C     ' 
C     /' Energy-dependent shift of fission channels '/ 
C     '    Scope 
      P_Z_Curv_S1_eff = P_Z_Curv_S1 * P_Z_Curvmod_S1 
      P_Z_Curv_S2_eff = P_Z_Curv_S2 * P_Z_Curvmod_S2 
C     ' 
      DZ_S1 = ZC_Mode_1 * (P_Z_Curv_S1_eff*R_Att(1) / (R_Z_Curv_S0 + 
     *P_Z_Curv_S1_eff*R_Att(1))             - (P_Z_Curv_S1_eff / 
     *(R_Z_Curv_S0 + P_Z_Curv_S1_eff) ) ) 
      DZ_S2 = ZC_Mode_2 * (P_Z_Curv_S2_eff*R_Att(2) / (R_Z_Curv_S0 + 
     *P_Z_Curv_S2_eff*R_Att(2))              - (P_Z_Curv_S2_eff / 
     *(R_Z_Curv_S0 + P_Z_Curv_S2_eff) ) ) 
      DZ_S3 = ZC_Mode_3 * (P_Z_Curv_S3*R_Att(3) / (R_Z_Curv_S0 + 
     *P_Z_Curv_S3*R_Att(3))              - (P_Z_Curv_S3 / (R_Z_Curv_S0 
     *+ P_Z_Curv_S3) ) ) 
      DZ_S4 = ZC_Mode_4 * (P_Z_Curv_S4*R_Att(4) / (R_Z_Curv_S0 + 
     *P_Z_Curv_S4*R_Att(4))              - (P_Z_Curv_S4 / (R_Z_Curv_S0 
     *+ P_Z_Curv_S4) ) ) 
C     ' 
C     ' 
C     ' Empirical shift of S2 channel at low excitation energy at scission 
C     ' for better reproduction of 238U(s,f) and some data for Th isotopes. 
C     ' Does not solve the problem of 229Th(nth,f). 
      EtotS2 = Max(E_Exc_S2 + EDISSFRAC * E_pot_scission,0.0) 
      IF (  EtotS2 .LT. 5.E0  ) THEN 
      DZ_S2 = DZ_S2 + (5.E0 - EtotS2) * 0.1 
      End If 
C     ' 
C     '   DZ_S1 = 0 
C     '   DZ_S2 = 0 
C     '   DZ_S3 = 0 
C     '   DZ_S4 = 0 
C     ' 
C     ' 
      P_Z_Mean_S0 = ZC_Mode_0 
      ZC_Mode_1 = ZC_Mode_1 + DZ_S1 
      P_Z_Mean_S1 = ZC_Mode_1 
C     /' Copy to global parameter '/ 
      ZC_Mode_2 = ZC_Mode_2 + DZ_S2 
      P_Z_Mean_S2 = ZC_Mode_2 
C     /'             "            '/ 
      ZC_Mode_3 = ZC_Mode_3 + DZ_S3 
      P_Z_Mean_S3 = ZC_Mode_3 
      ZC_Mode_4 = ZC_Mode_4 + DZ_S4 
      P_Z_Mean_S4 = ZC_Mode_4 
C     '    End Scope 
C     ' 
C     ' 
C     /' Energy dependence of charge polarization '/ 
C     /' Due to washing out of shells '/ 
C     ' 
      DO I = 10 , I_A_CN - 10 
C     ' mass number 
      DO J = 1 , 4 
C     ' fission channel 
      DO K = 1 , 2 
C     ' light - heavy group 
      Zshift(J,K,I) = Zshift(0,K,I) + (Zshift(J,K,I) - Zshift(0,K,
     *I))*R_Att(J) 
      END DO 
      END DO 
      END DO 
C     ' 
C     ' 
C     /' Energy dependence of shell-induced deformation '/ 
C     /' Due to washing out of shells '/ 
C     /' (Under development) '/ 
C     /'For I = 10 To I_Z_CN - 10  ' mass number 
C     For J = 1 To 4           ' fission channel 
C     For K = 1 To 2         ' light - heavy group 
C     beta(J,K,I) = beta(0,K,I) + (beta(J,K,I) - beta(0,K,I))*R_Att_Sad(J) 
C     if beta(J,K,I) < 0 Then 
C     beta(J,K,I) = 0 
C     End If 
C     Z1 = I 
C     Z2 = I_Z_CN - Z1 
C     A1 = Z1 / Csng(I_Z_CN) * Csng(I_A_CN) 
C     A2 = I_A_CN - A1 
C     E_defo = Lymass(Z1,A1,beta(J,K,I)) - Lymass(Z1,A1,0.0) 
C     Edefo(J,K,I) = E_defo 
C     Next 
C     Next 
C     Next  '/ 
C     ' 
C     ' 
C     ' 
C     ' 
C     /' General relations between Z and A of fission channels '/ 
C     /' 2nd iteration '/ 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_0 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(0,2,NINT(RA)) 
      END DO 
      AC_Mode_0 = (ZC_Mode_0 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
C     /' mean position in mass '/ 
      NC_Mode_0 = AC_Mode_0 - ZC_Mode_0 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_1 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(1,2,NINT(RA)) 
      END DO 
      AC_Mode_1 = (ZC_Mode_1 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      NC_Mode_1 = AC_Mode_1 - ZC_Mode_1 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_2 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(2,2,NINT(RA)) 
      END DO 
      AC_Mode_2 = (ZC_Mode_2 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      NC_Mode_2 = AC_Mode_2 - ZC_Mode_2 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_3 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(3,2,NINT(RA)) 
      END DO 
      AC_Mode_3 = (ZC_Mode_3 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      NC_Mode_3 = AC_Mode_3 - ZC_Mode_3 
C     ' 
      RZpol = 0 
      DO I = 1 , 3 
      RA = (ZC_Mode_4 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      RZpol = Zshift(4,2,NINT(RA)) 
      END DO 
      AC_Mode_4 = (ZC_Mode_4 - RZPol) * REAL(I_A_CN) / REAL(I_Z_CN) 
      NC_Mode_4 = AC_Mode_4 - ZC_Mode_4 
C     ' 
C     ' 
C     ' 
C     /' Yields of the fission modes '/ 
C     ' 
      Yield_Mode_0 = Getyield(E_exc_S0,E_exc_S0,T_low_SL,
     *TEgidy(REAL(I_A_CN),0.E0,Tscale)) 
      Yield_Mode_0 = Max(Yield_Mode_0,0.0) 
C     ' 
      Yield_Mode_1 = Getyield(E_exc_S1,E_exc_S0,T_low_S1_used,
     *TEgidy(REAL(I_A_CN),R_Shell_S1_eff + dE_Defo_S1,Tscale)) 
C     /'  - Getyield(E_exc_S0 - E_ld_S1,T_low,T_high); '/ 
      Yield_Mode_1 = Max(Yield_Mode_1,0.0) 
C     ' 
      Yield_Mode_2 = Getyield(E_exc_S2,E_exc_S0,T_low_S2,
     *TEgidy(REAL(I_A_CN),R_Shell_S2_eff + dE_Defo_S2,Tscale)) 
C     /'  - Getyield(E_exc_S0 - E_ld_S2,T_low,T_high); '/ 
      Yield_Mode_2 = Max(Yield_Mode_2,0.0) 
C     ' 
      Yield_Mode_3 = Getyield(E_exc_S3,E_exc_S0,T_low_S3,
     *TEgidy(REAL(I_A_CN),R_Shell_S3_eff + dE_Defo_S3,Tscale)) 
C     /'  - Getyield(E_exc_S0 - E_ld_S3,T_low,T_high); '/ 
      Yield_Mode_3 = Max(Yield_Mode_3,0.0) 
C     ' 
      Yield_Mode_4 = Getyield(E_exc_S4,E_exc_S0,T_low_S4,
     *TEgidy(REAL(I_A_CN),R_Shell_S4_eff + dE_Defo_S4,Tscale)) - 
     *Yield_Mode_0 
C     '   - Getyield(E_exc_S0 - E_ld_S4,T_low,T_high) 
      Yield_Mode_4 = Max(Yield_Mode_4,0.0) 
C     ' 
C     'Print TEgidy(Csng(I_A_CN),0.E0,Tscale),TEgidy(Csng(I_A_CN),R_Shell_S2_eff + dE_Defo_S2,Tscale),de_Defo_S2 
C     'sleep 
C     ' 
      IF (  B_S11 .GT. B_S1  ) THEN 
      Yield_Mode_11 = 0.0 
      Else 
      Yield_Mode_11 = Getyield(E_exc_S11,E_exc_S0,T_low_S11,
     *TEgidy(REAL(I_A_CN),R_Shell_S1_eff + 2.E0 * dE_Defo_S1,Tscale)) 
      End If 
C     ' 
      IF (  B_S22 .GT. B_S2  ) THEN 
      Yield_Mode_22 = 0.0 
      Else 
      Yield_Mode_22 = Getyield(E_exc_S22,E_exc_S0,T_low_S2,
     *TEgidy(REAL(I_A_CN),R_Shell_S2_eff,Tscale)) 
      End If 
C     ' 
C     ' 
      Yield_Norm = Yield_Mode_0 + Yield_Mode_1 + Yield_Mode_2 + 
     *Yield_Mode_3 + Yield_Mode_4 + Yield_Mode_11 + Yield_Mode_22 
      Yield_Mode_0 = Yield_Mode_0 / Yield_Norm 
      Yield_Mode_1 = Yield_Mode_1 / Yield_Norm 
      Yield_Mode_2 = Yield_Mode_2 / Yield_Norm 
      Yield_Mode_3 = Yield_Mode_3 / Yield_Norm 
      Yield_Mode_4 = Yield_Mode_4 / Yield_Norm 
      Yield_Mode_11 = Yield_Mode_11 / Yield_Norm 
      Yield_Mode_22 = Yield_Mode_22 / Yield_Norm 
C     ' 
C     ' 
C     /' Mass widhts of the fission channels '/ 
C     ' 
      SigA_Mode_0 = SigZ_Mode_0 * REAL(I_A_CN) / REAL(I_Z_CN) 
C     /' width in mass '/ 
      SigA_Mode_1 = SigZ_Mode_1 * REAL(I_A_CN) / REAL(I_Z_CN) 
      SigA_Mode_1 = Min(SigA_Mode_1,SigA_Mode_0) 
C     ' not broader than liquid-drop 
      SigA_Mode_2 = SigZ_Mode_2 * REAL(I_A_CN) / REAL(I_Z_CN) 
      SigA_Mode_2 = Min(SigA_Mode_2,SigA_Mode_0) 
C     ' not broader than liquid-drop 
      SigA_Mode_3 = SigZ_Mode_3 * REAL(I_A_CN) / REAL(I_Z_CN) 
      SigA_Mode_3 = Min(SigA_Mode_3,SigA_Mode_0) 
      SigA_Mode_4 = SigZ_mode_4 * REAL(I_A_CN) / REAL(I_Z_CN) 
      SigA_Mode_4 = Min(SigA_Mode_4,SigA_Mode_0) 
      SigA_Mode_11 = SigZ_Mode_1 * SQRT(2.E0) * REAL(I_A_CN) / 
     *REAL(I_Z_CN) 
      SigA_Mode_11 = Min(SigA_Mode_11,SigA_Mode_0) 
      SigA_Mode_22 = SigZ_Mode_2 * SQRT(2.E0) * REAL(I_A_CN) / 
     *REAL(I_Z_CN) 
      SigA_Mode_22 = Min(SigA_Mode_22,SigA_Mode_0) 
C     ' 
C     ' 
C     ' 
C     /' Shell effects of different fission channels '/ 
C     /' This is the "real" microscopic shell effect,not the effective shell-correction energy '/ 
C     /' EShell acts on the level density and determines the T parameter '/ 
C     ' 
      DO I = 1 , I_A_CN - 1 
      DO J = 0 , 4 
      EShell(J,1,I) = 0 
C     /' Shells in "light" fragment assumed to be zero '/ 
      END DO 
      DU0 = 0 
      EShell(0,2,I) = 0 
C     /' Shell = 0 in symmetric mode '/ 
      DU1 = R_Shell_S1_eff + dE_Defo_S1 
C     /' + R_A_Curv1_S1 * (AC_Mode_1 - Float(I,6))**2; '/ 
      DU1 = MIN(DU1,0.E0) 
C     /' Technical limit '/ 
      EShell(1,2,I) = DU1 
C     ' 
      DU2 = R_Shell_S2_eff + dE_Defo_S2 
C     /' + R_A_Curv1_S2 * (AC_Mode_2 - Float(I,6))**2; '/ 
      DU2 = Min(DU2,0.E0) 
C     /' Technical limit '/ 
      EShell(2,2,I) = DU2 
C     ' 
      DU3 = R_Shell_S3_eff + dE_Defo_S3 
C     /' + R_A_Curv1_S3 * (AC_Mode_3 - Float(I,6))**2; '/ 
      DU3 = Min(DU3,0.E0) 
C     /' Technical limit '/ 
      EShell(3,2,I) = DU3 
C     ' 
      DU4 = R_Shell_S4_eff + dE_Defo_S4 
C     /' + R_A_Curv1_S4 * (AC_Mode_4 - Float(I,6))**2; '/ 
      DU4 = Min(DU4,0.E0) 
C     /' Technical limit '/ 
      EShell(4,2,I) = DU4 
C     ' 
      END DO 
C     ' 
C     ' 
C     /' Intrinsic temperatures of fragments at scission '/ 
C     ' 
C     /' Mean values '/ 
      T_intr_Mode_0 = TEgidy(AC_Mode_0,0.0,0.8) 
      T_intr_Mode_1_heavy = TEgidy(AC_Mode_1,R_Shell_S1_eff + 
     *dE_Defo_S1,Tscale) 
      T_intr_Mode_1_light = TEgidy(REAL(I_A_CN) - AC_Mode_1,0.0,Tscale) 
      T_intr_Mode_2_heavy = TEgidy(AC_Mode_2,R_Shell_S2_eff + 
     *dE_Defo_S2,Tscale) 
      T_intr_Mode_2_light = TEgidy(REAL(I_A_CN) - AC_Mode_2,0.0,Tscale) 
      T_intr_Mode_3_heavy = TEgidy(AC_Mode_3,R_Shell_S3_eff + 
     *dE_Defo_S3,Tscale) 
      T_intr_Mode_3_light = TEgidy(REAL(I_A_CN) - AC_Mode_3,0.0,Tscale) 
      T_intr_Mode_4_heavy = TEgidy(AC_Mode_4,R_Shell_S4_eff + 
     *dE_Defo_S4,Tscale) 
      T_intr_Mode_4_light = TEgidy(REAL(I_A_CN) - AC_Mode_4,0.0,Tscale) 
C     ' 
C     ' 
C     /' Mass-dependent values of individual fragments '/ 
C     /' Mode 0 '/ 
      DO I = 1 , I_A_CN - 1 
      T = TEgidy(REAL(I),EShell(0,1,I),Tscale) 
      Temp(0,1,I) = T 
C     /' "light" fragment at freeze-out (somewhere before scission) '/ 
      T = TEgidy(REAL(I),EShell(0,2,I),Tscale) 
      Temp(0,2,I) = T 
C     /' "heavy" fragment at freeze-out (somewhere before scission) '/ 
C     ' 
      T = TEgidy(REAL(I),0.0,1.0) 
      TempFF(0,1,I) = T 
C     ' FF in their ground state 
      TempFF(0,2,I) = T 
C     ' FF in their ground state 
      END DO 
C     ' 
C     /' Mode 1 '/ 
      DO I = 1 , I_A_CN - 1 
      T = TEgidy(REAL(I),EShell(1,1,I),Tscale) 
      Temp(1,1,I) = T 
C     /' "light" fragment '/ 
      T = TEgidy(REAL(I),EShell(1,2,I),Tscale) 
      Temp(1,2,I) = T 
C     /' "heavy" fragment '/ 
C     ' 
      T = TEgidy(REAL(I),0.0,1.0) 
      TempFF(1,1,I) = T 
C     ' FF in their ground state 
      TempFF(1,2,I) = T 
C     ' FF in their ground state 
      END DO 
C     ' 
C     /' Mode 2 '/ 
      DO I = 1 , I_A_CN - 1 
      T = TEgidy(REAL(I),EShell(2,1,I),Tscale) 
      Temp(2,1,I) = T 
C     /' "light" fragment '/ 
      T = TEgidy(REAL(I),EShell(2,2,I),Tscale) 
      Temp(2,2,I) = T 
C     /' "heavy" fragment '/ 
C     ' 
C     /' The next section is introduced,because energy sorting is not strong enough, 
C     when shells are only introduced in the heavy fragment. 
C     Ad hoc assumption: For Mode 2 there are shells in both fragments of about 
C     equal size. Technically,we neglect the shells in both fragments. 
C     This has about the same effect for the energy sorting. '/ 
      T = TEgidy(REAL(I),0.0,Tscale) 
C     ' FF at scssion 
      Temp(2,1,I) = T 
C     /' "light" fragment '/ 
      T = TEgidy(REAL(I),0.0,Tscale) 
C     ' FF at scission 
      Temp(2,2,I) = T 
C     /' "heavy" fragment '/ 
C     ' 
      T = TEgidy(REAL(I),0.0,1.0) 
C     ' shell effect neglected 
      TempFF(2,1,I) = T 
C     ' FFs in their ground state 
      TempFF(2,2,I) = T 
C     ' FFs in their ground state 
      END DO 
C     ' 
C     /' Mode 3 '/ 
      DO I = 1 , I_A_CN -1 
      T = TEgidy(REAL(I),0.0,Tscale) 
      Temp(3,1,I) = T 
      T = TEgidy(REAL(I),0.0,Tscale) 
      Temp(3,2,I) = T 
C     ' 
      T = TEgidy(REAL(I),0.0,1.0) 
      TempFF(3,1,I) = T 
C     ' FF in their ground state 
      TempFF(3,2,I) = T 
C     ' FF in their ground state 
      END DO 
C     ' 
C     /' Mode 4 '/ 
      DO I = 1 , I_A_CN -1 
      T = TEgidy(REAL(I),0.0,Tscale) 
      Temp(4,1,I) = T 
      T = TEgidy(REAL(I),0.0,Tscale) 
      Temp(4,2,I) = T 
C     ' 
      T = TEgidy(REAL(I),0.0,1.0) 
      TempFF(4,1,I) = T 
C     ' FF in their ground state 
      TempFF(4,2,I) = T 
C     ' FF in their ground state 
      END DO 
C     ' 
C     ' 
C     /'** Intrinsic excitation energy at saddle and at scission as well as   **'/ 
C     /'** Even-odd effect in proton and neutron number for each fission mode **'/ 
      DO I_Mode = 0 , 6 
      E_coll_saddle(I_Mode) = 0 
      IF (  I_Mode .EQ. 0  )  Etot = E_exc_S0 
      IF (  I_Mode .EQ. 1  )  Etot = E_exc_S1 
      IF (  I_Mode .EQ. 2  )  Etot = E_exc_S2 
      IF (  I_Mode .EQ. 3  )  Etot = E_exc_S3 
      IF (  I_Mode .EQ. 4  )  Etot = E_exc_S4 
      IF (  I_Mode .EQ. 5  )  Etot = E_exc_S11 
      IF (  I_Mode .EQ. 6  )  Etot = E_exc_S22 
C     ' 
C     '  If I_Z_CN Mod 2 + I_N_CN Mod 2 = 0 Then  /' Even-even CN '/ 
C     '    If Etot > 0 And Etot < 2.E0 * 12.E0/Sqr(Csng(I_A_CN)) Then 
C     '     E_coll_saddle(I_Mode) = Etot  ' ->  Instead it may go into pre-scission kinetic energy! 
C     '      Etot = 0 
C     /' Excitation below the pairing gap in even-even CN goes into pre-scission kinetic energy '/ 
C     '    End If 
C     '    Etot = Etot - 2.E0 * 12.E0 / sqr(Csng(I_A_CN)) 
C     ' No intrinsic levels below the pairing gap: higher effective barrier 
C     '  End If 
      IF (   MOD(I_Z_CN,2)  +  MOD(I_N_CN,2)  .EQ. 0  ) THEN 
      Ediff = Min(Etot,14.0/SQRT(REAL(I_A_CN))) 
      End If 
      IF (   MOD(I_Z_CN,2)  +  MOD(I_N_CN,2)  .EQ. 1  ) THEN 
      Ediff = Min(Etot,2.0 * 14.0/SQRT(REAL(I_A_CN))) 
      End If 
      Ediff = Max(Ediff,0.0) 
      Etot = Etot - Ediff 
C     ' 
C     ' 
      IF (  Etot .LT. 0  ) THEN 
      E_tunn = -Etot
      Else
      E_tunn = 0
      END IF
      Etot = Max(Etot,0.0) 
C     ' 
      E_pot_scission = (De_Saddle_Scission(REAL(I_Z_CN)**2 /            
     *    REAL(I_A_CN)**0.33333E0,ESHIFTSASCI_intr) ) 
      Etot = Etot + EDISSFRAC * (E_pot_scission - E_tunn) 
C     /' All excitation energy at saddle and part of the potential-energy gain to scission 
C     go into intrinsic excitation energy at scission '/ 
C     ' 
C     ' 
C     ' 
      IF (  I_Mode .EQ. 2  ) THEN 
      EINTR_SCISSION = Etot 
C     /' (For Mode 2) Global parameter '/ 
      End If 
C     ' 
      DO IA1 = 40 , I_A_CN - 40 
C     ' 
      IA2 = I_A_CN - IA1 
      IF (  I_Mode .LE. 4  ) THEN 
      T1 = Temp(I_Mode,1,IA1) 
      T2 = Temp(I_Mode,2,IA2) 
      End If 
      IF (  I_Mode .EQ. 5  ) THEN 
      T1 = Temp(1,2,IA1) 
      T2 = Temp(1,2,IA2) 
      End If 
      IF (  I_Mode .EQ. 6  ) THEN 
      T1 = Temp(2,2,IA1) 
      T2 = Temp(2,2,IA2) 
      End If 
      DT = ABS(T2 - T1) 
C     ' 
C     /' Even-odd effect '/ 
      IF (   MOD(I_Z_CN,2)  .EQ. 0  ) THEN 
      Rincr1P = Exp(-Etot/PZ_EO_symm) 
      Else 
      Rincr1P = 0 
      End If 
      IF (   MOD(I_N_CN,2)  .EQ. 0  ) THEN 
      Rincr1N = Exp(-Etot/PN_EO_symm) 
      Else 
      Rincr1N = 0 
      End If 
      PEOZ(I_Mode,1,IA1) = Rincr1P 
      PEOZ(I_Mode,2,IA2) = Rincr1P 
      PEON(I_Mode,1,IA1) = Rincr1N 
      PEON(I_Mode,2,IA2) = Rincr1N 
C     ' 
      Rincr2 = Gaussintegral(DT/Etot-R_EO_Thresh,
     *R_EO_Sigma*(DT+0.0001)) 
C     /' even-odd effect due to asymmetry '/ 
      Rincr2P = (R_EO_MAX - Rincr1P) * Rincr2 
      Rincr2N = (R_EO_MAX - Rincr1N) * Rincr2 
C     ' 
      IF (  IA1 .LT. IA2  ) THEN 
C     ' A1 is lighter 
      PEOZ(I_Mode,1,IA1) = PEOZ(I_Mode,1,IA1) + Rincr2P 
      IF (   MOD(I_Z_CN,2)  .EQ. 0  ) THEN 
      PEOZ(I_Mode,2,IA2) = PEOZ(I_Mode,2,IA2) + Rincr2P 
      Else 
      PEOZ(I_Mode,2,IA2) = PEOZ(I_Mode,2,IA2) - Rincr2P 
      End if 
      PEON(I_Mode,1,IA1) = PEON(I_Mode,1,IA1) + Rincr2N 
      IF (   MOD(I_N_CN,2)  .EQ. 0  ) THEN 
      PEON(I_Mode,2,IA2) = PEON(I_Mode,2,IA2) + Rincr2N 
      Else 
      PEON(I_Mode,2,IA2) = PEON(I_Mode,2,IA2) - Rincr2N 
      End if 
      Else 
      PEOZ(I_Mode,1,IA1) = PEOZ(I_Mode,2,IA1) 
      PEON(I_Mode,1,IA1) = PEON(I_Mode,2,IA1) 
      PEOZ(I_Mode,2,IA2) = PEOZ(I_Mode,1,IA2) 
      PEON(I_Mode,2,IA2) = PEON(I_Mode,1,IA2) 
      End If 
C     ' 
C     ' 
C     /'  Else 
C     PEOZ(I_Mode,2,IA2) =                PEOZ(I_Mode,1,IA2) + Rincr2P 
C     IF I_Z_CN Mod 2 = 0 Then 
C     PEOZ(I_Mode,1,IA1) =                 PEOZ(I_Mode,1,IA1) + Rincr2P 
C     Else 
C     PEOZ(I_Mode,1,IA1) =                 PEOZ(I_Mode,1,IA1) - Rincr2P 
C     End if 
C     PEON(I_Mode,2,IA2) =              PEON(I_Mode,2,IA2) + Rincr2N 
C     IF I_N_CN Mod 1 = 0 Then 
C     PEON(I_Mode,1,IA1) =                 PEON(I_Mode,1,IA1) + Rincr2N 
C     Else 
C     PEON(I_Mode,1,IA1) =                 PEON(I_Mode,1,IA1) - Rincr2N 
C     End if 
C     End If  '/ 
C     ' 
      PEOZ(I_Mode,1,IA1) = PEOZ(I_Mode,1,IA1) * EOscale 
      PEOZ(I_Mode,2,IA2) = PEOZ(I_Mode,2,IA2) * EOscale 
      PEON(I_Mode,1,IA1) = PEON(I_Mode,1,IA1) * EOscale 
      PEON(I_Mode,2,IA2) = PEON(I_Mode,2,IA2) * EOscale 
C     ' 
C     /' Energy sorting '/ 
C     /' E1 = Etot * Gaussintegral(T2-T1,0.03); '/ 
      IF (  Abs(T1-T2) .LT. 1.E-6  ) THEN 
      E1 = 0.5E0 * Etot 
      Else 
      E1ES = Csort * T1 * T2 / ( Abs(T1 - T2) ) 
      E1ES = Min(E1ES,0.5E0*Etot) 
C     /' Asymptotic value after "complete" energy sorting '/ 
      E1FG = Etot * IA1 / I_A_CN 
C     /' in Fermi-gas regime '/ 
      IF (  Etot .LT. 13  )  E1 = E1ES 
C     ' complete energy sorting 
      IF (  Etot .GE. 13 .AND. Etot .LE. 20  ) THEN 
C     ' transition region 
      E1 = E1ES + (Etot-13)/7*(E1FG-E1ES) 
      End If 
      IF (  Etot .GT. 20  )  E1 = E1FG 
C     ' Fermi-gas regime 
      End If 
      E2 = Etot - E1 
      EPART(I_Mode,1,IA1) = E1 
C     /' Mean E* in light fragment '/ 
      EPART(I_Mode,2,IA2) = E2 
C     /' Mean E* in heavy fragment '/ 
      END DO 
      END DO 
C     ' 
C     ' 
C     /'** RMS angular momentum of fission fragments **'/ 
C     /' Following Naik et al.,EPJ A 31 (2007) 195 and  '/ 
C     /' S. G. Kadmensky,Phys. At. Nucl. 71 (2008) 1193 '/ 
C     ' 
C     '   Scope 
      ZT = P_Z_CN 
C     '  AT = I_A_CN 
      AT = P_A_CN 
      IF (  Emode .EQ. 2  )  AT = AT -1 
      Spin_CN = P_J_CN 
C     '   Print "ZT,AT,I_MAT",ZT,AT,I_MAT 
C     '   Print "SPIN_CN",Spin_CN 
C     '   Sleep 
C     ' 
      DO IZ1 = 10 , I_Z_CN - 10 
      AUCD = Int(REAL(IZ1) * REAL(I_A_CN) / REAL(I_Z_CN)) 
      DO IA1 = Int(AUCD - 15) , Int(AUCD + 15) 
      IF (  IA1 - IZ1 .GE. 10  ) THEN 
C     /' Rigid momentum of inertia for spherical nucleus '/ 
      I_rigid_spher = 1.16E0**2 * REAL(IA1)**1.6667E0 / 103.8415E0 
C     /' unit: hbar^2/MeV '/ 
      DO I_Mode = 0 , 6 
C     ' 
C     /' First (normally light) fission fragment: '/ 
C     ' 
      beta1 = Beta(I_Mode,1,IZ1) 
      alph = beta1 / SQRT(4.E0 * pi / 5.E0) 
      I_rigid = I_rigid_spher * (1.E0 + 0.5E0*alph + 9.E0/7.E0*alph**2) 
C     /' From Hasse & Myers,Geometrical Relationships ... '/ 
      E_exc = EPART(I_Mode,1,IA1) 
      IF (  E_exc .LT. 0  )  E_exc = 0 
      T = U_Temp(REAL(IZ1),REAL(IA1),E_exc,1,1,Tscale,Econd) 
      T = SQRT(T**2 + 0.8**2) 
C     ' For ZPM 
      I_eff = I_rigid * (1.E0 - 0.8E0 * exp(-0.693E0 * E_exc / 5.E0)) 
      J_rms = SQRT(2.E0 * I_eff * T) 
C     ' 
C     /' Influence of CN spin '/ 
      J_rms = SQRT(J_rms**2 + Spin_CN**2) 
C     ' 
C     /' Incoming neutron (spin + orbital) '/ 
      IF (  Emode .EQ. 2  ) THEN 
C     ' 2/3 * 1.16 * sqrt(2 * 939.65) / 197.33 = 0.1699 
      J_rms = SQRT(J_rms**2 + 0.5**2 +                   (0.1699 * 
     *AT**0.333333 * SQRT(R_E_exc_used))**2) 
      End If 
C     ' 
      IF (   MOD(IZ1,2)  .EQ. 1  )  J_rms = J_rms + Spin_odd * 
     *(REAL(IA1)/140.0)**0.66667 
C     /' empirical '/ 
C     /' Additional angular momentum of unpaired proton. '/ 
C     /' See also Tomar et al.,Pramana 68 (2007) 111 '/ 
C     ' 
      J_rms = J_rms * Jscaling 
C     ' Print Z1,I_Mode,beta1,T,E_exc,Spin_CN 
C     ' Print " ",I_rigid_spher,I_rigid,I_eff,J_rms 
C     ' 
      SpinRMSNZ(I_Mode,1,IA1-IZ1,IZ1) = J_rms 
C     ' 
C     ' 
C     '     Print A1,T,E_exc,I_rigid_spher,I_rigid,I_eff,J_rms 
C     ' 
C     /' Second (normally heavy) fission fragment: '/ 
C     ' 
      beta2 = Beta(I_Mode,2,IZ1) 
      alph = beta2 / SQRT(4.E0 * pi / 5.E0) 
      I_rigid = I_rigid_spher * (1.E0 + 0.5E0*alph + 9.E0/7.E0*alph**2) 
C     /' From Hasse & Myers,Geometrical Relationships ... '/ 
      E_exc = EPART(I_Mode,2,IA1) 
      IF (  E_exc .LT. 0  )  E_exc = 0 
      T = U_Temp(REAL(IZ1),REAL(IA1),E_exc,1,1,Tscale,Econd) 
      T = SQRT(T**2 + 0.8**2) 
C     ' For ZPM 
      I_eff = I_rigid * (1.E0 - 0.8E0 * exp(-0.693E0 * E_exc / 5.E0)) 
      J_rms = SQRT(2.E0 * I_eff * T) 
C     ' 
C     /' Influence of CN spin '/ 
      J_rms = SQRT(J_rms**2 + 1./3. * Spin_CN**2) 
C     ' 
C     /' Incoming neutron (spin + orbital) '/ 
      IF (  Emode .EQ. 2  ) THEN 
C     ' 2/3 * 1.16 * sqrt(2 * 939.65) / 197.33 = 0.1699 
      J_rms = SQRT(J_rms**2 + 1./3. * 0.5**2 +                  1./3. * 
     *(0.1699 * AT**0.333333 * SQRT(R_E_exc_used))**2) 
      End If 
C     ' 
      IF (   MOD(IZ1,2)  .EQ. 1  )  J_rms = J_rms + Spin_odd * 
     *(IA1/140.0)**0.66667 
C     /' empirical '/ 
C     /' Additional angular momentum of unpaired proton. '/ 
C     /' See also Tomar et al.,Pramana 68 (2007) 111 '/ 
C     ' 
      J_rms = J_rms * Jscaling 
C     ' 
      SpinRMSNZ(I_Mode,2,IA1-IZ1,IZ1) = J_rms 
C     ' 
      END DO 
      ENd If 
      END DO 
      END DO 
C     '   End Scope 
C     ' 
C     ' 
      R_Choice = Rnd 
      R_Sum_0 = Yield_Mode_0 
      R_Sum_1 = R_Sum_0 + Yield_Mode_1 
      R_Sum_2 = R_Sum_1 + Yield_Mode_2 
      R_Sum_3 = R_Sum_2 + Yield_Mode_3 
      R_Sum_4 = R_Sum_3 + Yield_Mode_4 
      R_Sum_5 = R_Sum_4 + Yield_Mode_11 
      R_Sum_6 = R_Sum_5 + Yield_Mode_22 
      I_Mode = 6 
      IF (  R_Choice .LT. R_Sum_0  )  I_Mode = 0 
      IF (  R_Choice .GE. R_Sum_0 .AND. R_Choice .LT. R_Sum_1  )  
     *I_Mode = 1 
      IF (  R_Choice .GE. R_Sum_1 .AND. R_Choice .LT. R_Sum_2  )  
     *I_Mode = 2 
      IF (  R_Choice .GE. R_Sum_2 .AND. R_Choice .LT. R_Sum_3  )  
     *I_Mode = 3 
      IF (  R_Choice .GE. R_Sum_3 .AND. R_Choice .LT. R_Sum_4  )  
     *I_Mode = 4 
      IF (  R_Choice .GE. R_Sum_4 .AND. R_Choice .LT. R_Sum_5  )  
     *I_Mode = 5 
      IF (  R_Choice .GE. R_Sum_5 .AND. R_Choice .LT. R_Sum_6  )  
     *I_Mode = 6 
C     '     End Scope 
C     ' 
C     ' 
C     /' Chosing Z and A values '/ 
      Select CASE( I_Mode) 
      CASE( 0) 
      R_A_heavy = PGauss(AC_Mode_0,SigA_Mode_0) 
C     /' random choice of mass '/ 
      RZpol = Zshift(0,2,NINT(R_A_heavy)) 
C     /' local polarization '/ 
      RZ = R_A_heavy * I_Z_CN / I_A_CN + RZpol 
C     /' mean position in Z for given mass '/ 
      R_Z_heavy = PGauss(RZ,SigPol_Mode_0) 
C     /' random choice of Z '/ 
      CASE( 1) 
      R_A_heavy = PGauss(AC_Mode_1,SigA_Mode_1) 
      RZpol = Zshift(1,2,NINT(R_A_heavy)) 
C     /' local polarization '/ 
      RZ = R_A_heavy * I_Z_CN / I_A_CN + RZpol 
      R_Z_heavy = PGauss(RZ,SigPol_Mode_1) 
      CASE( 2) 
      Iguess = 0 
      Next2: 
      Iguess = Iguess + 1 
      R_A_heavy = PBox2(AC_Mode_2,SigA_Mode_2*S2leftmod,SigA_Mode_2,
     *P_A_Width_S2) 
      RZpol = Zshift(2,2,NINT(R_A_heavy)) 
      RZ = R_A_heavy * I_Z_CN / I_A_CN + RZpol 
      RN = R_A_heavy - RZ 
      Rtest = RND 
C     '    If Iguess < 1.E3 Then 
C     '      If Rtest > Gaussintegral(RN-82,1.5*SigZ_Mode_2) Then 
C     '        Goto Next2 
C     '      End If 
C     '    End If 
C     '  If Iguess < 1.E3 Then 
C     '   If Rtest > Gaussintegral(RZ-ZTRUNC50,FTRUNC50*SigZ_Mode_2) Then 
C     '    If  Rtest > 0.5 * ERF((RZ-ZTRUNC50)/(FTRUNC50*SigZ_Mode_2)) + 0.5E0 Or       '       Rtest > 0.5 * ERF((I_Z_CN - RZ - ZTRUNC28)/(FTRUNC28*SigZ_Mode_2)) + 0.5 Then 
C     '      Goto Next2 
C     '    End If 
C     '  End If 
C     /' truncation below Z = 35 and below Z = 50 due to properties of deformed shells '/ 
      R_Z_heavy = PGauss(RZ,SigPol_Mode_2) 
      CASE( 3) 
      R_A_heavy = PGauss(AC_Mode_3,SigA_Mode_3) 
      RZpol = Zshift(3,2,R_A_heavy) 
      RZ = R_A_heavy * I_Z_CN / I_A_CN + RZpol 
      R_Z_heavy = PGauss(RZ,SigPol_Mode_3) 
      CASE( 4) 
      R_A_heavy = PGauss(AC_Mode_4,SigA_Mode_4) 
      RZpol = Zshift(4,2,R_A_heavy) 
      RZ = R_A_heavy * I_Z_CN / I_A_CN + RZpol 
      R_Z_heavy = PGauss(RZ,SigPol_Mode_4) 
      CASE( 5) 
      R_A_heavy = PGauss(AC_Mode_0,SigA_Mode_11) 
      RZ = R_A_heavy * I_Z_CN / I_A_CN 
      R_Z_heavy = PGAUSS(RZ,SigPol_Mode_0) 
      CASE( 6) 
      R_A_heavy = PGauss(AC_Mode_0,SigA_Mode_22) 
      RZ = R_A_heavy * I_Z_CN / I_A_CN 
      R_Z_heavy = PGauss(RZ,SigPol_Mode_0) 
      Case DEFAULT 
      End Select 
C     ' 
      R_Z_light = I_Z_CN - R_Z_heavy 
      R_A_light = I_A_CN - R_A_heavy 
C     ' 
C     ' 
C     /' Pre-neutron Z distribution,without even-odd effect '/ 
      I = NINT(R_Z_heavy) 
      IF (  I .GE. Lbound(ZPROV) .AND. I .LE. Ubound(Zprov)  ) THEN 
      ZPROV(I) = ZPROV(I) + Racc 
      ZMPROV(I_Mode,I) = ZMPROV(I_Mode,I) + Racc 
      End If 
      I = NINT(R_Z_light) 
      IF (  I .GE. Lbound(ZPROV) .AND. I .LE. Ubound(Zprov)  ) THEN 
      ZPROV(I) = ZPROV(I) + Racc 
      ZMPROV(I_Mode,I) = ZMPROV(I_Mode,I) + Racc 
      End If 
C     ' 
C     ' 
C     /' Provisional mass distribution,pre-neutron, 
C     directly deduced from Z distribution with UCD assumption '/ 
C     ' 
      APROV(NINT(R_Z_heavy * I_A_CN / I_Z_CN + 0.5)) = 
     *APROV(NINT(R_Z_heavy * I_A_CN / I_Z_CN + 0.5)) + Racc 
      APROV(NINT(R_Z_light * I_A_CN / I_Z_CN + 0.5)) = 
     *APROV(NINT(R_Z_light * I_A_CN / I_Z_CN + 0.5)) + Racc 
      AMPROV(I_Mode,NINT(R_Z_heavy * I_A_CN / I_Z_CN + 0.5)) = 
     *AMPROV(I_Mode,NINT(R_Z_heavy * I_A_CN / I_Z_CN + 0.5)) + Racc 
      AMPROV(I_Mode,NINT(R_Z_light * I_A_CN / I_Z_CN + 0.5)) = 
     *AMPROV(I_Mode,NINT(R_Z_light * I_A_CN / I_Z_CN + 0.5)) + Racc 
C     ' 
C     ' 
C     /' Round on integer values with even-odd effect '/ 
      R_N_heavy = R_A_heavy - R_Z_heavy 
C     ' 
      I_N_heavy = Even_odd(R_N_heavy,PEON(I_Mode,2,NINT(R_A_heavy))) 
      I_Z_heavy = Even_odd(R_Z_heavy,PEOZ(I_Mode,2,NINT(R_A_heavy))) 
      I_A_heavy = I_N_heavy + I_Z_heavy 
C     ' 
      I_N_light = I_N_CN - I_N_heavy 
      I_Z_light = I_Z_CN - I_Z_heavy 
      I_A_light = I_A_CN - I_A_heavy 
C     ' 
C     ' 
C     /' Correct mass distribution,pre-neutron '/ 
C     ' 
      APRE(I_A_heavy) = APRE(I_A_heavy) + Racc 
      APRE(I_A_light) = APRE(I_A_light) + Racc 
      AMPRE(I_Mode,I_A_heavy) = AMPRE(I_Mode,I_A_heavy) + Racc 
      AMPRE(I_Mode,I_A_light) = AMPRE(I_Mode,I_A_light) + Racc 
C     ' 
C     '    Q value from TF masses (M&S) + shell + pairing (consistent with rest of GEF) 
C     '   Qvalue = U_Mass(I_Z_CN,I_A_CN) + Lypair(I_Z_CN,I_A_CN) -  '           (U_Mass(I_Z_heavy,I_A_heavy) + Lypair(I_Z_heavy,I_A_heavy)  '          + U_Mass(I_Z_light,I_A_light) + Lypair(I_Z_light,I_A_light) ) 
C     ' 
C     '    Q value from 2012 mass evaluation (more precise,but not consistent). 
      Qvalue = AME2012(I_Z_CN,I_A_CN) - (AME2012(I_Z_heavy,I_A_heavy)   
     *            + AME2012(I_Z_light,I_A_light)) 
C     ' 
C     /' Nuclide distribution,pre-neutron '/ 
C     ' 
      NZPRE(I_N_heavy,I_Z_heavy) = NZPRE(I_N_heavy,I_Z_heavy) + 1 
      NZPRE(I_N_light,I_Z_light) = NZPRE(I_N_light,I_Z_light) + 1 
      NPRE(I_N_heavy) = NPRE(I_N_heavy) + Racc 
      NPRE(I_N_light) = NPRE(I_N_light) + Racc 
      NMPRE(I_Mode,I_N_heavy) = NMPRE(I_Mode,I_N_heavy) + Racc 
      NMPRE(I_Mode,I_N_light) = NMPRE(I_Mode,I_N_light) + Racc 
C     ' 
      ZISOPRE(I_A_Heavy,I_Z_Heavy) = ZISOPRE(I_A_Heavy,I_Z_Heavy) + 
     *Racc 
      ZISOPRE(I_A_Light,I_Z_Light) = ZISOPRE(I_A_Light,I_Z_Light) + 
     *Racc 
C     ' 
C     ' 
C     /' Excitation energy of fragments '/ 
C     ' 
      IF (  I_MOde .EQ. 0  ) THEN 
      Eexc_light_mean = Edefo(I_Mode,1,I_Z_light) 
C     /' Only deformation energy '/ 
      Eexc_heavy_mean = Edefo(I_Mode,2,I_Z_heavy) 
C     /' Only deformation energy '/ 
      RS = SIGDEFO_0 
      ESIGDEFOlight = ( Lymass(I_Z_light,I_A_light,beta(I_Mode,1,
     *I_Z_light) + RS) -                Lymass(I_Z_light,I_A_light,
     *beta(I_Mode,1,I_Z_light) )) 
      ESIGDEFOheavy = ( Lymass(I_Z_heavy,I_A_heavy,beta(I_Mode,2,
     *I_Z_heavy) + RS) -                Lymass(I_Z_heavy,I_A_heavy,
     *beta(I_Mode,2,I_Z_heavy) )) 
      End If 
      IF (  I_Mode .GT. 0 .AND. I_Mode .LE. 4  ) THEN 
      Eexc_light_mean = Edefo(I_Mode,1,I_Z_light) 
C     /' Only deformation energy '/ 
      Eexc_heavy_mean = Edefo(I_Mode,2,I_Z_heavy) 
C     /' Only deformation energy '/ 
      RS = SIGDEFO/SQRT(R_Att_Sad(I_Mode)) 
      ESIGDEFOlight = ( Lymass(I_Z_light,I_A_light,beta(I_Mode,1,
     *I_Z_light) + RS) -                Lymass(I_Z_light,I_A_light,
     *beta(I_Mode,1,I_Z_light) )) 
      ESIGDEFOheavy = ( Lymass(I_Z_heavy,I_A_heavy,beta(I_Mode,2,
     *I_Z_heavy) + RS) -                Lymass(I_Z_heavy,I_A_heavy,
     *beta(I_Mode,2,I_Z_heavy) )) 
C     ' 
C     ' If beta(I_MOde,1,I_Z_light) > 0.68 Then 
C     '   ESIGDEFOlight = 0.4*ESIGDEFOlight 
C     ' End If 
C     ' 
      End If 
      IF (  I_Mode .EQ. 5  ) THEN 
      Eexc_heavy_mean = Edefo(1,2,I_Z_heavy) 
      Eexc_light_mean = Edefo(1,2,I_Z_light) 
C     /' Shell effect stored for "heavy" fragment '/ 
      RS = SIGDEFO/SQRT(R_Att_Sad(I_Mode)) 
      ESIGDEFOheavy = ( Lymass(I_Z_heavy,I_A_heavy,beta(1,2,I_Z_heavy) 
     *+ RS) -                Lymass(I_Z_heavy,I_A_heavy,beta(1,2,
     *I_Z_heavy) )) 
      ESIGDEFOlight = ( Lymass(I_Z_light,I_A_light,beta(2,2,I_Z_light) 
     *+ RS) -                Lymass(I_Z_light,I_A_light,beta(2,2,
     *I_Z_light) )) 
      End If 
      IF (  I_Mode .EQ. 6  ) THEN 
      Eexc_heavy_mean = Edefo(2,2,I_Z_heavy) 
      Eexc_light_mean = Edefo(2,2,I_Z_light) 
C     /' Shell effect stored for "heavy" fragment '/ 
      RS = SIGDEFO/SQRT(R_Att_Sad(I_Mode)) 
      ESIGDEFOheavy = ( Lymass(I_Z_heavy,I_A_heavy,beta(2,2,I_Z_heavy) 
     *+ RS) -                Lymass(I_Z_heavy,I_A_heavy,beta(2,2,
     *I_Z_heavy) )) 
      ESIGDEFOlight = ( Lymass(I_Z_light,I_A_light,beta(2,2,I_Z_light) 
     *+ RS) -                Lymass(I_Z_light,I_A_light,beta(2,2,
     *I_Z_light) )) 
      End If 
      IF (  Eexc_heavy_mean .LT. 0  )  Eexc_heavy_mean = 0 
      IF (  Eexc_light_mean .LT. 0  )  Eexc_light_mean = 0 
C     ' 
C     /' Deformation of heavy and light fragment assumed to be uncorrelated '/ 
      TKEmin = 1.44 * I_Z_light * I_Z_heavy / (3.0 * 
     *(I_A_light**0.33333 + I_A_heavy**0.3333)) 
C     /' TKEmin for limiting the excitation energies of the fragments '/ 
      IF (  Qvalue-TKEmin .LT. 0  ) THEN 
C     '      Print "<I> Estimated TKEmin > Qvalue: TKEmin = ";TKEmin;",Qvalue = ";Qvalue 
C     '      Print "    A_heavy = ";I_A_heavy;",A_light;";I_A_light;",Mode = ";I_Mode 
C     '      Print "    Z_heavy = ";I_Z_heavy;",Z_light;";I_Z_light;",Mode = ";I_Mode 
      TKEmin = Qvalue - 1 
      End If 
      Eexc_heavy = -1. 
      DO WHILE( Eexc_heavy .LT. 0. .OR. Eexc_heavy .GT. (Qvalue-TKEmin) 
     ** I_A_light / I_A_CN) 
      Eexc_heavy = PGAUSS(Eexc_heavy_mean,ESIGDEFOheavy) 
      END DO 
      Eexc_light = -1. 
      DO WHILE( Eexc_light .LT. 0. .OR. Eexc_light .GT. (Qvalue-TKEmin) 
     ** I_A_heavy / I_A_CN) 
      Eexc_light = PGAUSS(Eexc_light_mean,ESIGDEFOlight) 
      END DO 
C     ' If Eexc_light_mean > 50 or Eexc_heavy_mean > 50 Then 
C     ' Print "Mode,Zlight,Alight,Eexc_light_mean",I_Mode,I_Z_light,I_A_light,Eexc_light_mean 
C     ' Print "Mode,Zheavy,Aheavy,Eexc_heavy_mean",I_Mode,I_Z_heavy,I_A_heavy,Eexc_heavy_mean 
C     ' End If 
C     ' 
C     /' Assumption: width in TKE is the '/ 
C     /' quadratic sum of widths in defo and coll. '/ 
C     /' Remark of caution: The width of the TKE for fixed mass contains often 
C     several fission modes. The width in Lang et al. for fixed Z contains several A, 
C     which contributes already with about 3% to the width. Therefore,the 
C     width in TXE (or TKE) for fixed A and fixed mode may be much smaller than 
C     4 or 5 percent! '/ 
C     ' 
      IF (  NINT(10.0*Eexc_heavy) .LE. Ubound(Edefo2d,2)  ) THEN 
      Edefo2d(I_A_heavy,NINT(10.0*Eexc_heavy))= Edefo2d(I_A_heavy,
     *NINT(10*Eexc_heavy))+Racc 
      End If 
      IF (  NINT(10.0*Eexc_light) .LE. Ubound(Edefo2d,2)  ) THEN 
      Edefo2d(I_A_light,NINT(10.0*Eexc_light))= Edefo2d(I_A_light,
     *NINT(10*Eexc_light))+Racc 
      End If 
C     ' 
C     /' Temperatures of fragments '/ 
C     ' 
      IF (  I_Mode .LE. 4  ) THEN 
      Tlight = Temp(I_Mode,1,I_A_light) 
      Theavy = Temp(I_Mode,2,I_A_heavy) 
      End If 
      IF (  I_Mode .EQ. 5  ) THEN 
      Tlight = Temp(1,2,I_A_light) 
      Theavy = Temp(1,2,I_A_heavy) 
      End If 
      IF (  I_Mode .EQ. 6  ) THEN 
      Tlight = Temp(2,2,I_A_light) 
      Theavy = Temp(2,2,I_A_heavy) 
      End If 
C     ' 
C     ' 
C     /' Intrinsic excitation energies of fragments '/ 
C     ' 
      E_intr_light_mean = EPART(I_Mode,1,I_A_light) 
      E_intr_heavy_mean = EPART(I_Mode,2,I_A_heavy) 
C     ' 
      IF (   MOD(I_Z_CN,2)  .EQ. 0  ) THEN 
C     ' Even-odd fluctuation of TXE acc. to Lang et al. NPA 345 (1980) 34 
C     ' Lower TXE for completely paired configuration at scission. 
C     ' Only the even-odd effect at symmetry is considered,because the 
C     ' energy gain by the asymmetry-driven even-odd effect goes to E_intr 
C     ' of the heavy fragment due to energy sorting. 
      IF (   MOD(I_Z_light,2)  .EQ. 0  ) THEN 
      IF (  RND .LT. PEOZ(I_Mode,1,0.5E0*I_A_CN)  ) THEN 
      TXE_shift = -12.E0/SQRT(I_A_CN) 
      End If 
      End If 
      End If 
C     ' 
      E_intr_light_mean = E_intr_light_mean + TXE_shift * 
     *E_intr_light_mean / (E_intr_light_mean + E_intr_heavy_mean) 
      IF (  E_intr_light_mean .LT. 0  )  E_intr_light_mean = 0 
      E_intr_heavy_mean = E_intr_heavy_mean + TXE_shift * 
     *E_intr_heavy_mean / (E_intr_heavy_mean + E_intr_light_mean) 
      IF (  E_intr_heavy_mean .LT. 0  )  E_intr_heavy_mean = 0 
C     ' 
      E_intr_light = -1. 
      DO WHILE( E_intr_light .LT. 0.) 
      E_intr_light = PGauss(E_intr_light_mean,EexcSIGrel* 
     *E_intr_light_mean+0.5) 
      END DO 
      E_intr_heavy = -1. 
      DO WHILE( E_intr_heavy .LT. 0.) 
      E_intr_heavy = PGauss(E_intr_heavy_mean,EexcSIGrel* 
     *E_intr_heavy_mean+0.5) 
      END DO 
C     ' 
      E_intr_light = E_intr_light - Lypair(I_Z_light,I_A_light) 
      E_intr_heavy = E_intr_heavy - Lypair(I_Z_heavy,I_A_heavy) 
C     /' Staggering of BE of fragments by pairing '/ 
C     /' Assumption: pairing only felt in the lowest nuclear levels,'/ 
C     /' at the end of the evaporation cascade '/ 
C     /' (This should be a good assumption for higher excitation energies. '/ 
C     /' Some deviations occur due to the even-odd effect at low exc. energies. '/ 
C     ' 
C     ' 
      IF (  E_intr_heavy .LT. 100  ) THEN 
      Eintr2d(I_A_heavy,NINT(10*E_intr_heavy))= Eintr2d(I_A_heavy,
     *NINT(10*E_intr_heavy))+Racc 
      End If 
      IF (  E_intr_light .LT. 100  ) THEN 
      Eintr2d(I_A_light,NINT(10*E_intr_light))= Eintr2d(I_A_light,
     *NINT(10*E_intr_light))+Racc 
      End If 
C     ' 
      Eexc_heavy = Eexc_heavy + E_intr_heavy 
      Eexc_light = Eexc_light + E_intr_light 
C     /' Now: deformation + intrinsic excitation energy '/ 
C     ' 
C     ' 
C     /' Collective energy of fragments '/ 
C     ' 
      Ecoll_mean = ECOLLFRAC * (De_Saddle_Scission(I_Z_CN**2 / 
     *I_A_CN**0.33333E0,ESHIFTSASCI_coll) - E_tunn) 
C     ' 
      IF (  Ecoll_mean .LT. 0  )  Ecoll_mean = 0 
C     ' 
C     /' Experimental data of prompt neutron yields show an enhancement of the '/ 
C     /' neutron yield for odd-Z CN,corresponding to an enhanced E* by about 1.6 MeV '/ 
C     /' The enhancement is equally shared to the light and the heavy fragment. '/ 
C     /' The neutron number of the CN has no influence. '/ 
C     /' The origin of this effect is not clear. '/ 
C     /' By technical reasons,this additional energy is introduced here into the '/ 
C     /' collective energy at scission,because this energy is divided equally between both fragments. '/ 
C     /'  KHS,31. Jan. 2012 '/ 
C     '  If  (I_Z_CN Mod 2) = 1 Then Ecoll_mean = Ecoll_mean + 1.6 
C     ' This is not used any more. It seems to be wrong or to be replaced by something else. 
C     ' 
C     '  Assuming positive correlation of Ecoll_heavy and Ecoll_light. 
C     '  This is probably not realistic! 
C     '  See Nix & Swiatecki,Nucl. Phys. 71 (1965) 1    Ecoll = -1 
C     /'  Ecoll = -1. 
C     While Ecoll < 0 
C     Ecoll = PGauss(Ecoll_mean,EexcSIGrel* Ecoll_mean) 
C     Wend 
C     Ecoll = Ecoll + E_coll_saddle(I_Mode) 
C     Ecoll_heavy = 0.5E0 * Ecoll 
C     Ecoll_light = 0.5E0 * Ecoll '/ 
C     ' 
C     '   Assuming no correlation (partly positive,partly negative correlation) 
C     '    Scope 
      Rmean = 0.5 * Ecoll_mean 
      Rsigma = SQRT(0.5) * EexcSIGrel * Ecoll_mean 
      Ecoll_heavy = -1 
      DO WHILE( Ecoll_heavy .LT. 0) 
      Ecoll_heavy = PGauss(Rmean,Rsigma) 
      END DO 
      Ecoll_heavy = Ecoll_heavy + 0.5E0 * E_coll_saddle(I_Mode) 
      Ecoll_light = -1 
      DO WHILE( Ecoll_light .LT. 0) 
      Ecoll_light = PGauss(Rmean,Rsigma) 
      END DO 
      Ecoll_light = Ecoll_light + 0.5E0 * E_coll_saddle(I_Mode) 
      Ecoll = Ecoll_heavy + Ecoll_light 
C     '    End Scope 
C     ' 
      Ecoll2d(I_A_heavy,NINT(10*Ecoll_heavy)) = Ecoll2d(I_A_heavy,
     *NINT(10*Ecoll_heavy)) + Racc 
      Ecoll2d(I_A_light,NINT(10*Ecoll_light)) = Ecoll2d(I_A_light,
     *NINT(10*Ecoll_light)) + Racc 
C     ' 
      Eexc_heavy = Eexc_heavy + Ecoll_heavy 
      Eexc_light = Eexc_light + Ecoll_light 
C     /' Now: also collective excitation energy added '/ 
C     ' 
C     ' 
C     ' 
      IF (  Eexc_heavy .LT. 100  ) THEN 
      Eexc2d(I_A_heavy,NINT(10*Eexc_heavy))= Eexc2d(I_A_heavy,
     *NINT(Eexc_heavy))+Racc 
      End If 
      IF (  Eexc_light .LT. 100  ) THEN 
      Eexc2d(I_A_light,NINT(10*Eexc_light))= Eexc2d(I_A_light,
     *NINT(Eexc_light))+Racc 
      End If 
C     ' 
C     ' 
C     /'** Angular momentum of fragments **'/ 
C     ' 
      IF (  I_Mode .LE. 4  ) THEN 
      J_Frag_light = PLinGauss(SpinRMSNZ(I_Mode,1,I_N_Light,
     *I_Z_light)/SQRT(2.0)) - 0.5 
      J_Frag_heavy = PLinGauss(SpinRMSNZ(I_Mode,2,I_N_Heavy,
     *I_Z_heavy)/SQRT(2.0)) - 0.5 
      End If 
      IF (  I_Mode .EQ. 5  ) THEN 
      J_Frag_light = PLinGauss(SpinRMSNZ(1,2,I_N_Light,
     *I_Z_light)/SQRT(2.0)) - 0.5 
      J_Frag_heavy = PLinGauss(SpinRMSNZ(1,2,I_N_Heavy,
     *I_Z_heavy)/SQRT(2.0)) - 0.5 
      End If 
      IF (  I_Mode .EQ. 6  ) THEN 
      J_Frag_light = PLinGauss(SpinRMSNZ(2,2,I_N_Light,
     *I_Z_light)/SQRT(2.0)) - 0.5 
      J_Frag_heavy = PLinGauss(SpinRMSNZ(2,2,I_N_Heavy,
     *I_Z_heavy)/SQRT(2.0)) - 0.5 
      End If 
C     ' 
      IF (  J_Frag_light .LT. 0  )  J_Frag_light = 0 
      IF (  J_Frag_light .LE. Ubound(JFRAGpre,3)  ) THEN 
      JFRAGpre(I_N_light,I_Z_light,J_Frag_light) = JFRAGpre(I_N_light,
     *I_Z_light,J_Frag_light) + 1 
      End If 
C     ' 
      IF (  J_Frag_heavy .LT. 0  )  J_Frag_heavy = 0 
      IF (  J_Frag_heavy .LE. Ubound(JFRAGpre,3)  ) THEN 
      JFRAGpre(I_N_heavy,I_Z_heavy,J_Frag_heavy) = JFRAGpre(I_N_heavy,
     *I_Z_heavy,J_Frag_heavy) + 1 
      End If 
C     ' 
      IfragEff_light = U_Ired(I_Z_light,I_A_light) 
      Erotlight = J_Frag_light*(J_Frag_light+1)/(2*IfragEff_light) 
C     ' 
      IfragEff_heavy = U_Ired(I_Z_heavy,I_A_heavy) 
      Erotheavy = J_Frag_heavy*(J_Frag_heavy+1)/(2*IfragEff_heavy) 
C     ' 
C     ' 
C     /' Kinetic energies of fragments '/ 
C     ' 
C     ' TXE includes E*_CN 
C     ' 
      TXE = Eexc_light + Eexc_heavy + Erotlight + Erotheavy 
C     ' 
      IF (  I_A_heavy .GE. Lbound(AQpre,1) .AND. I_A_heavy .LE. 
     *Ubound(AQpre,1) .AND. Qvalue .GE. Lbound(AQpre,2) .AND. Qvalue 
     *.LE. Ubound(AQpre,2)  ) THEN 
      AQpre(I_A_heavy,Qvalue) = AQpre(I_A_heavy,Qvalue) + 1 
      End If 
      IF (  I_A_light .GE. Lbound(AQpre,1) .AND. I_A_light .LE. 
     *Ubound(AQpre,1) .AND. Qvalue .GE. Lbound(AQpre,2) .AND. Qvalue 
     *.LE. Ubound(AQpre,2)  ) THEN 
      AQpre(I_A_light,Qvalue) = AQpre(I_A_light,Qvalue) + 1 
      End If 
C     ' 
      IF (  Qvalue .LT. Ubound(Qvalues,1) .AND. Qvalue .GT. 
     *Lbound(Qvalues,1)  ) THEN 
      Qvalues(Qvalue) = Qvalues(Qvalue) + 1 
      End If 
      IF (  TXE .LT. Ubound(TotXE,1) .AND. TXE .GT. Lbound(TotXE,1)  ) 
     *THEN 
      TotXE(NINT(TXE)) = TotXE(NINT(TXE)) + 1 
      End If 
C     ' 
      E_total = Qvalue + R_E_exc_GS 
      TKE = E_total - TXE 
      IF (  TKE .LT. 0  ) THEN 
      TXEcorr = TXE + TKE - 1 
      TKE = 1 
      Eexc_light = Eexc_light * TXEcorr/TXE 
      Eexc_heavy = Eexc_heavy * TXEcorr/TXE 
      TXE = TXEcorr 
      End If 
      TXE = Eexc_light + Eexc_heavy + Erotlight + Erotheavy 
      TXElight = Eexc_light + Erotlight 
      TXEheavy = Eexc_heavy + Erotheavy 
      Ekinlight = TKE * I_A_heavy / I_A_CN 
      Ekinheavy = TKE * I_A_light / I_A_CN 
C     ' 
      IF (  Ekinlight .LT. Ubound(Ekinpre,1) .AND. Ekinlight .GT. 
     *Lbound(EKinpre,1)  ) THEN 
      Ekinpre(NINT(Ekinlight)) = Ekinpre(NINT(Ekinlight)) + 1 
      EkinpreM(I_Mode,NINT(Ekinlight)) = EkinpreM(I_Mode,
     *NINT(Ekinlight)) + 1 
      End If 
      IF (  Ekinheavy .LT. Ubound(Ekinpre,1) .AND. Ekinheavy .GT. 
     *Lbound(EKinpre,1)  ) THEN 
      Ekinpre(NINT(Ekinheavy)) = Ekinpre(NINT(Ekinheavy)) + 1 
      EkinpreM(I_Mode,NINT(Ekinheavy)) = EkinpreM(I_Mode,
     *NINT(Ekinheavy)) + 1 
      End If 
      IF (  I_A_light .LT. Ubound(AEkinpre,1) .AND. I_A_light .GT. 
     *Lbound(AEkinpre,1) .AND. Ekinlight+1 .LT. Ubound(AEkinpre,2) 
     *.AND. Ekinlight .GT. Lbound(AEkinpre,2)  ) THEN 
      AEkinpre(I_A_light,NINT(Ekinlight)) = AEkinpre(I_A_light,
     *NINT(Ekinlight)) + 1 
      End If 
      IF (  I_A_heavy .LT. Ubound(AEkinpre,1) .AND. I_A_heavy .GT. 
     *Lbound(AEkinpre,1) .AND. Ekinheavy+1 .LT. Ubound(AEkinpre,2) 
     *.AND. Ekinheavy .GT. Lbound(AEkinpre,2)  ) THEN 
      AEkinpre(I_A_heavy,NINT(Ekinheavy)) = AEkinpre(I_A_heavy,
     *NINT(Ekinheavy)) + 1 
      End If 
      IF (  TKE .LT. Ubound(TKEpre,1) .AND. TKE .GT. Lbound(TKEpre,1)  
     *) THEN 
      TKEpre(NINT(TKE)) = TKEpre(NINT(TKE)) + 1 
      TKEpreM(I_Mode,NINT(TKE)) = TKEpreM(I_Mode,NINT(TKE)) + 1 
      End If 
      IF (  I_A_light .LT. Ubound(ATKEpre,1) .AND. I_A_light .GT. 
     *Lbound(ATKEpre,1) .AND. TKE + 1 .LT. Ubound(ATKEpre,2) .AND. TKE 
     *.GT. Lbound(ATKEpre,2)  ) THEN 
      ATKEpre(I_A_light,NINT(TKE)) = ATKEpre(I_A_light,NINT(TKE)) + 1 
      End If 
      IF (  I_A_heavy .LT. Ubound(ATKEpre,1) .AND. I_A_heavy .GT. 
     *Lbound(ATKEpre,1) .AND. TKE + 1 .LT. Ubound(ATKEpre,2) .AND. TKE 
     *.GT. Lbound(ATKEpre,2)  ) THEN 
      ATKEpre(I_A_heavy,NINT(TKE)) = ATKEpre(I_A_heavy,NINT(TKE)) + 1 
      End If 
C     ' 
C     ' 
C     '    End Scope 
C     ' 
C     ' 
C     ' Print " " 
C     /'** Neutron evaporation **'/ 
C     ' 
      Ngtot = 0 
      Nglight = 0 
      Ngheavy = 0 
      Egtot1000 = 0 
C     ' 
      Epre = E_pot_scission + E_exc_Barr - Ecoll - E_intr_light - 
     *E_intr_heavy - Erotlight - Erotheavy 
      Epre_again: 
C     ' Epre = Pgauss(5,5) 
C     ' Epre = Pgauss(7,6.E0 * U_temp(I_Z_CN,I_A_CN,E_exc_Barr,1,1,Tscale,Econd)) 
C     ' Epre = Pgauss(4,6.E0 * U_temp(I_Z_CN,I_A_CN,E_exc_Barr,1,1,Tscale,Econd)) 
      Epre_mean = 0.4 * De_Saddle_Scission(I_Z_CN**2/I_A_CN**0.333333,
     *ESHIFTSASCI_coll) 
C     'Epre = Pgauss(Epre_mean,6.E0 * U_temp(I_Z_CN,I_A_CN,E_exc_Barr,1,1,Tscale,Econd)) 
      Epre = Pgauss(Epre_mean,Epre_mean) 
C     ' 
C     ' 
      IF (  Epre .LT. 0  )  Goto Epre_again 
C     ' 
      IF (  Epre .LT. 0  )  Epre = 0 
C     ' 
      IF (  I_Mode .LE. 4  ) THEN 
      TheavyFF = TempFF(I_Mode,2,I_A_heavy) 
      TlightFF = TempFF(I_Mode,1,I_A_light) 
      End If 
      IF (  I_Mode .EQ. 5  ) THEN 
C     ' S11 
      TheavyFF = TempFF(1,2,I_A_heavy) 
      TlightFF = TempFF(1,2,I_A_light) 
      End If 
      IF (  I_Mode .EQ. 6  ) THEN 
C     ' S22 
      TheavyFF = TempFF(2,2,I_A_heavy) 
      TheavyFF = TempFF(2,2,I_A_light) 
      End If 
C     ' 
C     ' 
C     '*** Neutron evaporation from light fragment *** 
C     ' 
      In_post = 0 
C     ' 
      DO I = 1 , UBound(Array_En_light) 
      Array_En_light(I) = 0 
      Array_Vn_light_long(I) = 0 
      Array_Vn_light_perp(I) = 0 
      Array_Tn(I) = 0 
      END DO 
      CALL Eva(1,I_Z_light,I_A_light,Eexc_light,TlightFF,R_Z_Light_Post,
     *R_A_Light_Post,E_Final_Light,Array_En_light(),Array_Tn()) 
C     ' 
C     '  Print "E_Final_Light",E_Final_light 
C     '  Print "E_Final_tot  ",E_Final_light + E_FInal_heavy 
C     ' 
C     ' 
      DO I = 1 , UBound(Array_En_light) 
      IF (  Array_En_light(I) .EQ. 0  )  Exit 
      v_N = SQRT(Array_En_light(I)) 
C     ' units of velocity sqrt(E/A),E in MeV 
      IF (  Array_Tn(I) .GT. 100  ) THEN 
      v_F = SQRT(Ekinlight/R_A_light) 
      Else 
      v_F = u_accel(I_A_light,I_Z_light,I_A_heavy,I_Z_heavy,TKE,Epre,
     *Array_Tn(I)) 
      End If 
      v_N_long = v_N * (2.E0*rnd - 1.E0) 
      Array_Vn_light_long(I) = v_N_long 
      v_N_perp = SQRT(v_N**2 - v_N_long**2) 
      Array_Vn_light_perp(I) = v_N_perp 
      v_N_cm = SQRT( (v_F+v_N_long)**2 + v_N_perp**2 ) 
      E_N_cm = v_N_cm**2 
C     ' 
      In_post = In_post + 1 
      Array_En_post(In_post) = E_N_cm 
C     ' 
C     ' cosine of angle between light fragment and neutron 
C     ' (approximation: recoil of additional neutrons neglected 
      cos_alpha = (v_F + v_N_long) / v_N_cm 
      Array_cos_alpha(In_post) = cos_alpha 
      Array_phi(In_post) = Rnd * 360 
      J = Int(100*cos_alpha) 
      IF (  E_N_cm .GT. 0.4  )  Ndirlight(J) = Ndirlight(J) + 1 
C     ' 
      IF (  E_N_cm .GT. 0 .AND. E_N_cm*1000 .LT. UBOUND(EN)  ) THEN 
      EN(Int(E_N_cm*1000)) = EN(Int(E_N_cm*1000)) + 1 
C     ' neutron spectrum in cm,1 keV steps 
      ENfr(Int(E_N_cm*1000)) = ENfr(Int(E_N_cm*1000)) + 1 
C     ' neutron spectrum in cm,1 keV steps 
      IF (  I_N_Multi .LT. Ubound(ENfrC,1) .AND. I_Z_Multi .LT. 
     *Ubound(ENfrC,2)  ) THEN 
      ENfrC(I_N_Multi,I_Z_Multi,Int(E_N_cm*1000)) = EnfrC(I_N_Multi,
     *I_Z_Multi,Int(E_N_cm*1000)) + 1 
      End If 
      ENM(I_Mode,Int(E_N_cm*1000)) = ENM(I_Mode,Int(E_N_cm*1000)) + 1 
      ENlight(Int(E_N_cm*1000)) = ENlight(Int(E_N_cm*1000)) + 1 
      End If 
      END DO 
C     ' 
      R_N_Light_Post = R_A_Light_Post - R_Z_Light_Post 
      I_Z_Light_Post = NINT(R_Z_Light_Post) 
      I_N_Light_Post = NINT(R_N_Light_Post) 
      I_A_Light_Post = I_Z_Light_Post + I_N_Light_Post 
C     ' 
      APOST(I_A_light_Post)=APOST(I_A_light_Post)+Racc 
      AMPOST(I_MODE,I_A_light_Post)=AMPOST(I_MODE,I_A_light_Post)+Racc 
C     ' 
      ZPOST(I_Z_light_Post)=ZPOST(I_Z_light_Post)+Racc 
      ZMPOST(I_Mode,I_Z_light_Post)=ZMPOST(I_Mode,I_Z_light_Post)+Racc 
C     ' 
      NPOST(I_N_Light_Post)=NPOST(I_N_Light_Post)+Racc 
      NMPOST(I_Mode,I_N_Light_Post)=NMPOST(I_Mode,I_N_Light_Post)+Racc 
C     ' 
      NZPOST(I_N_light_Post,I_Z_light_post)= NZPOST(I_N_light_Post,
     *I_Z_light_post)+Racc 
C     ' 
      I_nu_light = I_A_Light - I_A_Light_Post 
      IF (  I_nu_light .GE. 0 .AND. I_nu_light .LE. 50  ) THEN 
      NNlight(I_nu_light) = NNlight(I_nu_light) + 1 
      End If 
      IF (  I_nu_light .GE. 0 .AND. I_nu_light .LE. 20  ) THEN 
      N2dpost(I_A_Light_Post,I_nu_light)=N2dpost(I_A_Light_post,
     *I_nu_light)+1 
      N2dpre(I_A_Light,I_nu_light)=N2dpre(I_A_Light,I_nu_light)+1 
      End If 
C     ' 
C     ' 
C     '*** Neutron evaporation from heavy fragment *** 
C     ' 
      DO I = 1 , UBound(Array_En_heavy) 
      Array_En_heavy(I) = 0 
      Array_Vn_heavy_long(I) = 0 
      Array_Vn_heavy_perp(I) = 0 
      Array_Tn(I) = 0 
      END DO 
C     ' 
      CALL Eva(2,I_Z_heavy,I_A_heavy,Eexc_heavy,TheavyFF,R_Z_Heavy_Post,
     *R_A_Heavy_Post,E_Final_Heavy,Array_En_heavy(),Array_Tn()) 
C     ' 
C     '  Print "E_Final_Heavy",E_Final_Heavy 
C     ' 
      DO I = 1 , UBound(Array_En_heavy) 
      IF (  Array_En_heavy(I) .EQ. 0  )  Exit 
      v_N = SQRT(Array_En_heavy(I)) 
C     ' units of velocity sqrt(E/A),E in MeV 
      IF (  Array_Tn(I) .GT. 100  ) THEN 
      v_F = SQRT(Ekinheavy/R_A_heavy) 
      Else 
      v_F = u_accel(I_A_heavy,I_Z_heavy,I_A_light,I_Z_light,TKE,Epre,
     *Array_Tn(I)) 
      End If 
      v_N_long = v_N * (2.E0*rnd - 1.E0) 
      Array_vN_heavy_long(I) = v_N_long 
      v_N_perp = SQRT(v_N**2 - v_N_long**2) 
      Array_vN_heavy_perp(I) = v_N_perp 
      v_N_cm = SQRT( (v_F+v_N_long)**2 + v_N_perp**2 ) 
      E_N_cm = v_N_cm**2 
C     ' 
      In_post = In_post + 1 
      Array_En_post(In_post) = E_N_cm 
C     ' 
C     ' cosine of angle between light fragment and neutron 
C     ' (approximation: recoil of additional neutrons neglected) 
      cos_alpha = -(v_F + v_N_long) / v_n_cm 
      Array_cos_alpha(In_post) = cos_alpha 
      Array_phi(In_post) = Rnd * 360 
      J = Int(100*cos_alpha) 
      IF (  E_N_cm .GT. 0.4  )  Ndirlight(J) = Ndirlight(J) + 1 
C     ' 
      IF (  E_N_cm .GT. 0 .AND. E_N_cm*1000 .LT. UBOUND(EN)  ) THEN 
      EN(Int(E_N_cm*1000)) = EN(Int(E_N_cm*1000)) + 1 
C     ' neutron spectrum in cm,1 keV steps 
      ENfr(Int(E_N_cm*1000)) = ENfr(Int(E_N_cm*1000)) + 1 
C     ' neutron spectrum in cm,1 keV steps 
      IF (  I_N_Multi .LT. Ubound(ENfrC,1) .AND. I_Z_Multi .LT. 
     *Ubound(ENfrC,2)  ) THEN 
      ENfrC(I_N_Multi,I_Z_Multi,Int(E_N_cm*1000)) = EnfrC(I_N_Multi,
     *I_Z_Multi,Int(E_N_cm*1000)) + 1 
      End If 
      ENM(I_Mode,Int(E_N_cm*1000))= ENM(I_Mode,Int(E_N_cm*1000)) + 1 
      ENheavy(Int(E_N_cm*1000)) = ENheavy(Int(E_N_cm*1000)) + 1 
      Else 
C     '        Print "-------------------------------------------------------" 
C     '        Print Ekinheavy,TKE,R_A_heavy,I_A_light 
C     '        Print I,Array_En_heavy(I),v_N,v_F,v_N_long,v_N_cm,E_N_cm 
C     '        Print E_N_cm,I_Z_heavy,I_N_heavy,Eexc_heavy,TheavyFF,E_Final_heavy,E_KIN 
      End If 
      END DO 
C     ' 
      R_N_Heavy_Post = R_A_Heavy_Post - R_Z_Heavy_Post 
      I_Z_Heavy_Post = NINT(R_Z_Heavy_Post) 
      I_N_Heavy_Post = NINT(R_N_Heavy_Post) 
      I_A_Heavy_Post = I_Z_Heavy_Post + I_N_Heavy_Post 
C     ' 
      APOST(I_A_heavy_Post)=APOST(I_A_heavy_Post)+Racc 
      AMPOST(I_MODE,I_A_heavy_Post)=AMPOST(I_MODE,I_A_heavy_Post)+Racc 
C     ' 
      ZPOST(I_Z_heavy_Post)= ZPOST(I_Z_heavy_Post)+Racc 
      ZMPOST(I_Mode,I_Z_heavy_post)=ZMPOST(I_Mode,I_Z_heavy_post)+Racc 
C     ' 
      NPOST(I_N_Heavy_Post)=NPOST(I_N_Heavy_Post)+Racc 
      NMPOST(I_Mode,I_N_Heavy_Post)=NMPOST(I_Mode,I_N_Heavy_Post)+Racc 
C     ' 
      NZPOST(I_N_heavy_Post,I_Z_heavy_post)= NZPOST(I_N_heavy_Post,
     *I_Z_heavy_post)+Racc 
      I_nu_heavy = I_A_heavy - I_A_Heavy_Post 
      IF (  I_nu_heavy .GE. 0 .AND. I_nu_heavy .LE. 50  ) THEN 
      NNheavy(I_nu_heavy) = NNheavy(I_nu_heavy) + 1 
      End If 
      IF (  I_nu_heavy .GE. 0 .AND. I_nu_heavy .LE. 20  ) THEN 
      N2dpost(I_A_Heavy_Post,I_nu_heavy)=N2dpost(I_A_Heavy_Post,
     *I_nu_heavy)+1 
      N2dpre(I_A_Heavy,I_nu_heavy)=N2dpre(I_A_Heavy,I_nu_heavy)+1 
      End If 
      I_nu_fr = I_nu_heavy + I_nu_light 
      IF (  I_nu_fr .GE. 0 .AND. I_nu_fr .LE. 50  ) THEN 
      NNfr(I_nu_fr) = NNfr(I_nu_fr) + 1 
      End If 
C     ' 
C     ' 
C     ' 
C     '*** Post-neutron energies 
C     ' 
      IF (  TKE .GE. 0 .AND. TKE .LE. 250 .AND. I_nu_fr .GE. 0 .AND. 
     *I_nu_fr .LE. 20  ) THEN 
      nuTKEpre(TKE,I_nu_fr) = nuTKEpre(TKE,I_nu_fr) + 1 
      End If 
C     '   Ekinlight_post = Ekinlight * (I_A_light_post/I_A_Light)  ' not exact! 
      vkinlight = SQRT(Ekinlight/I_A_Light) 
C     ' velocity in units of sqr(MeV/A) 
      J = I_A_light 
      DO I = 1 , Ubound(Array_Vn_light_long) 
      IF (  Array_Vn_light_long(I) .NE. 0  ) THEN 
      J = J - 1 
      vkinlight = vkinlight - Array_Vn_light_long(I) / J 
      vkinlight = SQRT(vkinlight**2 + (Array_Vn_light_perp(I)/J)**2 ) 
      End If 
      END DO 
      Ekinlight_post = vkinlight**2 * I_A_light_post 
C     ' 
C     '   Ekinheavy_post = Ekinheavy * (I_A_heavy_post/I_A_heavy)  '  "    " 
      vkinheavy = SQRT(Ekinheavy/I_A_heavy) 
C     ' velocity in units of sqr(MeV/A) 
      J = I_A_heavy 
      DO I = 1 , Ubound(Array_Vn_heavy_long) 
      IF (  Array_Vn_heavy_long(I) .NE. 0  ) THEN 
      J = J - 1 
      vkinheavy = vkinheavy - Array_Vn_heavy_long(I) / J 
      vkinheavy = SQRT(vkinheavy**2 + (Array_Vn_heavy_perp(I)/J)**2 ) 
      End If 
      END DO 
      Ekinheavy_post = vkinheavy**2 * I_A_heavy_post 
C     ' 
      TKE_post = Ekinlight_post + Ekinheavy_post 
      IF (  TKE_post .GE. 0 .AND. TKE_post .LE. 250 .AND. I_nu_fr .GE. 
     *0 .AND. I_nu_fr .LE. 20  ) THEN 
      nuTKEpost(TKE_post,I_nu_fr) = nuTKEpost(TKE_post,I_nu_fr) + 1 
      End If 
C     ' 
      IF (  Ekinlight_post .LT. Ubound(Ekinpost,1) .AND. Ekinlight_post 
     *.GT. Lbound(EKinpost,1)  ) THEN 
      Ekinpost(NINT(Ekinlight_post)) = Ekinpost(NINT(Ekinlight_post)) + 
     *1 
      EkinpostM(I_Mode,NINT(Ekinlight_post)) = EkinpostM(I_Mode,
     *NINT(Ekinlight_post)) + 1 
      End If 
      IF (  Ekinheavy_post .LT. Ubound(Ekinpost,1) .AND. Ekinheavy_post 
     *.GT. Lbound(EKinpost,1)  ) THEN 
      Ekinpost(NINT(Ekinheavy_post)) = Ekinpost(NINT(Ekinheavy_post)) + 
     *1 
      EkinpostM(I_Mode,NINT(Ekinheavy_post)) = EkinpostM(I_Mode,
     *NINT(Ekinheavy_post)) + 1 
      End If 
C     ' 
      IF (  TKE_post .LT. Ubound(TKEpost,1) .AND. TKE_post .GT. 
     *Lbound(TKEpost,1)  ) THEN 
      TKEpost(NINT(TKE_post)) = TKEpost(NINT(TKE_post)) + 1 
      TKEpostM(I_Mode,NINT(TKE_post)) = TKEpostM(I_Mode,NINT(TKE_post)) 
     *+ 1 
      End If 
      IF (  I_A_light_post .LT. Ubound(AEkinpost,1) .AND. 
     *I_A_light_post .GT. Lbound(AEkinpost,1) .AND. Ekinlight_post+1 
     *.LT. Ubound(AEkinpost,2) .AND. Ekinlight_post .GT. 
     *Lbound(AEkinpost,2)  ) THEN 
      AEkinpost(I_A_light_post,NINT(Ekinlight_post)) = 
     *AEkinpost(I_A_light_post,NINT(Ekinlight_post)) + 1 
      End If 
      IF (  I_A_heavy_post .LT. Ubound(AEkinpost,1) .AND. 
     *I_A_heavy_post .GT. Lbound(AEkinpost,1) .AND. Ekinheavy_post+1 
     *.LT. Ubound(AEkinpost,2) .AND. Ekinheavy_post .GT. 
     *Lbound(AEkinpost,2)  ) THEN 
      AEkinpost(I_A_heavy_post,NINT(Ekinheavy_post)) = 
     *AEkinpost(I_A_heavy_post,NINT(Ekinheavy_post)) + 1 
      End If 
      IF (  I_A_light_post .LT. Ubound(ATKEpost,1) .AND. I_A_light_post 
     *.GT. Lbound(ATKEpost,1) .AND. TKE_post + 1 .LT. Ubound(ATKEpost,
     *2) .AND. TKE_post .GT. Lbound(ATKEpost,2)  ) THEN 
      ATKEpost(I_A_light_post,NINT(TKE_post)) = ATKEpost(I_A_light_post,
     *NINT(TKE_post)) + 1 
      End If 
      IF (  I_A_heavy_post .LT. Ubound(ATKEpost,1) .AND. I_A_heavy_post 
     *.GT. Lbound(ATKEpost,1) .AND. TKE_post + 1 .LT. Ubound(ATKEpost,
     *2) .AND. TKE_post .GT. Lbound(ATKEpost,2)  ) THEN 
      ATKEpost(I_A_heavy_post,NINT(TKE_post)) = ATKEpost(I_A_heavy_post,
     *NINT(TKE_post)) + 1 
      End If 
C     ' 
      ZISOPOST(I_A_Heavy_Post,I_Z_Heavy_post)= ZISOPOST(I_A_Heavy_Post,
     *I_Z_Heavy_post)+Racc 
      ZISOPOST(I_A_Light_Post,I_Z_Light_post)= ZISOPOST(I_A_Light_Post,
     *I_Z_Light_post)+Racc 
C     ' 
      IF (  J_Frag_light .LE. Ubound(JFRAGpost,3)  ) THEN 
      JFRAGpost(I_N_light_post,I_Z_light_post,J_Frag_light) = 
     *JFRAGpost(I_N_light_post,I_Z_light_post,J_Frag_light) + 1 
      End If 
      IF (  J_Frag_heavy .LE. Ubound(Jfragpost,3)  ) THEN 
      JFRAGpost(I_N_heavy_post,I_Z_heavy_post,J_Frag_heavy) = 
     *JFRAGpost(I_N_heavy_post,I_Z_heavy_post,J_Frag_heavy) + 1 
      End If 
C     ' 
C     /' Scission neutrons (for testing only,not considered in energy balance!) '/ 
C     /'If Rnd < 0.3 Then 
C     E_N_cm = PMaxwell(0.5) 
C     EN(Int(E_N_cm*1000)) = EN(Int(E_N_cm*1000)) + 1 
C     End If '/ 
C     ' 
C     ' 
C     /' Prompt gamma emission '/ 
C     ' 
C     '    Scope 
      Jfrag = J_frag_light 
      Einit = E_Final_Light 
C     '    Entrance energy above yrast line (energy after last prompt neutron) 
      Nspectrum = Einit*1000 
      IF (  Nspectrum .GT. 0 .AND. Nspectrum .LT. Ubound(Eentrance)  ) 
     *THEN 
      Eentrance(Nspectrum) = Eentrance(Nspectrum) + 1 
      End If 
C     ' 
C     '   E1 gammas 
      Erest = E_Final_Light 
C     ' 
      DO WHILE( Erest .GE. 0.1) 
      Eg = P_Egamma_low(I_Z_light,I_A_light,Erest) 
C     ' in MeV 
C     ' 
      xran = 1000*Eg 
C     ' in keV 
C     ' 
C     '  Accumulate E1 gammas 
      Nspectrum = NINT(xran) 
      IF (  Nspectrum .GT. 0  ) THEN 
      IF (  Nspectrum .LE. Ubound(Egamma)  ) THEN 
      Egamma(Nspectrum) = Egamma(Nspectrum) + 1 
C     ' 1 keV units 
      End If 
      Nglight = Nglight + 1 
      Ngtot = Ngtot + 1 
      Egtot1000 = Egtot1000 + xran 
C     ' in 1 keV units 
      End If 
      Erest = Erest - Eg 
C     '  in MeV units 
      END DO 
C     ' 
C     ' Rotational band (note that Erest is above the yrast line!) 
      DO J = Jfrag , 2 , -2 
      Eg = J*(J+1)/(2*IfragEff_light) - (J-2)*(J-1)/(2*IfragEff_light) 
      Nspectrum = Int(Eg*1000 + 0.5) 
C     ' 1 keV units 
      IF (  Nspectrum .GT. 0  ) THEN 
      Nglight = Nglight + 1 
      Ngtot = Ngtot + 1 
      Egtot1000 = Egtot1000 + Eg * 1000 
      IF (  Nspectrum .LE. Ubound(Egamma)  ) THEN 
      Egamma(Nspectrum) = Egamma(Nspectrum) + 1 
      End If 
      IF (  Nspectrum .LE. Ubound(EgammaE2)  ) THEN 
      EgammaE2(Nspectrum) = EgammaE2(Nspectrum) + 1 
      End If 
      End If 
      END DO 
C     ' 
C     ' 
C     ' 2nd (heavy) fragment 
C     ' 
      Jfrag = J_frag_heavy 
      Einit = E_Final_Heavy 
C     '    Entrance energy above yrast line (energy after last prompt neutron) 
      Nspectrum = Einit*1000 
      IF (  Nspectrum .GT. 0 .AND. Nspectrum .LT. Ubound(Eentrance)  ) 
     *THEN 
      Eentrance(Nspectrum) = Eentrance(Nspectrum) + 1 
      End If 
C     ' 
C     ' E1 gammas 
      Erest = E_Final_Heavy 
C     ' 
      DO WHILE( Erest .GE. 0.1) 
      Eg = P_Egamma_low(I_Z_heavy,I_A_heavy,Erest) 
C     ' in MeV 
      xran = 1000 * Eg 
C     ' 
C     ' Accumulate E1 gammas 
      Nspectrum = NINT(xran) 
      IF (  Nspectrum .GT. 0  ) THEN 
      IF (  Nspectrum .LE. Ubound(Egamma)  ) THEN 
      Egamma(Nspectrum) = Egamma(Nspectrum) + 1 
C     ' 1 keV units 
      End If 
      Ngheavy = Ngheavy + 1 
      Ngtot = Ngtot + 1 
      Egtot1000 = Egtot1000 + xran 
C     ' in 1 keV units 
      End If 
      Erest = Erest - Eg 
C     '  in MeV units 
      END DO 
C     ' 
C     ' Rotational band (note that Erest is above the yrast line!) 
      DO J = Jfrag , 2 , -2 
      Eg = J*(J+1)/(2*IfragEff_heavy) - (J-2)*(J-1)/(2*IfragEff_heavy) 
      Nspectrum = Int(Eg*1000 + 0.5) 
C     ' 1 keV units 
      IF (  Nspectrum .GT. 0  ) THEN 
      Ngheavy = Ngheavy + 1 
      Ngtot = Ngtot + 1 
      Egtot1000 = Egtot1000 + Eg * 1000 
      IF (  Nspectrum .LE. Ubound(Egamma)  ) THEN 
      Egamma(Nspectrum) = Egamma(Nspectrum) + 1 
      End If 
      IF (  Nspectrum .LE. Ubound(EgammaE2)  ) THEN 
      EgammaE2(Nspectrum) = EgammaE2(Nspectrum) + 1 
      End If 
      End If 
      END DO 
C     ' 
C     ' 
C     ' 
C     '    End Scope 
C     ' 
      IF (  Nglight .LE. Ubound(NgammaA,2)  )  NgammaA(I_A_light,
     *Nglight) = NgammaA(I_A_light,Nglight) + 1 
      IF (  Ngheavy .LE. Ubound(NgammaA,2)  )  NgammaA(I_A_heavy,
     *Ngheavy) = NgammaA(I_A_heavy,Ngheavy) + 1 
      IF (  Ngtot .LE. Ubound(Ngammatot)  )  
     *Ngammatot(Ngtot)=Ngammatot(Ngtot) + 1 
      IF (  NINT(Egtot1000) .LE. Ubound(Egammatot,1)  )  
     *Egammatot(NINT(Egtot1000))=Egammatot(NINT(Egtot1000)) + 1 
C     ' 
C     ' 
      Nglight = 0 
      Ngheavy = 0 
      Ngtot = 0 
      Egtot1000 = 0 
C     ' 
C     ' 
C     ' SkipEvent: 
C     ' Next  ' For ILoop = 1 To NEVTused 
C     ' 
      End  
C     ' 
C     ' 
C     /' Subroutines '/ 
C     ' 
      Include "BEexp.FOR" 
      Include "BEldmTF.FOR" 
      Include "ShellMO.FOR" 
C     ' 
C     ' 
      INTEGER*4 FUNCTION U_Valid(I_Z,I_A)
      IMPLICIT NONE
      INTEGER*4 I_Z
      INTEGER*4 I_A
      INTEGER*4  Ivalid
      Ivalid = 1 
      IF (  I_A / I_Z .LT. 210.E0/90.E0 .OR. I_A / I_Z .GT. 
     *250.E0/90.E0  ) THEN 
      Ivalid = 0 
      End If 
      IF (  I_Z .LT. 76 .OR. I_Z .GT. 120  ) THEN 
      Ivalid = 0 
      End If 
      U_Valid = Ivalid 
      U_Valid = 1 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION U_Delta_S0(I_Z,I_A)
      IMPLICIT NONE
      INTEGER*4 I_Z
      INTEGER*4 I_A
C     ' I_Z and I_A refer to the fissioning nucleus90 22 
      REAL*4  Delta
      Delta = 0.3 
      IF (  I_Z .EQ. 90 .AND. I_A .EQ. 228  )  Delta = 0.70 
C     'N 
      IF (  I_Z .EQ. 90 .AND. I_A .EQ. 230  )  Delta = 0.6 
C     'N 
      IF (  I_Z .EQ. 90 .AND. I_A .EQ. 233  )  Delta = 0.3 
C     ' 
      IF (  I_Z .EQ. 91 .AND. I_A .EQ. 228  )  Delta = 0.65 
C     ' 
      IF (  I_Z .EQ. 92 .AND. I_A .EQ. 233  )  Delta = 0.5 
C     'N 
      IF (  I_Z .EQ. 92 .AND. I_A .EQ. 234  )  Delta = 0.6 
C     'N 
      IF (  I_Z .EQ. 92 .AND. I_A .EQ. 235  )  Delta = 0.3 
      IF (  I_Z .EQ. 92 .AND. I_A .EQ. 236  )  Delta = 0.3 
C     'N 
      IF (  I_Z .EQ. 92 .AND. I_A .EQ. 237  )  Delta = 0.3 
      IF (  I_Z .EQ. 92 .AND. I_A .EQ. 238  )  Delta = 0.3 
      IF (  I_Z .EQ. 92 .AND. I_A .EQ. 239  )  Delta = 0.1 
C     ' 
      IF (  I_Z .EQ. 93 .AND. I_A .EQ. 238  )  Delta = -0.1 
C     'N 
C     ' 
      IF (  I_Z .EQ. 94 .AND. I_A .EQ. 240  )  Delta = -0.1 
C     'N 
      IF (  I_Z .EQ. 94 .AND. I_A .EQ. 241  )  Delta = -0.5 
C     'N 
      IF (  I_Z .EQ. 94 .AND. I_A .EQ. 242  )  Delta = -0.15 
C     'N 
      IF (  I_Z .EQ. 94 .AND. I_A .EQ. 243  )  Delta = -0.45 
C     'N 
      IF (  I_Z .EQ. 94  )  Delta = 0.25 
C     ' 
      IF (  I_Z .EQ. 95 .AND. I_A .EQ. 242  )  Delta = -0.35 
C     'N 
C     ' 
      IF (  I_Z .EQ. 95 .AND. I_A .EQ. 243  )  Delta = -0.1 
C     'N 
C     ' 
      IF (  I_Z .EQ. 95 .AND. I_A .EQ. 244  )  Delta = -0.1 
C     ' 
      IF (  I_Z .EQ. 96 .AND. I_A .EQ. 244  )  Delta = 0 
C     'N 
      IF (  I_Z .EQ. 96 .AND. I_A .EQ. 246  )  Delta = -0.2 
C     'N 
      U_Delta_S0 = Delta 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION Getyield(E_rel,E_ref,T_low,T_high)
      IMPLICIT NONE
      REAL*4 E_rel
      REAL*4 E_ref
      REAL*4 T_low
      REAL*4 T_high
C     /' Erel: Energy relative to the barrier '/ 
C     /' T_low: Effective temperature below barrier '/ 
C     /' T_high: Effective temperature above barrier '/ 
      REAL*4  Exp1
      REAL*4  Yield
C     ' 
      Exp1 = E_rel/T_low - E_ref/0.4 
C     ' energy far below barrier 
C     ' Subtraction of E_ref/0.4 to prevent numerical problems. 
      IF (  Exp1 .LT. -50  ) THEN 
      Yield = 0 
      Else 
      Yield = Exp(E_rel / T_high - E_ref/0.4) * 1.E0 / (1.E0 + 
     *exp(-E_rel/ (T_high*T_low/(T_high-T_low) ) ) ) 
      End If 
C     '   print  E_rel,T_high,E_ref,Yield 
      Getyield = Yield 
C     ' 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION F1(Z_S_A)
      IMPLICIT NONE
      REAL*4 Z_S_A
C     /' Fit to the lower part of the data '/ 
      REAL*4  Result
      Result = exp(-9.05E0 + 4.58E0 * Log(Z_S_A/2.3E0)) 
      F1 = Result 
      END
      REAL*4 FUNCTION F2(Z_S_A)
      IMPLICIT NONE
      REAL*4 Z_S_A
C     /' Fit to the upper part of the data '/ 
      REAL*4  Result
      Result = exp(12.08E0 - 3.27E0 * Log(Z_S_A/2.3E0)) 
      F2 = Result 
      END
C     ' 
      REAL*4 FUNCTION Masscurv(Z,A,RI,kappa)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 RI
      REAL*4 kappa
C     /'  Fit to  Data of Fig. 7 of                                             '/ 
C     /'  "Shell effect in the symmetric-modal fission of pre-actinide nuclei"  '/ 
C     /'  S. I. Mulgin,K.-H. Schmidt,A. Grewe,S. V. Zhdanov                  '/ 
C     /'  Nucl. Phys. A 640 (1998) 375 
C     /' (From fit of the width of the mass distributions.) '/                                         '/ 
      REAL*4  Result1,Result2,Result
      REAL*4  Z_square_over_A
      REAL*4  ZsqrA
      REAL*4 F1 
      REAL*4 F2 
C     ' 
      Z_square_over_A = Z**2/A 
      ZsqrA = Z_square_over_A * (1.E0 - kappa * RI**2) / (1.E0 - kappa 
     ** ((226.E0 - 2.E0*91.E0)/226.E0)**2) 
C     ' 
      Result1 = F1(ZsqrA) 
      Result2 = F2(ZsqrA) 
      Result = Min(Result1,Result2) 
      Masscurv = Result 
C     ' 
      END
C     ' 
      REAL*4 FUNCTION Masscurv1(Z,A,RI,kappa)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 RI
      REAL*4 kappa
C     /'  Fit to  Data of Fig. 7 of                                             '/ 
C     /'  "Shell effect in the symmetric-modal fission of pre-actinide nuclei"  '/ 
C     /'  S. I. Mulgin,K.-H. Schmidt,A. Grewe,S. V. Zhdanov                  '/ 
C     /'  Nucl. Phys. A 640 (1998) 375 
C     /' (The left part assumed to be valid for the yields of the fission channels.) '/                                         '/ 
      REAL*4  Result1,Result2,Result
      REAL*4  Z_square_over_A
      REAL*4  ZsqrA
      REAL*4 F1 
      REAL*4 F2 
C     ' 
      Z_square_over_A = Z**2/A 
      ZsqrA = Z_square_over_A * (1.E0 - kappa * RI**2) / (1.E0 - kappa 
     ** ((226.E0 - 2.E0*91.E0)/226.E0)**2) 
C     ' 
      Result1 = F1(ZsqrA) 
C     '  Result2 = F2(ZsqrA) 
C     '  Result = Min(Result1,Result2) 
      Masscurv1 = Result1 
C     ' 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION De_Saddle_Scission(Z_square_over_Athird,
     *ESHIFTSASCI)
      IMPLICIT NONE
      REAL*4 Z_square_over_Athird
      REAL*4 ESHIFTSASCI
C     /' Energy release between saddle and scission '/ 
C     /' M. Asghar,R. W. Hasse,J. Physique C 6 (1984) 455 '/ 
      REAL*4  Result
      Result = (31.E0 - 11.E0) / (1550.E0 - 1300.E0) * 
     *(Z_square_over_Athird - 1300.E0 + ESHIFTSASCI) + 11.E0 
C     ' This formula with ESHIFTSASCI = 0 is the parameterisation of the results 
C     ' of Ashgar and Hasse,JPC 6 (1984) 455,see 
C     ' F. Rejmund,A. V. Ignatyuk,A. R. Junghans,K.-H. Schmidt 
C     ' Nucl. Phys. A 678 (2000) 215 
      Result = max(Result,0.0) 
      De_Saddle_Scission = Result 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION TEgidy(A,DU,Fred)
      IMPLICIT NONE
      REAL*4 A
      REAL*4 DU
      REAL*4 Fred
C     /' Temperature parameter of the constant-temperature formula for the 
C     nuclear level density. 
C     Input parameters: A = Mass number of nucleus 
C     DU = Shell effect (corrected for pairing:P=0 for odd-A nuclei) 
C     From "Correlations between the nuclear level density parameters" 
C     Dorel Bucurescu,Till von Egidy 
C     Phys. Rev. C 72 (2005) 067304    and 
C     "Systematics of nuclear level density parameters" 
C     Dorel Bucurescu,Till von Egidy 
C     J. Phys. G: Nucl. Part. Phys. 31 (2005) S1675 and 
C     "Systematics of nuclear level density parameters" 
C     Till von Egidy,Dorel Bucurescu 
C     Phys. Rev. C 72 (2005) 044311 '/ 
      REAL*4  Temp_smooth,Temp,T_Fac
C     ' Temp_smooth = 17.45E0 / (A^0.666667E0) 
C     ' Temp = (17.45E0 - 0.51E0 * DU + 0.051 * DU^2) / (A^0.666667E0) 
      Temp_smooth = 1.0 / (0.0570 * A**0.6666667) 
      Temp = 1.0 / ( (0.0570 + 0.00193*DU) * A**0.6666667) 
C     ' from  PRC 80 (2009) 054310 
      T_Fac = Temp / Temp_smooth 
      Temp = Temp * Fred 
C     /' (For influence of deformation) '/ 
      TEgidy = Temp 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION TRusanov(E,A)
      IMPLICIT NONE
      REAL*4 E
      REAL*4 A
C     /' Fermi-gas level density,parameterisation of Rusanov et al. '/ 
      IF (  E >0  ) THEN 
      TRusanov = SQRT(E / (0.094E0 * A) ) 
      Else 
      TRusanov = 0.0 
      End If 
      END
C     ' 
      REAL*4 FUNCTION LyMass(Z,A,beta)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 beta
C     ' 
C     /' liquid-drop mass,Myers & Swiatecki,Lysekil,1967  '/ 
C     /' pure liquid drop,without pairing and shell effects '/ 
C     ' 
C     /' On input:    Z     nuclear charge of nucleus        '/ 
C     /'              N     number of neutrons in nucleus    '/ 
C     /'              beta  deformation of nucleus           '/ 
C     /' On output:   binding energy of nucleus              '/ 
C     ' 
      REAL*4  pi
      PARAMETER (pi=3.14159)
      REAL*4  N
      REAL*4  alpha
      REAL*4  XCOM,XVS,XE,EL
C     ' 
      N = A - Z 
      alpha = SQRT(5.E0/(4.E0*pi)) * beta 
      XCOM = 1.E0 - 1.7826E0 * ((A - 2.E0*Z)/A)**2 
C     /' factor for asymmetry dependence of surface and volume term '/ 
      XVS = - XCOM * (15.4941E0*A                    - 
     *17.9439E0*A**(2.E0/3.E0)*(1.E0+0.4E0*Alpha**2)) 
C     /' sum of volume and surface energy '/ 
      XE = Z**2 * (0.7053E0/A**(1.E0/3.E0)*(1.E0-0.2E0*Alpha**2)        
     *           - 1.1529E0/A) 
      EL = XVS + XE 
C     /'   EL = EL + LyPair(Z,A); '/ 
      LyMass = EL 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION LyPair(Z,A)
      IMPLICIT NONE
      INTEGER*4 Z
      INTEGER*4 A
C     /' Calculates pairing energy '/ 
C     /' odd-odd nucleus:   Lypair = 0 '/ 
C     /' even-odd nucleus:  Lypair = -12/sqr(A) '/ 
C     /' even-even nucleus: Lypair = -2*12/sqr(A) '/ 
      REAL*4  E_PAIR
C     ' 
      E_PAIR = - 12.E0 / SQRT(REAL(A)) * ( MOD((Z+1) , 2) + MOD((A-Z+1) 
     *, 2)) 
C     ' 
      Lypair = E_PAIR 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION TFPair(Z,A)
      IMPLICIT NONE
      INTEGER*4 Z
      INTEGER*4 A
C     /' Pairing energy from Thomas-Fermi model of Myers and Swiatecki '/ 
C     /' Shifted that TFPair is zero for odd-odd nuclei '/ 
      INTEGER*4  N
      REAL*4  E_Pair
      N = A - Z 
      IF (   MOD(Z,2)  .EQ. 0 .AND.  MOD(N,2)  .EQ. 0  ) THEN 
C     /' even-even '/ 
      E_Pair = - 4.8E0 / Z**0.333333E0 - 4.8E0 / N**0.333333E0 + 6.6E0 
     */ A**0.666666E0 
      END IF 
      IF (   MOD(Z,2)  .EQ. 0 .AND.  MOD(N,2)  .EQ. 1  ) THEN 
C     /' even Z,odd N '/ 
      E_Pair = - 4.8E0 / Z**0.333333E0 + 6.6E0 / A**0.666666E0 
      END IF 
      IF (   MOD(Z,2)  .EQ. 1 .AND.  MOD(N,2)  .EQ. 0  ) THEN 
C     /' odd Z,even N '/ 
      E_Pair = - 4.8E0 / N**0.333333E0 + 6.6E0 / A**0.666666E0 
      END IF 
      IF (   MOD(Z,2)  .EQ. 1 .AND.  MOD(N,2)  .EQ. 1  ) THEN 
C     /' odd N,odd N '/ 
      E_Pair = 0.0 
      END IF 
      TFPair = E_Pair 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION Pmass(Z,A,beta)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 beta
C     /' Liquid-drop model of Pearson,2001 '/ 
      REAL*4  N,EA,BE
      REAL*4  avol
      DATA avol/-15.65/
      REAL*4  asf
      DATA asf/17.63/
      REAL*4  r0
      DATA r0/1.233/
      REAL*4  asym
      DATA asym/27.72/
      REAL*4  ass
      DATA ass/-25.60/
      REAL*4  alpha
      REAL*4  pi
      PARAMETER (pi=3.14159)
C     ' 
      N = A - Z 
      alpha = SQRT(5.E0/(4.E0*pi)) * beta 
      EA = avol + asf * A**(-0.333333)*(1.E0+0.4E0*Alpha**2) + 0.6E0 * 
     *1.44E0 * Z**2 / (A**1.333333 * r0 )*(1.E0-0.2E0*Alpha**2) + (asym 
     *+ ass * A**(-0.333333)) * (N-Z)**2 / A**2 
      BE = EA * A 
      Pmass = BE 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION FEDEFOP(Z,A,beta)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 beta
C     /' According to liquid-drop model of Pearson 2001 '/ 
      REAL*4  asf
      DATA asf/17.63/
      REAL*4  r0
      DATA r0/1.233/
      REAL*4  N,Alpha
      REAL*4  pi
      PARAMETER (pi=3.14159)
C     ' 
      N = A - Z 
      alpha = SQRT(5.E0/(4.E0*pi)) * beta 
      FEDEFOP = asf * A**(0.666667)*(0.4E0*Alpha**2) - 0.6E0 * 1.44E0 * 
     *Z**2 / (A**0.333333 * r0 )*(0.2E0*Alpha**2) 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION FEDEFOLys(Z,A,beta)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 beta
      REAL*4 LYMASS 
      FEDEFOLys = Lymass(Z,A,beta) - Lymass(Z,A,0.0) 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION LDMass(Z,A,beta)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 beta
      REAL*4  N,BEtab
      REAL*4 LYMASS 
      REAL*4 FEDEFOLYS 
      REAL*4 BEldmTF 
      REAL*4 BEexp 
      N = A - Z 
      BEtab = BEldmTF(NINT(N),NINT(Z)) + 2.0 * 12.0 / SQRT(REAL(A)) - 
     *0.00001433*Z**2.39 
C     ' The values in BEtab are the negative binding energies! 
C     ' Pairing in Thomas Fermi masses is zero for Z,N even ! 
      IF (  BEtab .EQ. 0.0  ) THEN 
      BEtab = Lymass(Z,A,0.0) 
C     '         Print "Warning: Binding energy of Z=";Z;",A=";A;" not in mass table,";                         " replaced by LYMASS" 
C     '         Print "I_Mode = ";I_Mode 
      End If 
      LDMASS = BEtab + FEDEFOLys(Z,A,beta) 
      END
C     ' 
      REAL*4 FUNCTION AME2012(IZ,IA)
      IMPLICIT NONE
      INTEGER*4 IZ
      INTEGER*4 IA
C     ' Masses from the 2003 mass evaluation,complemented by TF masses 
C     ' and Lysekil masses. 
      REAL*4  BEexpval
      REAL*4  Z,A,N
      INTEGER*4  INeu
      REAL*4 LYPAIR 
      REAL*4 U_SHELL 
      REAL*4 LDMASS 
      REAL*4 BEexp 
      INeu = IA - IZ 
      A = REAL(IA) 
      Z = REAL(IZ) 
      N = A - Z 
      BEexpval = BEexp(INeu,IZ) 
      IF (  BEexpval .GT. -1.E10  ) THEN 
      AME2012 = BEexpval 
      Else 
      AME2012 = Ldmass(Z,A,0.0) + U_SHELL(IZ,IA) + Lypair(IZ,IA) 
      End If 
      END
C     ' 
      REAL*4 FUNCTION U_SHELL(Z,A)
      IMPLICIT NONE
      INTEGER*4 Z
      INTEGER*4 A
      INTEGER*4  N
      REAL*4  Res
      REAL*4 ShellMO 
      N = A - Z 
      Res = ShellMO(N,Z) 
      IF (  Res .GT. 0.0  )  Res = 0.3 * Res 
C     ' KHS (12. Feb. 2012) 
C     '      ' The positive shell effects for deformed nuclei seem to be too positive 
C     ' This gives too many high-energetic prompt neutrons. 
      U_SHELL = Res 
      END
C     ' 
      REAL*4 FUNCTION U_SHELL_exp(IZ,IA)
      IMPLICIT NONE
      INTEGER*4 IZ
      INTEGER*4 IA
      REAL*4  Res
      REAL*4  Z,A
      REAL*4 LDMASS 
      REAL*4 LYPAIR 
      REAL*4 AME2012 
      Z = REAL(IZ) 
      A = REAL(IA) 
C     '   Res = 2.0 * ( AME2012(IZ,IA) - Lypair(IZ,IA) - LDMass(Z,A,0.0) )    '          - 0.25 * ( AME2012(IZ,IA-1) - Lypair(IZ,IA-1) - LDMass(Z,A-1.0,0.0) )    '          - 0.25 * ( AME2012(IZ,IA+1) - Lypair(IZ,IA+1) - LDMass(Z,A+1.0,0.0) )    '          - 0.25 * ( AME2012(IZ+1,IA+1) - Lypair(IZ+1,IA+1) - LDMass(Z+1.0,A+1.0,0.0) )    '          - 0.25 * ( AME2012(IZ-1,IA-1) - Lypair(IZ-1,IA-1) - LDMass(Z-1.0,A-1.0,0.0) ) 
      Res = 0.5 * ( AME2012(IZ,IA) - Lypair(IZ,IA) - LDMass(Z,A,0.0) ) 
     *+ 0.125 * ( AME2012(IZ,IA-1) - Lypair(IZ,IA-1) - LDMass(Z,A-1.0,
     *0.0) ) + 0.125 * ( AME2012(IZ,IA+1) - Lypair(IZ,IA+1) - LDMass(Z,
     *A+1.0,0.0) ) + 0.125 * ( AME2012(IZ+1,IA+1) - Lypair(IZ+1,IA+1) - 
     *LDMass(Z+1.0,A+1.0,0.0) ) + 0.125 * ( AME2012(IZ-1,IA-1) - 
     *Lypair(IZ-1,IA-1) - LDMass(Z-1.0,A-1.0,0.0) ) 
      U_SHELL_exp = Res 
      END
C     ' 
      REAL*4 FUNCTION U_SHELL_EO_exp(IZ,IA)
      IMPLICIT NONE
      INTEGER*4 IZ
      INTEGER*4 IA
C     ' Returns experimental shell and even-odd staggering 
      REAL*4  Res
      REAL*4  Z,A
      REAL*4 LDMASS 
      REAL*4 LYPAIR 
      REAL*4 AME2012 
      Z = REAL(IZ) 
      A = REAL(IA) 
      Res = AME2012(IZ,IA) - LDMass(Z,A,0.0) 
      U_SHELL_EO_exp = Res 
      END
C     ' 
C     ' 
C     ' 
      REAL*4 FUNCTION U_MASS(Z,A)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
C     /' LD + congruence energy + shell (no pairing) '/ 
      REAL*4  BE
      REAL*4 U_SHELL 
      REAL*4 LDMASS 
      IF (  Z .LT. 0 .OR. A .LT. 0  ) THEN 
C     '       Print "U_Mass: Z,A",Z,A 
      End If 
      BE = Ldmass(Z,A,0.0) + U_SHELL(NINT(Z),NINT(A)) 
C     '    BE = AME2012(Cint(Z),Cint(A)) - Lypair(Z,A) 
C     '    BE = Lymass(Z,A,0.0) + U_Shell(CInt(Z),CInt(A)) 
C     '    BE = Lymass(Z,A,0.0) 
      U_MASS = BE 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION ECOUL(Z1,A1,beta1,Z2,A2,beta2,d)
      IMPLICIT NONE
      REAL*4 Z1
      REAL*4 A1
      REAL*4 beta1
      REAL*4 Z2
      REAL*4 A2
      REAL*4 beta2
      REAL*4 d
C     ' 
C     /' Coulomb potential between two nuclei                    '/ 
C     /' surfaces are in a distance of d                         '/ 
C     /' in a tip to tip configuration                           '/ 
C     ' 
C     /' approximate formulation                                 '/ 
C     /' On input: Z1      nuclear charge of first nucleus       '/ 
C     /'           A1      mass number of irst nucleus   '/ 
C     /'           beta1   deformation of first nucleus          '/ 
C     /'           Z2      nuclear charge of second nucleus      '/ 
C     /'           A2      mass number of second nucleus  '/ 
C     /'           beta2   deformation of second nucleus         '/ 
C     /'           d       distance of surfaces of the nuclei    '/ 
C     ' 
      REAL*4  N1,N2,recoul
      REAL*4  dtot
      REAL*4  r0
      DATA r0/1.16/
C     ' 
      N1 = A1 - Z1 
      N2 = A2 - Z2 
      dtot = r0 *( (Z1+N1)**0.3333333E0 * (1.E0+0.6666667E0*beta1)      
     *        + (Z2+N2)**0.3333333E0 * (1.E0+0.6666667E0*beta2) ) + d 
      REcoul = Z1 * Z2 * 1.44E0 / dtot 
C     ' 
      ECOUL = REcoul 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION beta_light(Z,betaL0,betaL1)
      IMPLICIT NONE
      INTEGER*4 Z
      REAL*4 betaL0
      REAL*4 betaL1
C     /' Deformation of light fission fragment for S1 and S2 '/ 
C     /' Systematic correlation Z vs. beta for deformed shells '/ 
C     /' Z of fission fragment '/ 
      REAL*4  beta
      beta = (Z - betaL0) * betaL1/20.E0 
      beta_light = beta 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION beta_heavy(Z,betaH0,betaH1)
      IMPLICIT NONE
      INTEGER*4 Z
      REAL*4 betaH0
      REAL*4 betaH1
C     /' Deformation of heavy fission fragment for S2 '/ 
C     /' Systematic correlation Z vs. beta for deformed shells '/ 
C     /' Z of fission fragment '/ 
      REAL*4  beta
      beta = (Z - betaH0) * betaH1/20.E0 
      beta_heavy = beta 
      END
C     ' 
C     ' 
C     ' 
      REAL*4 FUNCTION Z_equi(ZCN,A1,A2,beta1,beta2,d,Imode,POLARadd,
     *POLARfac)
      IMPLICIT NONE
      INTEGER*4 ZCN
      INTEGER*4 A1
      INTEGER*4 A2
      REAL*4 beta1
      REAL*4 beta2
      REAL*4 d
      INTEGER*4 Imode
      REAL*4 POLARadd
      REAL*4 POLARfac
C     /' Determines the minimum potential of the scission-point configuration 
C     represented by two deformed nuclei divided by a tip distance d. 
C     A1,A2,beta1,beta2,d are fixed,Z1 is searched for and returned on output.  '/ 
C     ' 
C     /' ZCN: Z of fissioning nucleus '/ 
C     /' A1: A of first fission fragment '/ 
C     /' A2: A of second fission fragment '/ 
C     /' beta1: deformation of first fission fragment '/ 
C     /' beta2: deformation of second fission fragment '/ 
C     /' d: tip distance '/ 
C     ' 
      REAL*4  RZ_equi
      REAL*4  RA1,RA2,RZCN,RACN
      REAL*4  Z1UCD,Z2UCD
      REAL*4  re1,re2,re3,eps1,eps2,DZ_Pol
C     /' help variables '/ 
      REAL*4 ECOUL 
      REAL*4 LYMASS 
C     ' 
      RA1 = REAL(A1) 
      RA2 = REAL(A2) 
      RZCN = REAL(ZCN) 
      RACN = RA1 + RA2 
      Z1UCD = RA1 / (RA1 + RA2) * RZCN 
      Z2UCD = RZCN - Z1UCD 
      re1 = LyMass( Z1UCD-1.E0,RA1,beta1 ) + LyMass( Z2UCD+1.E0,RA2,
     *beta2 ) + ECoul( Z1UCD-1.E0,RA1,beta1,Z2UCD+1.E0,RA2,beta2,d ) 
      re2 = LyMass( Z1UCD,RA1,beta1) + LyMass( Z2UCD,RA2,beta2) + 
     *ECoul( Z1UCD,RA1,beta1,Z2UCD,RA2,beta2,d ) 
      re3 = LyMass( Z1UCD+1.E0,RA1,beta1 ) + LyMass( Z2UCD-1.E0,RA2,
     *beta2 ) + ECoul( Z1UCD+1.E0,RA1,beta1,Z2UCD-1.E0,RA2,beta2,d ) 
      eps2 = ( re1 - 2.E0*re2 + re3 ) / 2.E0 
      eps1 = ( re3 - re1 ) / 2.E0 
      DZ_Pol = -eps1 / ( 2.E0 * eps2 ) 
C     ' 
      IF (  DZ_Pol .GT. 2 .OR. DZ_Pol .LT. -2  )  DZ_Pol = 0 
C     ' 
      IF (  Imode .GT. 0  ) THEN 
C     /' Purely empirical enhancement of charge polarization '/ 
      DZ_POL = DZ_POL * POLARfac + POLARadd 
      End If 
C     ' 
      RZ_equi = Z1UCD + DZ_POL 
      Z_equi = RZ_equi 
      END
C     ' 
C     ' 
      SUBROUTINE Beta_opt_light(A1,A2,Z1,Z2,d,beta2_imposed,beta1_opt)
      IMPLICIT NONE
      REAL*4 A1
      REAL*4 A2
      REAL*4 Z1
      REAL*4 Z2
      REAL*4 d
      REAL*4 beta2_imposed
      REAL*4 beta1_opt
C     /' Determines the optimum deformation of the light fragment when the deformation of the 
C     heavy fragment is imposed. '/ 
C     ' 
      REAL*4  beta1,dbeta1,beta1_prev,beta1_next
      REAL*4  Uguess,Uplus,Uminus,Uprev,Unext
      INTEGER*4  I
      REAL*4 ECOUL 
      REAL*4 LYMASS 
C     ' 
C     /' List('Beta_opt_light called with '); 
C     List(A1,A2,Z1,Z2,d,beta2_imposed,beta1_opt); 
C     DCL Byes Bit(1) aligned; 
C     Call GPYES('Continue',Byes); '/ 
      beta1 = 0.5 
      dbeta1 = 0.01 
      Uguess = LyMass(Z1,A1,beta1) + Lymass(Z2,A2,beta2_imposed) + 
     *ECoul(Z1,A1,beta1,Z2,A2,beta2_imposed,d) 
      Uplus = LyMass(Z1,A1,beta1 + dbeta1) + Lymass(Z2,A2,
     *beta2_imposed) + ECoul(Z1,A1,beta1 + dbeta1,Z2,A2,beta2_imposed,
     *d) 
      Uminus = LyMass(Z1,A1,beta1 - dbeta1) + Lymass(Z2,A2,
     *beta2_imposed) + ECoul(Z1,A1,beta1 - dbeta1,Z2,A2,beta2_imposed,
     *d) 
      IF (  Uplus .GT. Uguess .AND. Uminus .GT. Uguess  ) THEN 
      beta1_opt = beta1 
      Else 
      IF (  Uplus .LT. Uguess  )  dbeta1 = 0.01 
      IF (  Uminus .LT. Uguess  )  dbeta1 = -0.01 
      Unext = Uguess 
      beta1_next = beta1 
      DO I = 1 , 10000 
      beta1_prev = beta1_next 
      Uprev = Unext 
      beta1_next = beta1_prev + dbeta1 
      Unext = LyMass(Z1,A1,beta1_next) + Lymass(Z2,A2,beta2_imposed) + 
     *ECoul(Z1,A1,beta1_next,Z2,A2,beta2_imposed,d) 
      IF (  Unext .GE. Uprev  )  Exit 
      END DO 
      beta1_opt = beta1_prev 
      END IF 
C     ' 
      END
C     ' 
C     ' 
      SUBROUTINE Beta_Equi(A1,A2,Z1,Z2,d,beta1prev,beta2prev,beta1opt,
     *beta2opt)
      IMPLICIT NONE
      REAL*4 A1
      REAL*4 A2
      REAL*4 Z1
      REAL*4 Z2
      REAL*4 d
      REAL*4 beta1prev
      REAL*4 beta2prev
      REAL*4 beta1opt
      REAL*4 beta2opt
C     /' Determines the minimum potential of the scission-point configuration 
C     represented by two deformed nuclei,divided by a tip distance d. 
C     A1,A2,Z1,Z2,d are fixed,beta1 and beta2 are searched for and returned on output '/ 
C     ' 
      INTEGER*4  B_analytical
      DATA B_analytical/1/
C     ' Switch to use the analytical approximation 
C     ' that replaces the long numerical calculation. 
      REAL*4  x,y,xcoul
      REAL*4  xcoul236U
      DATA xcoul236U/1369.64/
C     ' 
      REAL*4  beta1,beta2
C     ' 
C     '      Dim As Double U,Uprev,Ulast,Ubest,Uopt 
      REAL*4  U,Uprev,Ulast,Ubest,Uopt
C     ' 
C     '      Dim As Double sbeta1,sbeta2 
      REAL*4  sbeta1,sbeta2
C     ' 
      INTEGER*4  N,N1,N2,Nopt
C     ' 
C     '      Dim As Double eps = 5.E-4 
      REAL*4  eps
      DATA eps/5.E-4/
C     ' 
      INTEGER*4  I
      REAL*4 LYMASS 
      REAL*4 ECOUL 
C     ' 
      IF (  B_analytical .EQ. 0  ) THEN 
C     ' Numerical algorithm 
C     ' 
      beta1 = beta1prev 
      beta2 = beta2prev 
      Uprev = LyMass(Z1,A1,beta1) + LyMass(Z2,A2,beta2) + ECoul(Z1,A1,
     *beta1,Z2,A2,beta2,d) 
      Uopt = Uprev 
C     ' 
C     /' Test slope of variation of U '/ 
      beta1 = beta1prev + eps 
      U = 1.E30 
C     ' 
      beta2 = beta2prev 
C     '     For beta2 = beta2prev to 0 Step -eps 
      DO I = 1 , Int(beta2prev/eps) 
      beta2 = beta2 - eps 
      Ulast = U 
      U = LyMass(Z1,A1,beta1) + LyMass(Z2,A2,beta2) + ECoul(Z1,A1,beta1,
     *Z2,A2,beta2,d) 
      IF (  U .GT. Ulast  ) THEN 
      Exit 
      Else 
      Ubest = U 
      END IF 
      END DO 
      IF (  Ubest .LT. Uopt  ) THEN 
      Uopt = Ubest 
      sbeta1 = eps 
      sbeta2 = -eps 
      END IF 
C     ' 
      U = 1.E30 
      beta2 = beta2prev 
C     '   For beta2 = beta2prev To 1 Step eps 
      DO I = 1 , Int((1 - beta2prev)/eps) 
      beta2 = beta2 + eps 
      Ulast = U 
      U = LyMass(Z1,A1,beta1) + LyMass(Z2,A2,beta2) + ECoul(Z1,A1,beta1,
     *Z2,A2,beta2,d) 
      IF (  U .GT. Ulast  ) THEN 
      Exit 
      Else 
      Ubest = U 
      END IF 
      END DO 
      IF (  Ubest .LT. Uopt  ) THEN 
      Uopt = Ubest 
      sbeta1 = eps 
      sbeta2 = eps 
      End If 
C     ' 
      beta1 = beta1prev - eps 
      U = 1.E30 
      beta2 = beta2prev 
C     '   For beta2 = beta2prev To 0 Step -eps 
      DO I = 1 , Int(beta2prev/eps) 
      beta2 = beta2 - eps 
      Ulast = U 
      U = LyMass(Z1,A1,beta1) + LyMass(Z2,A2,beta2) + ECoul(Z1,A1,beta1,
     *Z2,A2,beta2,d) 
      IF (  U .GT. Ulast  ) THEN 
      Exit 
      Else 
      Ubest = U 
      End If 
      END DO 
      IF (  Ubest .LT. Uopt  ) THEN 
      Uopt = Ubest 
      sbeta1 = -eps 
      sbeta2 = -eps 
      END IF 
C     ' 
      U = 1.E30 
      beta2 = beta2prev 
C     '   For beta2 = beta2prev To 1 Step eps 
      DO I = 1 , Int((1-beta2prev)/eps) 
      beta2 = beta2 + eps 
      Ulast = U 
      U = LyMass(Z1,A1,beta1) + LyMass(Z2,A2,beta2) + ECoul(Z1,A1,beta1,
     *Z2,A2,beta2,d) 
      IF (  U .GT. Ulast  ) THEN 
      Exit 
      Else 
      Ubest = U 
      END IF 
      END DO 
      IF (  Ubest .LT. Uopt  ) THEN 
      Uopt = Ubest 
      sbeta1 = -eps 
      sbeta2 = eps 
      END IF 
C     ' 
C     ' 
      Ubest = Lymass(Z1,A1,beta1prev) + Lymass(Z2,A2,beta2prev) + 
     *ECoul(Z1,A1,beta1prev,Z2,A2,beta2prev,d) 
      U = Lymass(Z1,A1,beta1prev+REAL(sbeta1)) + Lymass(Z2,A2,
     *beta2prev+REAL(sbeta2)) + ECoul(Z1,A1,beta1prev+sbeta1,Z2,A2,
     *beta2prev+REAL(sbeta2),d) 
C     ' 
C     '   L1: 
      DO N = 1 , 1000 
C     ' 
C     '   L2: 
      DO N1 = 1 , N 
      N2 = N-N1 
      beta1 = beta1prev + sbeta1*N1 
      beta2 = beta2prev + sbeta2*N2 
      U = LyMass(Z1,A1,beta1) + LyMass(Z2,A2,beta2) + ECoul(Z1,A1,beta1,
     *Z2,A2,beta2,d) 
      IF (  U .LT. Ubest  ) THEN 
      Ubest = U 
      beta1opt = beta1 
      beta2opt = beta2 
      Nopt = N 
      END IF 
      END DO 
      IF (  N-Nopt .GT. 2  )  Exit 
      END DO 
C     ' 
C     ' 
      Else 
C     ' Analytical approximation 
C     ' Must be adapted if the relevant parameters of GEF are modified! 
      xcoul = (Z1 + Z2)**2 / (A1 + A2)**(1.0/3.0) 
      x = (Z1 / (Z1 + Z2))**(xcoul/xcoul236U) 
      y = 1.2512E-4 + 0.00122851*x - 0.00267707*x**2 + 0.00372901*x**3 
     *- 0.00219903*x**4 
      beta1opt = y * xcoul 
C     ' 
      x = (Z2 / (Z1 + Z2))**(xcoul/xcoul236U) 
      y = 1.2512E-4 + 0.00122851*x - 0.00267707*x**2 + 0.00372901*x**3 
     *- 0.00219903*x**4 
      beta2opt = y * xcoul 
C     ' 
      End If 
C     ' 
      END
C     ' 
C     ' 
      SUBROUTINE Eva(Ilh,Z_CN,A_CN,E_INIT,T,Z_RES,A_RES,E_FINAL,
     *Array_En(),Array_Tn())
      IMPLICIT NONE
      INTEGER*4 Ilh
      REAL*4 Z_CN
      REAL*4 A_CN
      REAL*4 E_INIT
      REAL*4 T
      REAL*4 Z_RES
      REAL*4 A_RES
      REAL*4 E_FINAL
      REAL*4 Array_En()
      REAL*4 Array_Tn()
C     ' 
C     /' Z_CN,A_CN,E_init       Parameters of initial nucleus '/ 
C     /' Z_RES,A_RES,E_FINAL    after evaporation '/ 
C     /' T temperature coefficient of level density '/ 
C     /' Array_En       kinetic energies of neutrons '/ 
C     /' Array_Tn       neutron emission time after scission '/ 
      REAL*4  E_MIN
C     /' Final energy for evaporation chain '/ 
      DATA E_MIN/0/
      REAL*4  SN,SNeff,SNmean
C     /' Neutron separation energy '/ 
      REAL*4  RShell
      INTEGER*4  ITry,Ifold
      REAL*4  Ai,Af,Zi,Zf,Ni,Nf,Ei,Ef
      REAL*4  bshift,bshiftm
      REAL*4  Tm,Td,Tf,Tmean,TCT
      REAL*4  Gamma_n,Gamma_g,Pgamma
      REAL*4  rho,rhom
      REAL*4  alev
      REAL*4  g_koeff
      REAL*4  E_kin
      REAL*4  Tn,Tn_acc
      REAL*4  Fred
      DATA Fred/0.6/
C     ' Fred is introduced to reproduce the neutron even-odd effect 
C     ' 
      Tn_acc = 0 
C     ' Tn_acc = 60 
      Ifold = 1 
C     ' 
      Ai = A_CN 
      Zi = Z_CN 
      Ei = E_INIT 
C     ' 
C     /' Shell effects included '/ 
      SN = U_Mass(Zi,Ai-1.E0) + Fred * Lypair(Zi,Ai-1.E0) - (U_Mass(Zi,
     *Ai) + Fred * Lypair(Zi,Ai)) 
      SNeff = U_Mass(Zi,Ai-1.E0) - U_Mass(Zi,Ai) 
C     '   SNmean = 0.5E0 * (U_Mass(Zi,Ai-2.E0) - U_Mass(Zi,Ai)) 
C     ' 
C     /' Shell effects excluded '/ 
C     '   SN = LDMass(Zi,Ai-1.E0,0.0) + Lypair(Zi,Ai-1.E0)       '     - (LDMass(Zi,Ai,0.0) + Lypair(Zi,Ai)) 
C     '   SNeff = LDMass(Zi,Ai-1.E0,0.0) - LDMass(Zi,Ai,0.0) 
C     ' 
C     ' 
      Zf = Zi 
      Af = Ai 
      Ef = Ei 
C     ' 
      IF (  Ei .LT. SN  )  Goto Raus 
C     ' 
      Do 
C     ' 
C     /' Treat gamma competition '/ 
      Tm = U_temp(Zi,Ai,Ei,1,1,Tscale,Econd) 
C     ' emitting nucleus 
      Td = U_temp(Zi,Ai-1,Ei-SNeff,1,1,Tscale,Econd) 
C     ' 
      Gamma_g = 0.624 * Ai**1.6 * Tm**5 
C     ' in meV (Ignatyuk,Bologna) 
      Gamma_g = Gamma_g * 1.E-9 
C     ' in MeV 
C     ' 
      Tmean = (Tm + Td)/2 
C     ' 
C     '          Gamma_n = (Ai-1)^0.66667 * 0.0302 * Td^2 / exp(SNeff/Tmean)   ' in MeV (Moretto) 
      Gamma_n = (Ai-1)**0.66667 * 0.13 * Td**2 / exp(SNeff/Td) 
C     ' in MeV (Mor. PRC 54,3062) 
C     ' 
C     ' 
      Tn = Pexp(0.658 / Gamma_n) 
C     ' in units of 10^-21 s (hbar=0.658zs*MeV) 
      Tn = Tn * 2 
C     ' Due to pre-exponential factor of Maxwellien,Tn is about 2 times to large 
      Tn_acc = Tn_acc + Tn 
C     ' 
C     ' Influence on lev.dens. of pairing at low E* 
C     ' (Constant temperature assumed) 
      IF (  Ei-Sn .LT. Abs(Fred * Lypair(Zi,Ai-1))  ) THEN 
C     ' rest energy below mean g.s. of odd-odd nuclei 
      IF (   MOD(Zi,2)  .LT. 0.5 .OR.  MOD((Ai-Zi-1),2)  .LT. 0.5  ) 
     *THEN 
C     ' even Z or even N 
      Gamma_n = exp(-12.E0/SQRT(Ai)/Td) * Gamma_n 
      End If 
      IF (   MOD(Zi,2)  .LT. 0.5 .AND.  MOD((Ai-Zi-1),2)  .LT. 0.5  ) 
     *THEN 
C     'n Z and even N 
C     ' For low level density below pairing gap in even-even nuclei 
      Gamma_n = exp(-12.E0/SQRT(Ai)/Td) * Gamma_n 
      End If 
      End If 
C     /' Reduces the even-odd effect in neutron number 
C     due to low level density below the pairing gap '/ 
C     ' 
C     ' 
C     ' 
      Pgamma = Gamma_g / (Gamma_g + Gamma_n) 
C     ' 
      IF (  RND .LT. Pgamma  ) THEN 
C     ' gamma will be emitted 
C     '              Scope 
      INTEGER*4  N
      REAL*4  Eg
C     ' 
      Eg = P_Egamma_high(Zi,Ai,Ei) 
C     ' 
C     ' Accumulate E1 gammas 
      N = NINT(Eg*1000) 
      IF (  N .GT. 0  ) THEN 
      Ngtot = Ngtot + 1 
      IF (  Ilh .EQ. 1  )  Nglight = Nglight + 1 
      IF (  Ilh .EQ. 2  )  Ngheavy = Ngheavy + 1 
      Egtot1000 = Egtot1000 + EG*1000 
      IF (  N .LE. Ubound(Egamma)  ) THEN 
      Egamma(N) = Egamma(N) + 1 
      End If 
      End If 
      Ei = Ei - Eg 
C     '              End Scope 
      End If 
C     ' 
      IF (  Ei-Sn .LE. E_MIN  ) THEN 
      Zf = Zi 
      Af = Ai 
      Ef = Ei 
      Goto Raus 
      End If 
C     ' 
      ITry = 0 
      Too_Low: 
      ITry = ITry + 1 
      IF (  ITry .LT. 99  ) THEN 
      Td = U_Temp(Zi,Ai-1,Ei-SNeff,1,1,Tscale,Econd) 
C     ' maximum residual energy of daughter nucleus (for En_kin = 0) 
C     ' 
      E_kin = PMaxwellMod(Td,Ai-1) 
C     /' Maxwell,with partial 1/v behaviour '/ 
C     ' 
      Tf = U_temp(Zi,Ai-1,Ei-E_kin-SNeff,1,1,Tscale,Econd) 
C     ' final energy of daughter nucleus with En_kin considered 
C     ' 
C     '         If Ei-E_kin-2*Td > 10 Then   ' In Fermi-gas regime 
      IF (  Ei-E_kin-Td .GT. 5  ) THEN 
C     ' to avoid Tf at negative energies 
C     '        If RND > sqr( Exp(E_kin/Td)/ Exp(E_kin/Tf) ) Then goto Too_low 
C     '        If RND > ( Exp(E_kin/Td)/ Exp(E_kin/Tf) )^0.33333 Then goto Too_low 
      IF (  RND .GT. ( Exp(E_kin/Td)/ Exp(E_kin/Tf) )**0.25  )  goto 
     *Too_low 
C     ' Modified Maxwell that adapts to the Fermi-gas regime 
C     ' 
C     '         If RND > ( Exp(E_kin/Td)^2/ Exp(E_kin/Tf) )^0.3333333 Then goto Too_low 
C     ' adjusted to data,justification not clear 
      End If 
C     ' 
      Else 
C     /' E_kin too high after several attemps '/ 
C     /' no neutron emitted '/ 
      Af = Ai 
      Zf = Zi 
      Ef = Ei 
C     ' 
      GOTO Raus 
      END IF 
C     ' 
      IF (  E_kin .GT. Ei-SN  ) THEN 
C     /' E_kin from PMaxwell is not available '/ 
C     /' Try again '/ 
      Goto Too_Low 
      End If 
C     ' 
      Af = Ai - 1 
      Zf = Zi 
      Ef = Ei - E_kin - SN 
C     ' Print "Eva: E_kin(neutron) = ";Ilh,E_kin 
C     ' 
C     /' ANAL(EN,E_kin); 
C     ANAL(ENM(I_MODE),E_kin); '/ 
C     ' 
C     /' Shell effects included '/ 
      SN = (U_Mass(Zf,Af-1.E0) + Fred * Lypair(Zf,Af-1.E0)) - 
     *(U_Mass(Zf,Af) + Fred * Lypair(Zf,Af)) 
      SNeff = U_Mass(Zf,Af-1.E0) - U_Mass(Zf,Af) 
C     '  SNmean = 0.5E0 * (U_Mass(Zf,Af-2.E0) - U_Mass(Zf,Af)) 
C     ' 
C     /' Shell effects excluded '/ 
C     '   SN = LDMass(Zf,Af-1.E0,0.0) + Lypair(Zf,Af-1.E0)          '     - (LDMass(Zf,Af,0.0) + Lypair(Zf,Af)) 
C     '   SNeff = LDMass(Zf,Af-1.E0,0.0) - LDMass(Zf,Af,0.0) 
C     ' 
      Ai = Af 
      Zi = Zf 
      Ei = Ef 
C     ' 
      Array_En(Ifold) = E_kin * (Af-1.E0) / Af 
      Array_Tn(Ifold) = Tn_acc 
      Ifold = Ifold + 1 
C     ' 
C     ' 
      Loop DO WHILE( Ei-SN .GT. E_min) 
C     ' 
      Raus: 
      A_RES = Af 
      Z_RES = Zf 
      E_FINAL = MAX(Ef,0.0) 
C     ' 
      END
C     ' 
C     ' 
C     ' 
      REAL*4 FUNCTION u_accel(A1,Z1,A2,Z2,TKE,E0,Tn)
      IMPLICIT NONE
      REAL*4 A1
      REAL*4 Z1
      REAL*4 A2
      REAL*4 Z2
      REAL*4 TKE
      REAL*4 E0
      REAL*4 Tn
C     ' returns the velocity of the fragment 1 after time Tn 
C     ' 
C     'Acceleration of fission fragments by their Coulomb field 
C     ' 
C     ' natural constants 
      REAL*4  e2
C     ' MeV 
      DATA e2/1.44/
      REAL*4  u
C     ' MeV / c^2 
      DATA u/931.5/
      REAL*4  hbarc
C     ' MeV fm 
      DATA hbarc/197/
C     ' 
C     ' variables 
      REAL*4  Ared,d0,v0
      REAL*4  d,t,dt,a,v,v1,E
      REAL*4  vinf
C     ' relative velocity at infinity 
C     ' 
      Ared = A1 * A2 / (A1 + A2) 
      vinf = SQRT(TKE/Ared) 
C     ' sqr(E/A),Ekin asymmptotic in MeV 
      IF (  t .GT. 100  ) THEN 
      v = vinf 
      goto match 
      End If 
C     ' 
      d0 = e2 * Z1 * Z2 / (TKE-E0) 
C     ' fm 
      v0 = SQRT(E0) 
C     ' sqr(E/A),Ekin at scission in MeV 
C     ' 
      d = d0 
      v = 0 
      dt = 0.01 
      DO t = 0 , 1 , dt 
C     ' in  10^-21 s 
      IF (  t .GE. Tn  )  Goto match 
      E = E0 + e2 * Z1 * Z2 * (1/d0 - 1/d) 
C     ' MeV 
      v = SQRT(E/Ared) 
C     ' sqr(E/A),E in MeV 
      d = d + v * 14 * dt 
C     ' in fm 
      END DO 
      dt = 0.1 
      DO t = 1.1 , 10 , dt 
C     ' in  10^-21 s 
      IF (  t .GE. Tn  )  Goto match 
      E = E0 + e2 * Z1 * Z2 * (1/d0 - 1/d) 
C     ' MeV 
      v = SQRT(E/Ared) 
C     ' sqr(E/A),E in MeV 
      d = d + v * 14 * dt 
C     ' in fm 
      END DO 
      dt = 1 
      DO t = 11 , 100 , dt 
C     ' in  10^-21 s 
      IF (  t .GE. Tn  )  Goto match 
      E = E0 + e2 * Z1 * Z2 * (1/d0 - 1/d) 
C     ' MeV 
      v = SQRT(E/Ared) 
C     ' sqr(E/A),E in MeV 
      d = d + v * 14 * dt 
C     ' in fm 
      END DO 
      match: 
      v1 = v * A2/(A1+A2) 
      u_accel = v1 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION P_Egamma_low(Zi,Ai,Ei)
      IMPLICIT NONE
      REAL*4 Zi
      REAL*4 Ai
      REAL*4 Ei
C     ' Random function,returns gamma energy in MeV 
C     ' For energies below Sn: no competition with neutrons 
      REAL*4  Rres
      INTEGER*4  N
      REAL*4  sigMax,Eg,Erest,rhorest,fg
      REAL*4  xran,yran
      REAL*4  Tm
      REAL*4  GammaExp
C     ' 
      REAL*4  betadef
      DATA betadef/0/
      REAL*4  gammadef
      DATA gammadef/0/
C     ' 
      REAL*4  G0(3),E0(3)
      INTEGER*4  I
C     ' 
      REAL*4  alev
C     ' 
      N = Int(Ei*10 + 0.5) 
      IF (  N .LE. 0  )  N = 1 
      REAL*4 , DIMENSION(N) :: sigma
C     ' sigma is not normalized! 
C     ' (Normalization is done by Monte-Carlo procedure.) 
C     ' 
      Tm = U_temp(Zi,Ai,Ei,1,1,Tscale,Econd) 
      IF (  betadef .EQ. 0 .AND. gammadef .EQ. 0  ) THEN 
      E0(2) = E0_GDR(Zi,Ai) 
      G0(2) = Width_GDR(E0(2)) 
C     ' 
C     ' Establish distribution 
      sigMax = 0 
      DO Eg = 0.1 , Ei , 0.1 
      N = NINT(Eg*10) 
      sigma(N) = exp(-Eg/Tm) * Eg**3 * (G0(2) * Eg) / ( (Eg**2 - 
     *E0(2)**2)**2 + G0(2)**2 * E0(2)**2 ) 
C     ' + 0.7 * G0(2) * 4 * pi^2 * Tm^2 / E0(2)^5 ) 
C     ' last line: correction for low gamma energy (PRC 41 (190) 1941) 
      IF (  sigma(N) .GT. sigMax  )  sigMax = sigma(N) 
      END DO 
      Else 
      sigMax = 0 
      DO I = 1 , 3 
      E0(I) = E0_GDR(Zi,Ai) * Efac_def_GDR(betadef,gammadef,I) 
      G0(I) = Width_GDR(E0(I)) 
C     ' Establish distribution 
      DO Eg = 0.1 , Ei , 0.1 
      N = NINT(Eg*10) 
      sigma(N) = sigma(N) + exp(-Eg/Tm) * Eg**3 * (G0(I) * Eg) / ( 
     *(Eg**2 - E0(I)**2)**2 + G0(I)**2 * E0(I)**2 ) 
C     '   + 0.7 * G0(I) * 4 * pi^2 * Tm^2 / E0^5 ) 
C     ' last line: correction for low gamma energy (PRC 41 (190) 1941) 
      IF (  sigma(N) .GT. sigMax  )  sigMax = sigma(N) 
      END DO 
      END DO 
      End If 
C     ' 
C     ' Dice gamma energy from distribution 
      diceagain_gamma_low: 
      xran = rnd * Ei * 10 
C     ' in units of 100 keV 
      yran = rnd * sigMax 
      IF (  yran .GT. sigma(NINT(xran))  )  goto diceagain_gamma_low 
C     ' 
      P_Egamma_low = xran/10 
C     ' convert to MeV 
      END
C     ' 
      REAL*4 FUNCTION P_Egamma_high(Zi,Ai,Ei)
      IMPLICIT NONE
      REAL*4 Zi
      REAL*4 Ai
      REAL*4 Ei
C     ' Random function,returns gamma energy in MeV 
C     ' From PRL 49 (1982) 434 
C     ' For energies above Sn: competition with neutrons included 
      INTEGER*4  N
      REAL*4  sigMax,Eg
      REAL*4  xran,yran
      REAL*4  Tm
      REAL*4  G0,E0
C     ' 
      N = Int(Ei*10 + 0.5) 
      IF (  N .LE. 0  )  N = 1 
      REAL*4 , DIMENSION(N) :: sigma
C     ' sigma is not normalized 
C     ' (Normalization is done by Monte-Carlo procedure.) 
C     ' 
      E0 = E0_GDR(Zi,Ai) 
      G0 = Width_GDR(E0) 
      Tm = U_temp(Zi,Ai,Ei,1,1,Tscale,Econd) 
C     ' 
C     ' Establish distribution 
      sigMax = 0 
      DO Eg = 0.1 , Ei , 0.1 
      N = NINT(Eg*10.0) 
      sigma(N) = Eg**3 / Tm**2 * exp(-Eg/Tm) * (G0 * Eg) / ( (Eg**2 - 
     *E0**2)**2 + G0**2 * E0**2 ) 
      IF (  sigma(N) .GT. sigMax  )  sigMax = sigma(N) 
      END DO 
C     ' 
C     ' Dice gamma energy from distribution 
      diceagain_gamma_high: 
      xran = rnd * Ei * 10 
C     ' in units of 100 keV 
      yran = rnd * sigMax 
      IF (  yran .GT. sigma(NINT(xran))  )  goto diceagain_gamma_high 
C     ' 
      P_Egamma_high = xran/10 
C     ' convert to MeV 
      END
C     ' 
      REAL*4 FUNCTION U_Ired(Z,A)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
C     ' Effective moment of inertia by pairing and shell effect 
      REAL*4  I_rigid_spher,IfragEff
      REAL*4 U_SHELL 
C     ' 
      I_rigid_spher = 1.16E0**2 * A**1.6667E0 / 103.8415E0 
      IfragEff = I_rigid_spher + 0.003 * A**(4.0/3.0) * U_shell(NINT(Z),
     *NINT(A)) 
C     ' reduction due to shell (Deleplanque et al. PRC 69 (2004) 044309) 
      IfragEff = 0.45 * IfragEff 
C     ' Effect of superfluidity 
C     '  IfragEff = 0.65 * IfragEff   ' Average effect of superfluidity and deformation 
      U_Ired = IfragEff 
      END
C     ' 
      REAL*4 FUNCTION U_alev_ld(Z,A)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
C     '  U_alev_ld = 0.073 * A + 0.095 * A^0.666667  'Ignatyuk (1970's) 
      U_alev_ld = 0.078 * A + 0.115 * A**0.6666667 
C     ' Ignatyuk (Bologna 2000) 
C     '  U_alev_ld = 0.089 * A    ' only volume term 
      END
C     ' 
      REAL*4 FUNCTION U_Temp(Z,A,E,Ishell,Ipair,Tscale,Econd)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 E
      INTEGER*4 Ishell
      INTEGER*4 Ipair
      REAL*4 Tscale
      REAL*4 Econd
C     ' Temperature (modified Gilbert-Cameron composite level density) 
C     ' KHS (10. 2. 2012) 
      REAL*4  alev
      REAL*4  Eeff0,Eeff1,Rho0,Rho1,TCT,TFG
      REAL*4  fgamma
      DATA fgamma/0.055/
      REAL*4  RShell,RPair,Res
      REAL*4 U_ALEV_LD 
      REAL*4 U_SHELL 
      REAL*4 LYPAIR 
      REAL*4 TEGIDY 
C     ' Used global parameters: Tscale 
C     '   alev = U_alev_ld(Z,A) * 1.1   ' Factor adjusted to high-energy prompt neutrons in U235(nth,f) 
C     ' alev = U_alev_ld(Z,A) * 0.8  ' " with the correction for non-constant T (FG range) 
      alev = U_alev_ld(Z,A) 
C     ' 
      IF (  Ishell .EQ. 1  ) THEN 
      RShell = U_Shell(NINT(Z),NINT(A)) 
      Else 
      RShell = 0.0 
      End If 
      TCT = TEgidy(A,RShell,Tscale) 
C     ' 
      IF (  Ipair .EQ. 1  ) THEN 
      RPair = Lypair(NINT(Z),NINT(A)) 
      Else 
      Rpair = 0.0 
      End If 
      Eeff0 = E - Econd + RPair + Rshell*(1.0 - exp(-fgamma * E)) 
C     ' 
      IF (  Eeff0 .GT. 0.5  ) THEN 
      Eeff1 = Eeff0 + 0.1 
      Rho0 = 1.E0/Eeff0**1.25 * exp(2.E0 * SQRT(alev * Eeff0)) 
      Rho1 = 1.E0/Eeff1**1.25 * exp(2.E0 * SQRT(alev * Eeff1)) 
C     '         Rho0 = 1.E0/Eeff0 * exp(2.E0 * sqr(alev * Eeff0)) 
C     '         Rho1 = 1.E0/Eeff1 * exp(2.E0 * sqr(alev * Eeff1)) 
      TFG = 0.1E0 / (log(Rho1) - log(Rho0)) 
      Else 
      TFG = 0.0 
      End If 
      Res = TCT 
      IF (  TFG .GT. Res  )  Res = TFG 
C     ' 
C     ' If Res > 1.4 Then Res = 1.4 
C     ' 
      U_Temp = Res 
      END
C     ' 
      REAL*4 FUNCTION U_Temp2(Z,A,E,Rshell,Rpair,Tscale,Econd)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 E
      REAL*4 Rshell
      REAL*4 Rpair
      REAL*4 Tscale
      REAL*4 Econd
C     ' Temperature (modified Gilbert-Cameron composite level density) 
C     ' KHS (10. 2. 2012) 
      REAL*4  alev
      REAL*4  Eeff0,Eeff1,Rho0,Rho1,TCT,TFG
      REAL*4  fgamma
      DATA fgamma/0.055/
      REAL*4  Res
C     ' Used global parameters: Tscale 
C     '  alev = U_alev_ld(Z,A) * 1.1   ' Factor adjusted to high-energy prompt neutrons in U235(nth,f) 
C     '  alev = U_alev_ld(Z,A) * 0.86  ' " with the correction for non-constant T (FG range) 
      alev = U_alev_ld(Z,A) 
C     ' 
      TCT = TEgidy(A,RShell,Tscale) 
C     ' 
      Eeff0 = E - Econd + RPair + Rshell*(1.0 - exp(-fgamma * E)) 
C     '    Eeff0 = E - Econd + Lypair(CInt(Z),CInt(A)) + Rshell*(1.0 - exp(-fgamma * E)) 
C     ' 
      IF (  Eeff0 .GT. 0.5  ) THEN 
      Eeff1 = Eeff0 + 0.1 
      Rho0 = 1.E0/Eeff0**1.25 * exp(2.E0 * SQRT(alev * Eeff0)) 
      Rho1 = 1.E0/Eeff1**1.25 * exp(2.E0 * SQRT(alev * Eeff1)) 
C     '         Rho0 = 1.E0/Eeff0 * exp(2.E0 * sqr(alev * Eeff0)) 
C     '         Rho1 = 1.E0/Eeff1 * exp(2.E0 * sqr(alev * Eeff1)) 
      TFG = 0.1E0 / (log(Rho1) - log(Rho0)) 
      Else 
      TFG = 0.0 
      End If 
      Res = TCT 
      IF (  TFG .GT. Res  )  Res = TFG 
      U_Temp2 = Res 
      END
C     ' 
      REAL*4 FUNCTION E0_GDR(Z,A)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
C     ' Calculates the centroid energy of the GDR for spherical nucleus 
C     ' according to the FRDM (ADNDT 59 (1995) 185 and PLB 670 (2008) 200) 
      REAL*4  epsilon
      DATA epsilon/0.0768/
      REAL*4  J
      DATA J/32.7/
      REAL*4  Q
      DATA Q/29.2/
      REAL*4  R0
      DATA R0/1.16/
      REAL*4  mstar
      DATA mstar/874/
      REAL*4  hbar
      DATA hbar/197.3/
      REAL*4  Aonethird,u,N,E0
C     ' 
C     ' according to [9] in Phys. Lett. B 690 (2010) 473: 
      E0_GDR = 18.0/A**0.333333 + 25.0 / A**0.1666667 
C     ' 
C     ' according to the FRDM (ADNDT 59 (1995) 185 and PLB 670 (2008) 200): 
C     '    Aonethird = A^0.333333 
C     '    N = A - Z 
C     '    u = (1-epsilon)/Aonethird * 3*J/Q 
C     '    E0_GDR = hbar /(R0*Aonethird)*sqr(8*J*A^2/ (mstar*4*N*Z) ) *   '      (1 + u - epsilon * (1+epsilon+3*u)/(1+epsilon+u))^(-1/2) 
      END
C     ' 
      REAL*4 FUNCTION Width_GDR(E0)
      IMPLICIT NONE
      REAL*4 E0
C     ' Spreading width of the GDR (Nucl. Phys. A 531 (1991) 27) 
      Width_GDR = 1.99 * (E0/10)**1.6 
      END
C     ' 
      REAL*4 FUNCTION Efac_def_GDR(Beta,Gamma,K)
      IMPLICIT NONE
      REAL*4 Beta
      REAL*4 Gamma
      REAL*4 K
C     ' Modification factors of the resonance energy due to triaxial deformation 
C     ' Hill-Wheeler parameterisation (PRC 89 (1953) 1102) 
C     ' Possible values for K:  K-2 = -1,0,1 
      IF (  beta .EQ. 0 .AND. gamma .EQ. 0  ) THEN 
      Efac_def_GDR = 1 
      Else 
      Efac_def_GDR = 1/(exp(SQRT(5/(4*pi))*Beta * cos(gamma - 
     *0.666667*(K-2)*pi))) 
      End If 
      END
C     ' 
      REAL*4 FUNCTION GgGtot(Z,A,E,Egamma)
      IMPLICIT NONE
      REAL*4 Z
      REAL*4 A
      REAL*4 E
      REAL*4 Egamma
C     ' From PRL 49 (1982) 434 
C     ' Probability to emit a gamma of energy Egamma in competition to neutron emission 
      REAL*4  EG,GG,T,SN
      EG = E0_GDR(Z,A) 
      GG = Width_GDR(EG) 
      T = U_Temp(Z,A,E,1,1,Tscale,Econd) 
      SN = U_Mass(Z,A-1.E0) + Lypair(Z,A-1.E0) - (U_Mass(Z,A) + 
     *Lypair(Z,A)) 
      GgGtot = Egamma**3 / T**2 * exp((Sn-Egamma)/T) * GG * EG / 
     *((Egamma**2 - EG**2)**2 + GG**2 * EG**2) 
      END
C     ' 
      REAL*4 FUNCTION E_next(T1,T2,E1,E2,A1,A2)
      IMPLICIT NONE
      REAL*4 T1
      REAL*4 T2
      REAL*4 E1
      REAL*4 E2
      REAL*4 A1
      REAL*4 A2
C     /' Samples the energy transfer in one step between two nuclei '/ 
C     /' in thermal contact '/ 
C     /' The energy transfer is only determined by the available phase space. '/ 
C     /' Only one kind of nucleons considered! '/ 
C     ' 
C     /' T1,T2 Temperatures of the two nuclei '/ 
C     /' E1,E2 Initial energies of the two nuclei '/ 
C     /' A1,A2 Mass numbers of the two nuclei '/ 
C     ' 
      REAL*4  E12
      REAL*4  Delta1,Delta2
C     /' Pairing gaps '/ 
      REAL*4  Delta_E1,Delta_E2
      REAL*4  E1final
C     /' Energy 1 after transfer '/ 
      REAL*4  E1mod,E2mod
      REAL*4 PEXPLIM 
C     ' 
C     /' Assumed level densities: '/ 
C     /' Even number of nucleons: 
C     1 ground state at energy E = - 2 Delta not considered, 
C     continuous level density above E = 0 : rho1,2 = a1,2 * exp(E1,2/T1,2) '/ 
C     ' 
      E12 = E1 + E2 
C     /' Total energy '/ 
C     ' 
      E1mod = E1 
      E2mod = E2 
      IF (  (E1mod > E2mod)  ) THEN 
      Delta_E1 = Pexplim(-1.E0/T1,0.0,E1mod) 
      E1mod = E1mod - Delta_E1 
      E2mod = E2mod + Delta_E1 
      Delta_E2 = Pexplim(-1.E0/T2,0.0,E2mod) 
      E2mod = E2mod - Delta_E2 
      E1mod = E1mod + Delta_E2 
      Else 
      Delta_E2 = Pexplim(-1.E0/T2,0.0,E2mod) 
      E2mod = E2mod - Delta_E2 
      E1mod = E1mod + Delta_E2 
      Delta_E1 = Pexplim(-1.E0/T1,0.0,E1mod) 
      E1mod = E1mod - Delta_E1 
      E2mod = E2mod + Delta_E1 
      END IF 
      E1final = E1mod 
C     ' 
C     /' Select; 
C     When (E1 > E2) Do; 
C     L3: 
C     Delta_E1 = Pexplim(-1.E0/T1,0.0,E1); 
C     E1final = E1 - Delta_E1; 
C     Delta_E1 = Pexplim(-1.E0/T2,0.0,E12-E1final); 
C     E1final = E1final + Delta_E1; 
C     End; 
C     When (E1 <= E2) Do; 
C     L4: 
C     Delta_E1 = Pexplim(-1.E0/T2,0.0,E12-E1); 
C     E1final = E1 + Delta_E1; 
C     Delta_E1 = Pexplim(-1.E0/T1,0.0,E1final); 
C     E1final = E1final - Delta_E1; 
C     End; 
C     Otherwise Do; 
C     List('This should not happen.'); 
C     End; 
C     End; '/ 
C     ' 
      E_next = E1final 
C     ' 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION Pexplim(R_lambda,xmin,xmax)
      IMPLICIT NONE
      REAL*4 R_lambda
      REAL*4 xmin
      REAL*4 xmax
C     /' random number from an exponential between xmin and xmax '/ 
C     /' decay constant: f(x) = exp(lambda * x) !!! '/ 
C     /' xmin,xmax: limits for sampling '/ 
      REAL*4  umin,umax
C     /' xmin,xmax transformed '/ 
      REAL*4  u
C     /' help variable '/ 
      REAL*4  R_res
C     /' sampled value '/ 
C     ' 
      IF (  ABS(R_lambda) .LT. 1.E-30  ) THEN 
      R_res = xmin + Rnd * (xmax-xmin) 
      Else 
      umin = exp(xmin*R_lambda) 
      umax = exp(xmax*R_lambda) 
      u = umin + Rnd * (umax-umin) 
      R_res = 1.E0/R_lambda * log(u) 
      Pexplim = R_res 
      END IF 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION U_Even_Odd(I_Channel,PEO)
      IMPLICIT NONE
      INTEGER*4 I_Channel
      REAL*4 PEO
C     ' Creates even-odd fluctuations 
      REAL*4  R
      IF (   MOD(I_Channel,2)  .EQ. 0  ) THEN 
      R = 1.0 + PEO 
      Else 
      R = 1.0 - PEO 
      End If 
      U_Even_Odd = R 
      END
C     ' 
C     ' 
      INTEGER*4 FUNCTION EVEN_ODD(R_ORIGIN,R_EVEN_ODD)
      IMPLICIT NONE
      REAL*4 R_ORIGIN
      REAL*4 R_EVEN_ODD
C     ' 
C     /' Procedure to calculate I_OUT from R_IN in a way that         '/ 
C     /' on the average a flat distribution in R_IN results in a      '/ 
C     /' fluctuating distribution in I_OUT with an even-odd effect as '/ 
C     /' given by R_EVEN_ODD                                          '/ 
C     ' 
C     /' ------------------------------------------------------------ '/ 
C     /' EXAMPLES :                                                   '/ 
C     /' ------------------------------------------------------------ '/ 
C     /'    If R_EVEN_ODD = 0 :                                       '/ 
C     /'           CEIL(R_IN)  ----                                   '/ 
C     /'                                                              '/ 
C     /'              R_IN ->                                         '/ 
C     /'            (somewhere in between CEIL(R_IN) and FLOOR(R_IN)) '/ 
C     /'                                                              '/ 
C     /'           FLOOR(R_IN) ----       --> I_OUT                   '/ 
C     /' ------------------------------------------------------------ '/ 
C     /'    If R_EVEN_ODD > 0 :                                       '/ 
C     /'      The interval for the above treatment is                 '/ 
C     /'         larger for FLOOR(R_IN) = even and                    '/ 
C     /'         smaller for FLOOR(R_IN) = odd                        '/ 
C     /'    For R_EVEN_ODD < 0 : just opposite treatment              '/ 
C     /' ------------------------------------------------------------ '/ 
C     ' 
C     /' ------------------------------------------------------------ '/ 
C     /' On input:   R_ORIGIN    nuclear charge (real number)         '/ 
C     /'             R_EVEN_ODD  requested even-odd effect            '/ 
C     /' Intermediate quantity: R_IN = R_ORIGIN + 0.5                 '/ 
C     /' On output:  I_OUT       nuclear charge (integer)             '/ 
C     /' ------------------------------------------------------------ '/ 
C     ' 
      REAL*4  R_IN,R_REST,R_HELP
      REAL*4  R_FLOOR
      REAL*4  R_MIDDLE
      INTEGER*4  I_OUT
C     ' 
      R_EVEN_ODD = MIN(R_EVEN_ODD,1) 
      R_IN = R_ORIGIN + 0.5E0 
      R_FLOOR = FLOOR(R_IN) 
      IF (  Abs(R_EVEN_ODD) .LT. 1.E-3  ) THEN 
      I_OUT = R_FLOOR	 
      Else 
      R_REST = R_IN - R_FLOOR 
      R_MIDDLE = R_FLOOR + 0.5E0 
      IF (   MOD(R_FLOOR,2)  .EQ. 0  ) THEN 
C     /' even before modif. '/ 
      R_HELP = R_MIDDLE + (R_REST - 0.5E0) * 1.E0 / Max(0.01,(1.E0 + 
     *R_EVEN_ODD)) 
      R_HELP = Min(R_HELP,R_MIDDLE+1) 
      R_HELP = Max(R_HELP,R_MIDDLE-1) 
      ELSE 
C     /' odd before modification '/ 
      R_HELP = R_MIDDLE + (R_REST - 0.5E0) * 1.E0 / Max(0.01,(1.E0 - 
     *R_EVEN_ODD)) 
      R_HELP = Min(R_HELP,R_MIDDLE+1) 
      R_HELP = Max(R_HELP,R_MIDDLE-1) 
      END IF 
      I_OUT = FLOOR(R_HELP) 
      END IF 
      Even_odd = I_OUT 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION BFTF(RZ,RA,I_Switch)
      IMPLICIT NONE
      REAL*4 RZ
      REAL*4 RA
      INTEGER*4 I_Switch
C     /' Fission barriers from Myers and Swiatecki,Thomas-Fermi model '/ 
C     /'  I_Switch: 0: liquid-drop; 1: with shells and pairing, 
C     2: averaged over pairing,3: with shell and pairing + pairing gap at barrier '/ 
C     ' 4: liquid-drop + g.s. shell,no Z correction 
      REAL*4  RN,RI,Rkappa,RS,RF,RX
      REAL*4  RX0
      DATA RX0/48.5428/
      REAL*4  RX1
      DATA RX1/34.15/
      REAL*4  RB
      INTEGER*4  IZ,IA
      REAL*4 U_SHELL 
      REAL*4 U_SHELL_EXP 
      REAL*4 U_SHELL_EO_EXP 
      REAL*4 LYPAIR 
C     ' 
      IZ = NINT(RZ) 
      IA = NINT(RA) 
      RN = RA - RZ 
      RI = (RN-RZ) / RA 
      Rkappa = 1.9E0 + (RZ - 80.E0) / 75.E0 
      RS = RA**0.666667E0 * (1.E0 - Rkappa * RI**2) 
      RX = RZ**2 / (RA * (1.E0 - Rkappa * RI**2)) 
      IF (  RX .LT. 30  ) THEN 
C     /' out of range '/ 
      RF = 1.E10 
      End If 
      IF (  RX .GT. RX0  ) THEN 
C     /' out of range '/ 
      RF = 0.0 
      End If 
      IF (  RX .LT. RX1 .AND. RX .GT. 30  ) THEN 
      RF = 0.595553E0 - 0.124136E0 * (RX - RX1) 
      End If 
      IF (  RX .GE. RX1 .AND. RX .LE. RX0  ) THEN 
      RF = 0.000199749 * (RX0 - RX)**3 
      End If 
      RB = RF * RS 
C     ' 
      Select CASE( I_Switch) 
      CASE( 0) 
      BFTF = RB 
      CASE( 1) 
C     ' including even-odd staggering due to increased pairing strength at barrier 
C     ' Tentative modification from comparison with experimental fission barriers 
C     ' (shell correction at the barrier?) 
      IF (  RZ .GT. 86.5  )  RB = RB - 0.15 * (RZ - 86.5) 
C     '    If RZ > 90 Then RB = RB + 0.3 * (RZ - 90.0) 
C     '    If RZ > 98 Then RB = RB - 0.15 * (RZ - 98.0) 
      IF (  RZ .GT. 90  )  RB = RB + 0.35 * (RZ - 90.0) 
      IF (  RZ .GT. 93  )  RB = RB + 0.15 * (RZ - 93.0) 
      IF (  RZ .GT. 95  )  RB = RB - 0.25 * (RZ - 95.0) 
C     '    BFTF = RB - U_Shell(IZ,IA) 
C     '    BFTF = RB - U_Shell_exp(IZ,IA) 
      BFTF = RB - U_Shell_EO_exp(IZ,IA) + Lypair(IZ,IA) * 14.0/12.0 
      CASE( 2) 
C     ' averaged over even-odd staggering 
      IF (  RZ .GT. 86.5  )  RB = RB - 0.15 * (RZ - 86.5) 
      IF (  RZ .GT. 90  )  RB = RB + 0.35 * (RZ - 90.0) 
      IF (  RZ .GT. 93  )  RB = RB + 0.15 * (RZ - 93.0) 
      IF (  RZ .GT. 95  )  RB = RB - 0.25 * (RZ - 95.0) 
      BFTF = RB - U_Shell_exp(IZ,IA) 
      CASE( 3) 
C     ' like Case 1 + pairing gap at barrier 
      IF (  RZ .GT. 86.5  )  RB = RB - 0.15 * (RZ - 86.5) 
      IF (  RZ .GT. 90  )  RB = RB + 0.35 * (RZ - 90.0) 
      IF (  RZ .GT. 93  )  RB = RB + 0.15 * (RZ - 93.0) 
      IF (  RZ .GT. 95  )  RB = RB - 0.25 * (RZ - 95.0) 
      BFTF = RB - U_Shell_EO_exp(IZ,IA) 
      CASE( 4) 
C     ' like case 3 but without Z correction 
C     ' This is the direct description from the topographic theorem. 
      BFTF = RB - U_Shell_exp(IZ,IA) 
      Case DEFAULT 
C     '         Print "Undefined option in BFTF" 
C     '         Sleep 
      End Select 
C     /'  If I_Switch = 0 Then 
C     BFTF = RB 
C     Else 
C     ' Tentative modification from comparison with experimental fission barriers 
C     ' (shell correction at the barrier?) 
C     If RZ > 86.5 Then RB = RB - 0.15 * (RZ - 86.5) 
C     '    If RZ > 90 Then RB = RB + 0.3 * (RZ - 90.0) 
C     '    If RZ > 98 Then RB = RB - 0.15 * (RZ - 98.0) 
C     If RZ > 90 Then RB = RB + 0.35 * (RZ - 90.0) 
C     If RZ > 93 Then RB = RB + 0.15 * (RZ - 93.0) 
C     If RZ > 95 Then RB = RB - 0.25 * (RZ - 95.0) 
C     ' 
C     '    BFTF = RB - U_Shell(IZ,IA) 
C     '    BFTF = RB - U_Shell_exp(IZ,IA) 
C     BFTF = RB - U_Shell_EO_exp(IZ,IA) + Lypair(IZ,IA) * 14.0/12.0 
C     End If '/ 
      END
C     ' 
      REAL*4 FUNCTION BFTFA(RZ,RA,I_Switch)
      IMPLICIT NONE
      REAL*4 RZ
      REAL*4 RA
      INTEGER*4 I_Switch
C     /' inner barrier height '/ 
      REAL*4  EA,BF0,Z4A,Z3A,DB
      REAL*4  coeff
      DATA coeff/0.5/
      REAL*4 BFTF 
      BF0 = BFTF(RZ,RA,I_Switch) 
C     ' Z4A = RZ^4 / RA 
C     '  EB - EA from fit to Smirenkin barriers: 
C     '  V. M. Kupriyanov,K. K. Istekov,B. I. Fursov,G. N. Smirenkin 
C     '  Sov. J. Nucl. Phys. 32 (1980) 184 
C     '  DB = -10.3517 + 1.6027E-5 * Z4A + 5.4945E-11 * Z4A^2  ' EA - EB 
C     ' 
C     '  EB - EA from fit to data from Dahlinger et al. (KHS,21. Dec. 2012) 
      Z3A = RZ**3 / RA 
      DB = -(5.40101 - 0.00666175*Z3A + 1.52531E-6*Z3A**2) 
      IF (  DB .GT. 0.0  ) THEN 
      EA = BF0 - DB 
      Else 
      EA = BF0 
      End If 
      BFTFA = EA 
      END
C     ' 
      REAL*4 FUNCTION BFTFB(RZ,RA,I_Switch)
      IMPLICIT NONE
      REAL*4 RZ
      REAL*4 RA
      INTEGER*4 I_Switch
C     /' outer barrier height '/ 
      REAL*4  EB,BF0,Z4A,Z3A,DB
      REAL*4  coeff
      DATA coeff/0.5/
      REAL*4 BFTF 
      BF0 = BFTF(RZ,RA,I_Switch) 
C     ' Z4A = RZ^4 / RA 
C     '  EB - EA from fit to Smirenkin barriers: 
C     '  V. M. Kupriyanov,K. K. Istekov,B. I. Fursov,G. N. Smirenkin 
C     '  Sov. J. Nucl. Phys. 32 (1980) 184 
C     '   DB = -10.3517 + 1.6027E-5 * Z4A + 5.4945E-11 * Z4A^2  ' EA - EB 
C     ' 
C     '  EB - EA from fit to data from Dahlinger et al. (KHS,21. Dec. 2012) 
      Z3A = RZ**3 / RA 
      DB = -(5.40101 - 0.00666175*Z3A + 1.52531E-6*Z3A**2) 
      IF (  DB .LT. 0.0  ) THEN 
      EB = BF0 + DB 
      Else 
      EB = BF0 
      End If 
      BFTFB = EB 
      END
C     ' 
C     ' 
C     ' 
C     /' Utility functions '/ 
C     ' 
C     ' 
      REAL*4 FUNCTION Gaussintegral(R_x,R_sigma)
      IMPLICIT NONE
      REAL*4 R_x
      REAL*4 R_sigma
C     /' Smoothed step function. Grows from 0 to 1 around R_x 
C     with a Gauss-integral function with given sigma'/ 
      REAL*4  R_ret
C     ' Note: The variable R_sigma = standard deviation / sqr(2) ! 
      REAL*4 ERF 
      R_ret = 0.5E0 + 0.5E0 * Erf(R_x / R_sigma) 
      Gaussintegral = R_ret 
      END
C     ' 
      REAL*4 FUNCTION U_Box(x,sigma,length)
      IMPLICIT NONE
      REAL*4 x
      REAL*4 sigma
      REAL*4 length
      REAL*4  y
C     ' Note: The variable sigma = standard deviation / sqr(2) ! 
      REAL*4 GAUSSINTEGRAL 
      y = Gaussintegral(x+0.5*length,sigma) - 
     *Gaussintegral(x-0.5*length,sigma) 
      U_Box = y/length 
      END
C     ' 
      REAL*4 FUNCTION U_Gauss(x,sigma)
      IMPLICIT NONE
      REAL*4 x
      REAL*4 sigma
      REAL*4  y
      REAL*4  pi
      PARAMETER (pi=3.14159)
C     ' 
      y = 1.0 / (SQRT(2.0 * pi) * sigma) * exp(-x**2/ ( 2.0 * sigma**2 
     *) ) 
      U_Gauss = y 
      END
C     ' 
      REAL*4 FUNCTION U_Gauss_mod(x,sigma)
      IMPLICIT NONE
      REAL*4 x
      REAL*4 sigma
C     ' Gaussian with Sheppard correction 
      REAL*4  y
      REAL*4  sigma_mod
      REAL*4  pi
      PARAMETER (pi=3.14159)
      sigma_mod = SQRT(sigma**2 + 1./12.) 
C     ' 
      y = 1.0 / (SQRT(2.0 * pi) * sigma_mod) * exp(-x**2/ ( 2.0 * 
     *sigma_mod**2 ) ) 
      U_Gauss_mod = y 
      END
C     ' 
C     ' 
      REAL*4 FUNCTION PBox(Mean,Sigma,Bottom)
      IMPLICIT NONE
      REAL*4 Mean
      REAL*4 Sigma
      REAL*4 Bottom
C     ' Rectangular distribution folded with a Gaussian distribution 
      REAL*4  R
      R = PGauss(Mean,Sigma) 
      R = R + (Rnd-0.5)*Bottom 
      PBox = R 
      END
C     ' 
      REAL*4 FUNCTION PBox2(Mean,Sigma1,Sigma2,Bottom)
      IMPLICIT NONE
      REAL*4 Mean
      REAL*4 Sigma1
      REAL*4 Sigma2
      REAL*4 Bottom
C     ' Rectangular distribution folded with a Gaussian distribution. 
C     ' One wing is steeper. 
C     ' Sigma1 = lower side,Sigma2 = upper side 
      REAL*4  Sigma,R
      Sigma = Max(Sigma1,Sigma2) 
      Pbox_Repeat: 
      R = PGauss(Mean,Sigma) 
      R = R + (Rnd-0.5)*Bottom 
      IF (  Sigma1 .LT. Sigma2  ) THEN 
      IF (  R .LT. Mean - 0.5*Bottom  ) THEN 
      IF (  RND .GT. Exp( -(R - Mean + 0.5*Bottom)**2 / (2.0 * 
     *Sigma1**2) ) / Exp( -(R - Mean + 0.5*Bottom)**2 / (2.0 * 
     *Sigma2**2) )  ) THEN 
      R = Mean - 0.5*Bottom + (Mean - 0.5*Bottom - R) 
      End If 
      End If 
      End If 
      IF (  Sigma2 .LE. Sigma1  ) THEN 
      IF (  R .GT. Mean + 0.5*Bottom  ) THEN 
      IF (  RND .GT. Exp( -(R - Mean - 0.5*Bottom)**2 / (2.0 * 
     *Sigma2**2) ) / Exp( -(R - Mean - 0.5*Bottom)**2 / (2.0 * 
     *Sigma1**2) )  ) THEN 
      R = Mean + 0.5*Bottom - (R - Mean - 0.5*Bottom) 
      End If 
      End If 
      End If 
      PBox2 = R 
      END
C     ' 
      REAL*4 FUNCTION PPower(Order,Rmin,Rmax)
      IMPLICIT NONE
      INTEGER*4 Order
      REAL*4 Rmin
      REAL*4 Rmax
C     ' Random generator of a power function: (y = x^Order -> x_random = RND^(1/(Order+1)) 
C     ' PPower = 0 at Rmin to PPower = Ymax at Rmax 
      REAL*4  R
      R = Rmin + (Rmax-Rmin) * Rnd**(1.0/(Order+1)) 
      PPower = R 
      END
C     ' 
      REAL*4 FUNCTION PPower_Griffin_v(Order,Rmin,Rmax)
      IMPLICIT NONE
      INTEGER*4 Order
      REAL*4 Rmin
      REAL*4 Rmax
C     ' Random generator of a power function: (y = x^Order -> x_random = RND^(1/(Order+1)) 
C     ' PPower = 0 at Rmin to PPower = Ymax at Rmax 
      REAL*4  R,v_particle,RRND
      Repeat_Griffin: 
      R = Rmin + (Rmax-Rmin) * Rnd**(1.0/(Order)) 
      v_particle = SQRT(Abs((R-Rmax)/(Rmin-Rmax))) 
      RRND = RND 
      IF (  RRND .GT. v_particle  ) THEN 
      Goto Repeat_Griffin 
      End If 
      PPower_Griffin_v = R 
      END
C     ' 
      REAL*4 FUNCTION PPower_Griffin_E(Order,Rmin,Rmax)
      IMPLICIT NONE
      INTEGER*4 Order
      REAL*4 Rmin
      REAL*4 Rmax
C     ' Random generator of a power function: (y = x^Order -> x_random = RND^(1/(Order+1)) 
C     ' PPower = 0 at Rmin to PPower = Ymax at Rmax 
      REAL*4  R,E_particle
      Repeat_Griffin: 
      R = Rmin + (Rmax-Rmin) * Rnd**(1.0/(Order)) 
      E_particle = (R-Rmax)/(Rmin-Rmax) 
      IF (  Rnd .GT. E_particle  )  Goto Repeat_Griffin 
      PPower_Griffin_E = R 
      END
C     ' 
      REAL*4 FUNCTION PGauss(Mean,Sigma)
      IMPLICIT NONE
      REAL*4 Mean
      REAL*4 Sigma
C     ' Box-Mueller method 
      INTEGER*4  ISet
      DATA ISet/0/
      REAL*4  V1,V2,R,Fac,GasDev,Result
      REAL*4  GSet
      IF (  ISet .EQ. 0  ) THEN 
      Repeat: 
      V1 = 2.E0 * Rnd - 1.E0 
      V2 = 2.E0 * Rnd - 1.E0 
      R = V1**2 + V2**2 
      IF (  R .GE. 1.E0 .OR. R .EQ. 0.0  )  Goto Repeat 
      Fac = SQRT(-2.E0 * Log(R)/R) 
      GSet = V1 * Fac 
      GasDev = V2 * Fac 
      ISet = 1 
      Else 
      GasDev = GSet 
      ISet = 0 
      End If 
      Result = Sigma * GasDev 
      PGauss = Mean + Result 
      END
C     ' 
      REAL*4 FUNCTION PLinGauss(R_Sigma)
      IMPLICIT NONE
      REAL*4 R_Sigma
C     /' Random-number generator for linear * Gaussian function '/ 
C     /' Distribution of nuclear angular momenta '/ 
      REAL*4  R_Res,B_rms
      B_rms = R_Sigma / SQRT(2.0) 
C     ' Because 
C     ' the sum of two PGauss functions increases the width. 
      R_Res = Abs(PGauss(0,B_rms)) + Abs(PGauss(0,B_rms)) 
      R_Res = R_Res + B_rms/4.E0 * (1.E0 - exp(-R_Res/R_Sigma)) 
C     ' correction of shape (approximative) 
      PLinGauss = R_Res 
      END
C     ' 
      REAL*4 FUNCTION U_LinGauss(x,R_Sigma)
      IMPLICIT NONE
      REAL*4 x
      REAL*4 R_Sigma
C     /' Gaussian times a linear function '/ 
C     /' Not normalized! '/ 
      REAL*4  R_Res
      IF (  R_Sigma .GT. 0.0  ) THEN 
      R_Res = x * exp(-x**2/(2.0 * R_Sigma**2)) 
      Else 
      R_Res = 0.0 
      End If 
      U_LinGauss = R_Res 
      END
C     ' 
      REAL*4 FUNCTION PExp(R_Tau)
      IMPLICIT NONE
      REAL*4 R_Tau
C     /' Random-number generator for an exponential distribution '/ 
      REAL*4  X1,R_Res
      Again: 
      X1 = RND 
      IF (  X1 .GT. 1.E-10 .AND. X1 .LT. 0.99999E0  ) THEN 
C     ' for avoiding numerical problems 
      R_Res = - R_Tau * Log(X1) 
      Else 
      Goto Again 
      End If 
      PExp = R_Res 
      END
C     ' 
      REAL*4 FUNCTION PMaxwell(R_T)
      IMPLICIT NONE
      REAL*4 R_T
C     /' Random-number generator for a surface Maxwell distribution '/ 
C     /' y = x * exp(-x/T) '/ 
      REAL*8  R_Res,R_T_int
      R_T_int = R_T 
      R_Res = -R_T_int * (Log(Rnd) + Log(Rnd)) 
      PMaxwell = R_Res 
      END
C     ' 
      REAL*4 FUNCTION PMaxwellv(R_T)
      IMPLICIT NONE
      REAL*4 R_T
C     /' Random generator according to a distribution similar to a '/ 
C     /' Maxwell distribution with quantum-mech. x-section for neutrons '/ 
C     /' (approximation by KHS) '/ 
C     /' Y = SQRT(X) * EXP(-X/T) '/ 
      REAL*4  EN
      EN = 2.E0 * R_T * SQRT(Log(Rnd) * Log(Rnd)) 
      PMaxwellv = EN 
      END
C     ' 
      REAL*4 FUNCTION PMaxwellMod(R_T,R_A)
      IMPLICIT NONE
      REAL*4 R_T
      REAL*4 R_A
C     /' Random generator according to a distribution similar to a '/ 
C     /' Maxwell distribution with quantum-mech. x-section for neutrons '/ 
C     /' (approximation by KHS) '/ 
C     /' Y = SQRT(X) * EXP(-X/T) '/ 
      REAL*4  EN
      IF (  RND .LT. 3.3 / SQRT(R_A)  ) THEN 
C     ' according to PR-116-683 (Dostrowsky et al.) 
      EN = 2.E0 * R_T * SQRT(Log(Rnd) * Log(Rnd)) 
      Else 
      EN = -R_T * (Log(Rnd) + Log(Rnd)) 
      End If 
      PMaxwellMod = EN 
      END
C     ' 
      REAL*4 FUNCTION Floor(R)
      IMPLICIT NONE
      REAL*4 R
      	Floor = Int(R) 
      END
C     ' 
      REAL*4 FUNCTION Ceil(R)
      IMPLICIT NONE
      REAL*4 R
      IF (  R .GT. Floor(R)  ) THEN 
      Ceil = Floor(R) + 1 
      Else 
      Ceil = R 
      End If 
      END
C     ' 
      INTEGER*4 FUNCTION CC_Count(CIn,CDiv)
      IMPLICIT NONE
      CHARACTER*(*) CIn
      CHARACTER*(*) CDiv
C     /' Returns the number of pieces in a string '/ 
      INTEGER*4  I
      DATA I/0,N/
      CHARACTER*(*)  CRest
      CRest = Trim(CIn) 
C     ' remove leading and trailing blanks 
      N = 0 
      IF (  CRest .EQ. ""  ) THEN 
      Return N 
      End If 
      I = Instr(CRest,CDiv) 
      IF (  I .EQ. 0  ) THEN 
      N = 1 
      Return N 
      Else 
      DO WHILE( I .GT. 0) 
      N = N + 1 
      CRest = Mid(CRest,I+Len(CDiv)) 
      CRest = Trim(CRest) 
      I = Instr(CRest,CDiv) 
      END DO 
      N = N + 1 
      Return N 
      End If 
      END
C     ' 
      SUBROUTINE CC_Cut(CIn,CDiv,COut(),N)
      IMPLICIT NONE
      CHARACTER*(*) CIn
      CHARACTER*(*) CDiv
      CHARACTER*(*) COut()
      INTEGER*4 N
C     /' Cuts a string into pieces with CDiv as divider '/ 
C     /' Special treatment for blank as devider: 
C     multiple blanks count as one divider '/ 
      INTEGER*4  I
      DATA I/0/
      CHARACTER*(*)  CRest
      CRest = Trim(CIn) 
C     ' remove leading and trailing blanks 
      N = 0 
      IF (  CRest .EQ. ""  ) THEN 
      Return 
      End If 
      I = Instr(CRest,CDiv) 
      IF (  I .EQ. 0  ) THEN 
      N = 1 
      COut(1) = CIn 
      Return 
      Else 
      DO WHILE( I .GT. 0) 
      N = N + 1 
      IF (  N .GT. Ubound(COut)  ) THEN 
      N = N - 1 
C     '          Print "<E> Dimension of COut too small in CC_cut(";CIn;")" 
      End if 
      COut(N) = Mid(CRest,1,I-1) 
      CRest = Mid(CRest,I+Len(CDiv)) 
      CRest = Trim(CRest) 
      I = Instr(CRest,CDiv) 
      END DO 
      N = N + 1 
      IF (  N .GT. Ubound(COut)  ) THEN 
      N = N - 1 
C     '          Print "<E> Dimension of COut too small in CC_cut(";CIn;")" 
      End if 
      COut(N) = CRest 
      Return 
      End if 
      END
C     ' 
      REAL*4 FUNCTION Round(R,N)
      IMPLICIT NONE
      REAL*4 R
      INTEGER*4 N
C     ' R   Input value 
C     ' N   Number of significant digits 
      REAL*4  RN10,Rred,Rextended,Rrounded,Rout,Rabs
      INTEGER*4  N10,Isign
      IF (  R .EQ. 0  ) THEN 
      Round = 0 
      Else 
      Isign = Sgn(R) 
      Rabs = Abs(R) 
      N10 = Int(Log10(Rabs)) 
      RN10 = 10**N10 
      Rred = Rabs / RN10 
      Rextended = Rred * 10**(N-1) 
      Rrounded = Fix(Rextended + 0.5) 
      Rout = Rrounded / 10**(N-1) * RN10 
      Round = Isign * Rout 
      End If 
      END
C     ' 
      INTEGER*8 FUNCTION Modulo(I,J)
      IMPLICIT NONE
      NONE I
      NONE J
      INTEGER*4  ULongint Iratio,Iresult
      Iratio = I \ J 
      Iresult = I - J * Iratio 
      Modulo = Iresult 
      END
C     ' 
      INTEGER*4 FUNCTION PLoss(IL)
      IMPLICIT NONE
      NONE IL
C     ' Extracts and returns number of prompt protons 
      CHARACTER*(*)  Ctest
      INTEGER*4  I,NP
      Ctest = Oct(IL) 
      NP = 0 
      DO I = 1 , Len(Ctest) 
      IF (  Mid(Ctest,I,1) .EQ. "2" .OR. Mid(Ctest,I,1) .EQ. "4"  )  NP 
     *= NP + 1 
      END DO 
      PLoss = NP 
      END
